package com.ruoyi.web.controller.aboutus;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbFeedback;
import com.ruoyi.system.service.ITbFeedbackService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 问题反馈Controller
 * 
 * @author ruoyi
 * @date 2023-05-04
 */
@Controller
@RequestMapping("/business/feedback")
public class TbFeedbackController extends BaseController
{
    private String prefix = "business/feedback";

    @Autowired
    private ITbFeedbackService tbFeedbackService;

    @RequiresPermissions("business:feedback:view")
    @GetMapping()
    public String feedback()
    {
        return prefix + "/feedback";
    }

    /**
     * 查询问题反馈列表
     */
    @RequiresPermissions("business:feedback:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbFeedback tbFeedback)
    {
        startPage();
        List<TbFeedback> list = tbFeedbackService.selectTbFeedbackList(tbFeedback);
        return getDataTable(list);
    }

    /**
     * 导出问题反馈列表
     */
    @RequiresPermissions("business:feedback:export")
    @Log(title = "问题反馈", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbFeedback tbFeedback)
    {
        List<TbFeedback> list = tbFeedbackService.selectTbFeedbackList(tbFeedback);
        ExcelUtil<TbFeedback> util = new ExcelUtil<TbFeedback>(TbFeedback.class);
        return util.exportExcel(list, "问题反馈数据");
    }

    /**
     * 新增问题反馈
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存问题反馈
     */
    @RequiresPermissions("business:feedback:add")
    @Log(title = "问题反馈", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbFeedback tbFeedback)
    {
        return toAjax(tbFeedbackService.insertTbFeedback(tbFeedback));
    }

    /**
     * 修改问题反馈
     */
    @RequiresPermissions("business:feedback:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbFeedback tbFeedback = tbFeedbackService.selectTbFeedbackById(id);
        mmap.put("tbFeedback", tbFeedback);
        return prefix + "/edit";
    }

    /**
     * 修改保存问题反馈
     */
    @RequiresPermissions("business:feedback:edit")
    @Log(title = "问题反馈", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbFeedback tbFeedback)
    {
        return toAjax(tbFeedbackService.updateTbFeedback(tbFeedback));
    }

    /**
     * 删除问题反馈
     */
    @RequiresPermissions("business:feedback:remove")
    @Log(title = "问题反馈", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbFeedbackService.deleteTbFeedbackByIds(ids));
    }
}
