package com.ruoyi.web.controller.aboutus;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbVersionRecord;
import com.ruoyi.system.service.ITbVersionRecordService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 版本记录Controller
 * 
 * @author ruoyi
 * @date 2023-05-04
 */
@Controller
@RequestMapping("/business/record")
public class TbVersionRecordController extends BaseController
{
    private String prefix = "business/record";

    @Autowired
    private ITbVersionRecordService tbVersionRecordService;

    @RequiresPermissions("business:record:view")
    @GetMapping()
    public String record()
    {
        return prefix + "/record";
    }

    /**
     * 查询版本记录列表
     */
    @RequiresPermissions("business:record:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbVersionRecord tbVersionRecord)
    {
        startPage();
        List<TbVersionRecord> list = tbVersionRecordService.selectTbVersionRecordList(tbVersionRecord);
        return getDataTable(list);
    }

    /**
     * 导出版本记录列表
     */
    @RequiresPermissions("business:record:export")
    @Log(title = "版本记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbVersionRecord tbVersionRecord)
    {
        List<TbVersionRecord> list = tbVersionRecordService.selectTbVersionRecordList(tbVersionRecord);
        ExcelUtil<TbVersionRecord> util = new ExcelUtil<TbVersionRecord>(TbVersionRecord.class);
        return util.exportExcel(list, "版本记录数据");
    }

    /**
     * 新增版本记录
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存版本记录
     */
    @RequiresPermissions("business:record:add")
    @Log(title = "版本记录", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbVersionRecord tbVersionRecord)
    {
        return toAjax(tbVersionRecordService.insertTbVersionRecord(tbVersionRecord));
    }

    /**
     * 修改版本记录
     */
    @RequiresPermissions("business:record:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbVersionRecord tbVersionRecord = tbVersionRecordService.selectTbVersionRecordById(id);
        mmap.put("tbVersionRecord", tbVersionRecord);
        return prefix + "/edit";
    }

    /**
     * 修改保存版本记录
     */
    @RequiresPermissions("business:record:edit")
    @Log(title = "版本记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbVersionRecord tbVersionRecord)
    {
        return toAjax(tbVersionRecordService.updateTbVersionRecord(tbVersionRecord));
    }

    /**
     * 删除版本记录
     */
    @RequiresPermissions("business:record:remove")
    @Log(title = "版本记录", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbVersionRecordService.deleteTbVersionRecordByIds(ids));
    }
}
