package com.ruoyi.web.controller.aboutus;

import java.util.List;

import com.ruoyi.system.domain.TbSchool;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbWeblink;
import com.ruoyi.system.service.ITbWeblinkService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 微信，微博，小红书等链接或二维码Controller
 * 
 * @author ruoyi
 * @date 2023-05-05
 */
@Controller
@RequestMapping("/business/weblink")
public class TbWeblinkController extends BaseController
{
    private String prefix = "business/weblink";

    @Autowired
    private ITbWeblinkService tbWeblinkService;

    @RequiresPermissions("business:weblink:view")
    @GetMapping()
    public String weblink()
    {
        return prefix + "/weblink";
    }

    /**
     * 查询微信，微博，小红书等链接或二维码列表
     */
    @RequiresPermissions("business:weblink:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbWeblink tbWeblink)
    {
        startPage();
        List<TbWeblink> list = tbWeblinkService.selectTbWeblinkList(tbWeblink);
        return getDataTable(list);
    }

    /**
     * 导出微信，微博，小红书等链接或二维码列表
     */
    @RequiresPermissions("business:weblink:export")
    @Log(title = "微信，微博，小红书等链接或二维码", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbWeblink tbWeblink)
    {
        List<TbWeblink> list = tbWeblinkService.selectTbWeblinkList(tbWeblink);
        ExcelUtil<TbWeblink> util = new ExcelUtil<TbWeblink>(TbWeblink.class);
        return util.exportExcel(list, "微信，微博，小红书等链接或二维码数据");
    }

    /**
     * 新增微信，微博，小红书等链接或二维码
     */
    @GetMapping("/add")
    public String add(ModelMap mmap)
    {
        TbWeblink weblink=new TbWeblink();
        mmap.put("weblink",weblink);
        return prefix + "/add";
    }

    /**
     * 新增保存微信，微博，小红书等链接或二维码
     */
    @RequiresPermissions("business:weblink:add")
    @Log(title = "微信，微博，小红书等链接或二维码", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbWeblink tbWeblink)
    {
        return toAjax(tbWeblinkService.insertTbWeblink(tbWeblink));
    }

    /**
     * 修改微信，微博，小红书等链接或二维码
     */
    @RequiresPermissions("business:weblink:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbWeblink tbWeblink = tbWeblinkService.selectTbWeblinkById(id);
        mmap.put("tbWeblink", tbWeblink);
        return prefix + "/edit";
    }

    /**
     * 修改保存微信，微博，小红书等链接或二维码
     */
    @RequiresPermissions("business:weblink:edit")
    @Log(title = "微信，微博，小红书等链接或二维码", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbWeblink tbWeblink)
    {
        return toAjax(tbWeblinkService.updateTbWeblink(tbWeblink));
    }

    /**
     * 删除微信，微博，小红书等链接或二维码
     */
    @RequiresPermissions("business:weblink:remove")
    @Log(title = "微信，微博，小红书等链接或二维码", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbWeblinkService.deleteTbWeblinkByIds(ids));
    }

    @GetMapping("/uploadLinkIcon")
    public String uploadLinkIcon(ModelMap mmap)
    {
        TbWeblink tbWeblink=new TbWeblink();
        mmap.put("weblink",tbWeblink);
        return prefix + "/uploadLinkIcon";
    }

    @GetMapping("/uploadQRImage")
    public String uploadQRImage(ModelMap mmap)
    {
        TbWeblink tbWeblink=new TbWeblink();
        mmap.put("weblink",tbWeblink);
        return prefix + "/uploadQRImage";
    }

}
