package com.ruoyi.web.controller.apply;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.ApplyStateEnum;
import com.ruoyi.common.constant.ApplyStatusEnum;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbNotice;
import com.ruoyi.system.domain.TbUserApply;
import com.ruoyi.system.domain.TbUserApplyOperationRecord;
import com.ruoyi.system.domain.TbUserMaterial;
import com.ruoyi.system.res.UserMaterial1Res;
import com.ruoyi.system.res.UserMaterialRes;
import com.ruoyi.system.service.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDate;
import java.util.List;

/**
 * 用户提交的材料Controller
 * 
 * @author ruoyi
 * @date 2023-04-10
 */
@Controller
@RequestMapping("/system/checkUserMaterial")
public class TbCheckUserMaterialController extends BaseController
{
    private String prefix = "business/checkMaterial";

    @Autowired
    private ICheckUserMaterialService tbUserMaterialService;
    @Autowired
    private ITbNoticeService tbNoticeService;
    @Autowired
    private ITbUserApplyOperationRecordService userApplyOperationRecordService;
    @Autowired
    private ITbUserApplyInfoService tbUserApplyInfoService;

    @RequiresPermissions("system:checkUserMaterial:view")
    @GetMapping()
    public String material()
    {
        return prefix + "/showMaterial";
    }

    /**
     * 查询用户提交的材料列表
     */
    @RequiresPermissions("system:checkUserMaterial:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserMaterial tbUserMaterial)
    {
        startPage();
        List<UserMaterialRes> list = tbUserMaterialService.selectUserMaterialListForCheck(tbUserMaterial);
        return getDataTable(list);
    }

    /**
     * 根据申请id查询材料
     */
    @RequiresPermissions("system:checkUserMaterial:list")
    @GetMapping("/list/{applyId}")
    public String list(@PathVariable("applyId") String applyId, ModelMap mmap)
    {
        UserMaterial1Res userMaterial1Res = tbUserMaterialService.selectUserMaterialList(applyId);
        mmap.put("userMaterial1Res", userMaterial1Res);
        return prefix+"/checkMaterial";
    }

    /**
     * 修改保存用户申请信息
     */
    @Transactional
    @RequiresPermissions("system:checkUserMaterial:edit")
    @Log(title = "审核用户材料信息", businessType = BusinessType.UPDATE)
    @PostMapping("/check")
    @ResponseBody
    public AjaxResult editSave(TbNotice tbNotice)
    {
        TbUserApplyOperationRecord operationRecord=new TbUserApplyOperationRecord();
        TbUserApply tbUserApply=new TbUserApply();
        tbUserApply.setId(tbNotice.getStatusDesc());
        /**
         * 0 审核通过，1 审核没通过
         */
        if("0".equals(tbNotice.getNoticeTypeDesc())){
//            tbUserApply.setApplyStatus(ApplyStatusEnum.pay_ok.getStatus());
            tbUserApply.setApplyState(ApplyStateEnum.formal.getState());
            operationRecord.setOperationContent("审核通过");
            operationRecord.setRemark("材料审核通过");
        }else if("1".equals(tbNotice.getNoticeTypeDesc())){
            tbUserApply.setApplyStatus(ApplyStatusEnum.upload_material.getStatus());
            tbUserApply.setApplyState(ApplyStateEnum.modify.getState());
            operationRecord.setOperationContent(tbNotice.getNoticeTitle());
            operationRecord.setRemark("请根据个人通知修改相关信息");
        }
        /**
         * 更新申请状态
         */
        tbUserApplyInfoService.updateTbUserApplyStatusById(tbUserApply);
        /**
         * 添加申请操作记录
         */
        operationRecord.setApplyId(tbNotice.getStatusDesc());
        operationRecord.setOperationDate(LocalDate.now());
        userApplyOperationRecordService.insertTbUserApplyOperationRecord(operationRecord);

        /**
         * 发布通知
         */
        tbNotice.setCreator(getUserId());
        tbNotice.setNoticeType(2);
        return toAjax(tbNoticeService.insertTbNotice(tbNotice));
    }

}
