package com.ruoyi.web.controller.apply;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.ApplyStateEnum;
import com.ruoyi.common.constant.ApplyStatusEnum;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.*;
import com.ruoyi.system.res.UserApplyRes;
import com.ruoyi.system.service.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户申请信息Controller
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Controller
@RequestMapping("/system/applyInfo")
public class TbUserApplyInfoController extends BaseController
{
    private String prefix = "system/userApply";

    @Autowired
    private ITbUserApplyInfoService tbUserApplyInfoService;
    @Autowired
    private ITbUserBasicInfoService tbUserBasicInfoService;
    @Autowired
    private ITbUserDetailInfoService tbUserDetailInfoService;
    @Autowired
    private ITbUserLanguageBackgroundService tbUserLanguageBackgroundService;
    @Autowired
    private ITbUserEducationBackgroundService tbUserEducationBackgroundService;
    @Autowired
    private ITbUserParentInfoService tbUserParentInfoService;
    @Autowired
    private ITbUserWorkExperienceService tbUserWorkExperienceService;
    @Autowired
    private ITbNoticeService tbNoticeService;
    @Autowired
    private ITbUserApplyOperationRecordService userApplyOperationRecordService;

    @RequiresPermissions("system:applyInfo:view")
    @GetMapping()
    public String applyInfo()
    {
        return prefix + "/applyInfo";
    }

    /**
     * 查询用户申请信息列表
     */
    @RequiresPermissions("system:applyInfo:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserApply tbUserApply)
    {
        startPage();
        tbUserApply.setApplyStatus(ApplyStatusEnum.check_table.getStatus());
        List<UserApplyRes> list = tbUserApplyInfoService.selectTbUserApplyInfoList(tbUserApply);
        if(null == list || list.isEmpty()){
            return getDataTable(new ArrayList<TbUserApply>());
        }
        return getDataTable(list);
    }

    /**
     * 导出用户申请信息列表
     */
//    @RequiresPermissions("system:applyInfo:export")
//    @Log(title = "用户申请信息", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    @ResponseBody
//    public AjaxResult export(TbUserDetailInfo tbUserDetailInfo)
//    {
//        List<TbUserDetailInfo> list = tbUserDetailInfoService.selectTbUserDetailInfoList(tbUserDetailInfo);
//        ExcelUtil<TbUserDetailInfo> util = new ExcelUtil<TbUserDetailInfo>(TbUserDetailInfo.class);
//        return util.exportExcel(list, "用户申请信息数据");
//    }

    /**
     * 审核用户申请信息
     */
    @RequiresPermissions("system:applyInfo:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        /**
         * 添加基本信息
         */
        TbUserBasicInfo tbUserBasicInfo=tbUserBasicInfoService.selectTbUserBasicInfoByApplyId(id);
        mmap.put("tbUserBasicInfo", tbUserBasicInfo);

        /**
         * 添加详细信息
         */
        TbUserDetailInfo tbUserDetailInfo = tbUserDetailInfoService.selectTbUserDetailInfoByApplyId(id);
        mmap.put("tbUserDetailInfo", tbUserDetailInfo);

        /**
         * 添加教育背景
         */
        List<TbUserEducationBackground> educationBackgroundList=tbUserEducationBackgroundService.selectTbUserEducationBackgroundListByApplyId(id);
        mmap.put("educationBackgroundList", educationBackgroundList);

        /**
         * 添加工作经历
         */
        List<TbUserWorkExperience> workExperienceList= tbUserWorkExperienceService.selectTbUserWorkExperienceListByApplyId(id);
        mmap.put("workExperienceList", workExperienceList);

        /**
         * 添加语言背景
         */
        TbUserLanguageBackground tbUserLanguageBackground=tbUserLanguageBackgroundService.selectTbUserLanguageBackgroundByApplyId(id);
        mmap.put("tbUserLanguageBackground", tbUserLanguageBackground);

        /**
         * 添加父母信息
         */
        List<TbUserParentInfo> parentInfoList= tbUserParentInfoService.selectTbUserParentInfoListByApplyId(id);
        mmap.put("parentInfoList", parentInfoList);

        return prefix + "/edit";
    }

    /**
     * 修改保存用户申请信息
     */
    @Transactional
    @RequiresPermissions("system:applyInfo:edit")
    @Log(title = "审核用户申请信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbNotice tbNotice)
    {
        TbUserApplyOperationRecord operationRecord=new TbUserApplyOperationRecord();
        TbUserApply tbUserApply=new TbUserApply();
        tbUserApply.setId(tbNotice.getStatusDesc());
        /**
         * 0 审核通过，1 审核没通过
         */
        if("0".equals(tbNotice.getNoticeTypeDesc())){
            tbUserApply.setApplyStatus(ApplyStatusEnum.upload_material.getStatus());
            tbUserApply.setApplyState(ApplyStateEnum.formal.getState());
            operationRecord.setOperationContent("审核通过");
            operationRecord.setRemark("联系顾问准备上传材料");
            //修改六种表格信息的状态，将编辑状态改为不可修改
            tbUserBasicInfoService.updateModifyState(tbNotice.getStatusDesc(),"N");
            tbUserDetailInfoService.updateModifyState(tbNotice.getStatusDesc(),"N");
            tbUserEducationBackgroundService.updateModifyState(tbNotice.getStatusDesc(),"N");
            tbUserLanguageBackgroundService.updateModifyState(tbNotice.getStatusDesc(),"N");
            tbUserParentInfoService.updateModifyState(tbNotice.getStatusDesc(),"N");
            tbUserWorkExperienceService.updateModifyState(tbNotice.getStatusDesc(),"N");
        }else if("1".equals(tbNotice.getNoticeTypeDesc())){
            tbUserApply.setApplyStatus(ApplyStatusEnum.fill_in_table.getStatus());
            tbUserApply.setApplyState(ApplyStateEnum.modify.getState());
            operationRecord.setOperationContent(tbNotice.getNoticeTitle());
            operationRecord.setRemark("请根据个人通知修改相关信息");
            tbNotice.setApplyId(tbNotice.getStatusDesc());

            //修改六种表格信息的状态，将编辑状态改为可修改
            tbUserBasicInfoService.updateModifyState(tbNotice.getStatusDesc(), Constants.YES);
            tbUserDetailInfoService.updateModifyState(tbNotice.getStatusDesc(),Constants.YES);
            tbUserEducationBackgroundService.updateModifyState(tbNotice.getStatusDesc(),Constants.YES);
            tbUserLanguageBackgroundService.updateModifyState(tbNotice.getStatusDesc(),Constants.YES);
            tbUserParentInfoService.updateModifyState(tbNotice.getStatusDesc(),Constants.YES);
            tbUserWorkExperienceService.updateModifyState(tbNotice.getStatusDesc(),Constants.YES);
        }
        /**
         * 更新申请状态
         */
        tbUserApplyInfoService.updateTbUserApplyStatusById(tbUserApply);
        /**
         * 添加申请操作记录
         */
        operationRecord.setApplyId(tbNotice.getStatusDesc());
        operationRecord.setOperationDate(LocalDate.now());
        userApplyOperationRecordService.insertTbUserApplyOperationRecord(operationRecord);

        /**
         * 发布通知
         */
        tbNotice.setCreator(getUserId());
        tbNotice.setNoticeType(2);
        return toAjax(tbNoticeService.insertTbNotice(tbNotice));
    }

}
