package com.ruoyi.web.controller.apply;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserBasicInfo;
import com.ruoyi.system.service.ITbUserBasicInfoService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户基本信息Controller
 * 
 * @author ruoyi
 * @date 2023-01-05
 */
@Controller
@RequestMapping("/system/basic")
public class TbUserBasicInfoController extends BaseController
{
    private String prefix = "business/basicInfo";

    @Autowired
    private ITbUserBasicInfoService tbUserBasicInfoService;

    @RequiresPermissions("system:basic:view")
    @GetMapping()
    public String info()
    {
        return prefix + "/basic";
    }

    /**
     * 查询用户基本信息列表
     */
    @RequiresPermissions("system:basic:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserBasicInfo tbUserBasicInfo)
    {
        startPage();
        List<TbUserBasicInfo> list = tbUserBasicInfoService.selectTbUserBasicInfoList(tbUserBasicInfo);
        return getDataTable(list);
    }

    /**
     * 导出用户基本信息列表
     */
    @RequiresPermissions("system:basic:export")
    @Log(title = "用户基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUserBasicInfo tbUserBasicInfo)
    {
        List<TbUserBasicInfo> list = tbUserBasicInfoService.selectTbUserBasicInfoList(tbUserBasicInfo);
        ExcelUtil<TbUserBasicInfo> util = new ExcelUtil<TbUserBasicInfo>(TbUserBasicInfo.class);
        return util.exportExcel(list, "用户基本信息数据");
    }

    /**
     * 新增用户基本信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户基本信息
     */
    @RequiresPermissions("system:basic:add")
    @Log(title = "用户基本信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserBasicInfo tbUserBasicInfo)
    {
        return toAjax(tbUserBasicInfoService.insertTbUserBasicInfo(tbUserBasicInfo));
    }

    /**
     * 修改用户基本信息
     */
    @RequiresPermissions("system:basic:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserBasicInfo tbUserBasicInfo = tbUserBasicInfoService.selectTbUserBasicInfoById(id);
        mmap.put("tbUserBasicInfo", tbUserBasicInfo);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户基本信息
     */
    @RequiresPermissions("system:basic:edit")
    @Log(title = "用户基本信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserBasicInfo tbUserBasicInfo)
    {
        return toAjax(tbUserBasicInfoService.updateTbUserBasicInfo(tbUserBasicInfo));
    }

    /**
     * 删除用户基本信息
     */
    @RequiresPermissions("system:basic:remove")
    @Log(title = "用户基本信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserBasicInfoService.deleteTbUserBasicInfoByIds(ids));
    }
}
