package com.ruoyi.web.controller.apply;

import java.util.List;

import com.ruoyi.system.res.StudentInfo;
import org.apache.ibatis.annotations.Param;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserDetailInfo;
import com.ruoyi.system.service.ITbUserDetailInfoService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户详细信息Controller
 * 
 * @author ruoyi
 * @date 2023-01-05
 */
@Controller
@RequestMapping("/system/detail")
public class TbUserDetailInfoController extends BaseController
{
    private String prefix = "business/detailInfo";

    @Autowired
    private ITbUserDetailInfoService tbUserDetailInfoService;

    @RequiresPermissions("system:detail:view")
    @GetMapping()
    public String info()
    {
        return prefix + "/detail";
    }

    /**
     * 查询用户详细信息列表
     */
    @RequiresPermissions("system:detail:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserDetailInfo tbUserDetailInfo)
    {
        startPage();
        List<TbUserDetailInfo> list = tbUserDetailInfoService.selectTbUserDetailInfoList(tbUserDetailInfo);
        return getDataTable(list);
    }

    /**
     * 导出用户详细信息列表
     */
    @RequiresPermissions("system:detail:export")
    @Log(title = "用户详细信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUserDetailInfo tbUserDetailInfo)
    {
        List<TbUserDetailInfo> list = tbUserDetailInfoService.selectTbUserDetailInfoList(tbUserDetailInfo);
        ExcelUtil<TbUserDetailInfo> util = new ExcelUtil<TbUserDetailInfo>(TbUserDetailInfo.class);
        return util.exportExcel(list, "用户详细信息数据");
    }

    /**
     * 新增用户详细信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户详细信息
     */
    @RequiresPermissions("system:detail:add")
    @Log(title = "用户详细信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserDetailInfo tbUserDetailInfo)
    {
        return toAjax(tbUserDetailInfoService.insertTbUserDetailInfo(tbUserDetailInfo));
    }

    /**
     * 修改用户详细信息
     */
    @RequiresPermissions("system:detail:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserDetailInfo tbUserDetailInfo = tbUserDetailInfoService.selectTbUserDetailInfoById(id);
        mmap.put("tbUserDetailInfo", tbUserDetailInfo);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户详细信息
     */
    @RequiresPermissions("system:detail:edit")
    @Log(title = "用户详细信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserDetailInfo tbUserDetailInfo)
    {
        return toAjax(tbUserDetailInfoService.updateTbUserDetailInfo(tbUserDetailInfo));
    }

    /**
     * 删除用户详细信息
     */
    @RequiresPermissions("system:detail:remove")
    @Log(title = "用户详细信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserDetailInfoService.deleteTbUserDetailInfoByIds(ids));
    }

    /**
     * @Author : fanxiaolong
     * @Description : 根据手机号或者护照号或者身份证号查询用户的姓名
     * @DateTime : 2023/8/3 16:44
     * @param : vagueParam
     * @return : java.lang.String
     */
    @Log(title = "根据手机号或者护照号或者身份证号查询用户的姓名", businessType = BusinessType.QUERY)
    @GetMapping("/query")
    @ResponseBody
    public StudentInfo queryUserName(@RequestParam String vagueParam){
        return tbUserDetailInfoService.queryUserName(vagueParam);
    }
}
