package com.ruoyi.web.controller.apply;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserEducationBackground;
import com.ruoyi.system.service.ITbUserEducationBackgroundService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户教育背景Controller
 * 
 * @author ruoyi
 * @date 2023-01-05
 */
@Controller
@RequestMapping("/system/edu")
public class TbUserEducationBackgroundController extends BaseController
{
    private String prefix = "business/education";

    @Autowired
    private ITbUserEducationBackgroundService tbUserEducationBackgroundService;

    @RequiresPermissions("system:edu:view")
    @GetMapping()
    public String background()
    {
        return prefix + "/edu";
    }

    /**
     * 查询用户教育背景列表
     */
    @RequiresPermissions("system:edu:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserEducationBackground tbUserEducationBackground)
    {
        startPage();
        List<TbUserEducationBackground> list = tbUserEducationBackgroundService.selectTbUserEducationBackgroundList(tbUserEducationBackground);
        return getDataTable(list);
    }

    /**
     * 导出用户教育背景列表
     */
    @RequiresPermissions("system:edu:export")
    @Log(title = "用户教育背景", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUserEducationBackground tbUserEducationBackground)
    {
        List<TbUserEducationBackground> list = tbUserEducationBackgroundService.selectTbUserEducationBackgroundList(tbUserEducationBackground);
        ExcelUtil<TbUserEducationBackground> util = new ExcelUtil<TbUserEducationBackground>(TbUserEducationBackground.class);
        return util.exportExcel(list, "用户教育背景数据");
    }

    /**
     * 新增用户教育背景
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户教育背景
     */
    @RequiresPermissions("system:edu:add")
    @Log(title = "用户教育背景", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserEducationBackground tbUserEducationBackground)
    {
        return toAjax(tbUserEducationBackgroundService.insertTbUserEducationBackground(tbUserEducationBackground));
    }

    /**
     * 修改用户教育背景
     */
    @RequiresPermissions("system:edu:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserEducationBackground tbUserEducationBackground = tbUserEducationBackgroundService.selectTbUserEducationBackgroundById(id);
        mmap.put("tbUserEducationBackground", tbUserEducationBackground);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户教育背景
     */
    @RequiresPermissions("system:edu:edit")
    @Log(title = "用户教育背景", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserEducationBackground tbUserEducationBackground)
    {
        return toAjax(tbUserEducationBackgroundService.updateTbUserEducationBackground(tbUserEducationBackground));
    }

    /**
     * 删除用户教育背景
     */
    @RequiresPermissions("system:edu:remove")
    @Log(title = "用户教育背景", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserEducationBackgroundService.deleteTbUserEducationBackgroundByIds(ids));
    }
}
