package com.ruoyi.web.controller.apply;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserLanguageBackground;
import com.ruoyi.system.service.ITbUserLanguageBackgroundService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户语言背景Controller
 * 
 * @author ruoyi
 * @date 2023-01-05
 */
@Controller
@RequestMapping("/system/language")
public class TbUserLanguageBackgroundController extends BaseController
{
    private String prefix = "business/language";

    @Autowired
    private ITbUserLanguageBackgroundService tbUserLanguageBackgroundService;

    @RequiresPermissions("system:language:view")
    @GetMapping()
    public String background()
    {
        return prefix + "/language";
    }

    /**
     * 查询用户语言背景列表
     */
    @RequiresPermissions("system:language:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserLanguageBackground tbUserLanguageBackground)
    {
        startPage();
        List<TbUserLanguageBackground> list = tbUserLanguageBackgroundService.selectTbUserLanguageBackgroundList(tbUserLanguageBackground);
        return getDataTable(list);
    }

    /**
     * 导出用户语言背景列表
     */
    @RequiresPermissions("system:language:export")
    @Log(title = "用户语言背景", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUserLanguageBackground tbUserLanguageBackground)
    {
        List<TbUserLanguageBackground> list = tbUserLanguageBackgroundService.selectTbUserLanguageBackgroundList(tbUserLanguageBackground);
        ExcelUtil<TbUserLanguageBackground> util = new ExcelUtil<TbUserLanguageBackground>(TbUserLanguageBackground.class);
        return util.exportExcel(list, "用户语言背景数据");
    }

    /**
     * 新增用户语言背景
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户语言背景
     */
    @RequiresPermissions("system:language:add")
    @Log(title = "用户语言背景", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserLanguageBackground tbUserLanguageBackground)
    {
        return toAjax(tbUserLanguageBackgroundService.insertTbUserLanguageBackground(tbUserLanguageBackground));
    }

    /**
     * 修改用户语言背景
     */
    @RequiresPermissions("system:language:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserLanguageBackground tbUserLanguageBackground = tbUserLanguageBackgroundService.selectTbUserLanguageBackgroundById(id);
        mmap.put("tbUserLanguageBackground", tbUserLanguageBackground);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户语言背景
     */
    @RequiresPermissions("system:language:edit")
    @Log(title = "用户语言背景", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserLanguageBackground tbUserLanguageBackground)
    {
        return toAjax(tbUserLanguageBackgroundService.updateTbUserLanguageBackground(tbUserLanguageBackground));
    }

    /**
     * 删除用户语言背景
     */
    @RequiresPermissions("system:language:remove")
    @Log(title = "用户语言背景", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserLanguageBackgroundService.deleteTbUserLanguageBackgroundByIds(ids));
    }
}
