package com.ruoyi.web.controller.apply;

import java.util.List;

import com.ruoyi.system.res.MaterialTypeRes;
import com.ruoyi.system.res.UserMaterialRes;
import com.ruoyi.system.service.ITbMaterialDemoService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserMaterial;
import com.ruoyi.system.service.ITbUserMaterialService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户提交的材料Controller
 * 
 * @author ruoyi
 * @date 2023-04-10
 */
@Controller
@RequestMapping("/system/userMaterial")
public class TbUserMaterialController extends BaseController
{
    private String prefix = "business/material";

    @Autowired
    private ITbUserMaterialService tbUserMaterialService;
    @Autowired
    private ITbMaterialDemoService materialDemoService;

    @RequiresPermissions("system:userMaterial:view")
    @GetMapping()
    public String material()
    {
        return prefix + "/material";
    }

    /**
     * 查询用户提交的材料列表
     */
    @RequiresPermissions("system:userMaterial:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserMaterial tbUserMaterial)
    {
        startPage();
        List<UserMaterialRes> list = tbUserMaterialService.selectUserMaterialList(tbUserMaterial);
        return getDataTable(list);
    }

    /**
     * 新增用户提交的材料
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户提交的材料
     */
    @RequiresPermissions("system:userMaterial:add")
    @Log(title = "用户提交的材料", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserMaterial tbUserMaterial)
    {
        return toAjax(tbUserMaterialService.insertTbUserMaterial(tbUserMaterial));
    }

    /**
     * 修改用户提交的材料
     */
    @RequiresPermissions("system:userMaterial:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserMaterial tbUserMaterial = tbUserMaterialService.selectTbUserMaterialById(id);
        mmap.put("tbUserMaterial", tbUserMaterial);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户提交的材料
     */
    @RequiresPermissions("system:userMaterial:edit")
    @Log(title = "用户提交的材料", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserMaterial tbUserMaterial)
    {
        return toAjax(tbUserMaterialService.updateTbUserMaterial(tbUserMaterial));
    }

    /**
     * 删除用户提交的材料
     */
    @RequiresPermissions("system:userMaterial:remove")
    @Log(title = "用户提交的材料", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserMaterialService.deleteTbUserMaterialByIds(ids));
    }

    /**
     * @Author : fanxiaolong
     * @Description : 返回id，material_name 键值对
     * @DateTime : 2023/4/11 17:41
     * @param :
     * @return : java.util.List<com.ruoyi.system.res.MaterialTypeRes>
     */
    @GetMapping("/getMaterialType")
    @ResponseBody
    public List<MaterialTypeRes> getMaterialType(){

        return materialDemoService.getMaterialType();
    }
}
