package com.ruoyi.web.controller.apply;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import com.ruoyi.common.constant.ApplyStatusEnum;
import com.ruoyi.common.utils.DataUtils;
import com.ruoyi.system.domain.TbUserApply;
import com.ruoyi.system.domain.TbUserDetailInfo;
import com.ruoyi.system.res.UserApplyRes;
import com.ruoyi.system.service.ITbUserApplyInfoService;
import com.ruoyi.system.service.ITbUserDetailInfoService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserOffer;
import com.ruoyi.system.service.ITbUserOfferService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户offerController
 * 
 * @author ruoyi
 * @date 2023-01-16
 */
@Slf4j
@Controller
@RequestMapping("/system/offer")
public class TbUserOfferController extends BaseController
{
    private String prefix = "business/offer";

    @Autowired
    private ITbUserOfferService tbUserOfferService;

    @Autowired
    private ITbUserApplyInfoService tbUserApplyInfoService;

    @Autowired
    private ITbUserDetailInfoService tbUserDetailInfoService;

    @RequiresPermissions("system:offer:view")
    @GetMapping()
    public String offer()
    {
        return prefix + "/offer";
    }

    /**
     * 查询用户offer列表
     */
    @RequiresPermissions("system:offer:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserOffer tbUserOffer)
    {
        startPage();
        List<TbUserOffer> list = tbUserOfferService.selectTbUserOfferList(tbUserOffer);
        return getDataTable(list);
    }

    /**
     * 导出用户offer列表
     */
    @RequiresPermissions("system:offer:export")
    @Log(title = "用户offer", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUserOffer tbUserOffer)
    {
        List<TbUserOffer> list = tbUserOfferService.selectTbUserOfferList(tbUserOffer);
        ExcelUtil<TbUserOffer> util = new ExcelUtil<TbUserOffer>(TbUserOffer.class);
        return util.exportExcel(list, "用户offer数据");
    }

    /**
     * 新增用户offer
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户offer
     */
    @RequiresPermissions("system:offer:add")
    @Log(title = "用户offer", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserOffer tbUserOffer)
    {
        tbUserOffer.setOfferTime(LocalDate.now());
        return toAjax(tbUserOfferService.insertTbUserOffer(tbUserOffer));
    }

    /**
     * 修改用户offer
     */
    @RequiresPermissions("system:offer:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserOffer tbUserOffer = tbUserOfferService.selectTbUserOfferById(id);
        mmap.put("tbUserOffer", tbUserOffer);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户offer
     */
    @RequiresPermissions("system:offer:edit")
    @Log(title = "用户offer", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserOffer tbUserOffer)
    {
        return toAjax(tbUserOfferService.updateTbUserOffer(tbUserOffer));
    }

    /**
     * 删除用户offer
     */
    @RequiresPermissions("system:offer:remove")
    @Log(title = "用户offer", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserOfferService.deleteTbUserOfferByIds(ids));
    }

    /**
     * 根据用户id查询申请信息
     */
    @RequiresPermissions("system:offer:list")
    @Log(title = "查询用户申请", businessType = BusinessType.QUERY)
    @GetMapping( "/queryApplyByUserId")
    @ResponseBody
    public List<UserApplyRes> queryApplyByUserId(String userId)
    {
        TbUserDetailInfo detailInfo=new TbUserDetailInfo();
        if(DataUtils.isIdCard(userId)){
            detailInfo.setIdCard(userId);
        }else if(DataUtils.isPhone(userId)){
            detailInfo.setMobilephone(userId);
        }else{
            detailInfo.setPassportNumber(userId);
        }
        List<TbUserDetailInfo> userDetailInfoList=tbUserDetailInfoService.selectTbUserDetailInfoList(detailInfo);
        if(ObjectUtils.isNotEmpty(userDetailInfoList) && !userDetailInfoList.isEmpty()){
            TbUserApply tbUserApply=new TbUserApply();
            tbUserApply.setApplyStatus(ApplyStatusEnum.pay_ok.getStatus());
            tbUserApply.setUserId(userDetailInfoList.get(0).getUserid());
            List<UserApplyRes> list=tbUserApplyInfoService.selectTbUserApplyInfoList(tbUserApply);
            if(null == list){
                return new ArrayList<UserApplyRes>();
            }
            return list;
        }else{
            return new ArrayList<UserApplyRes>();
        }
    }
}
