package com.ruoyi.web.controller.apply;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserParentInfo;
import com.ruoyi.system.service.ITbUserParentInfoService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户父母信息Controller
 * 
 * @author ruoyi
 * @date 2023-01-05
 */
@Controller
@RequestMapping("/system/parent")
public class TbUserParentInfoController extends BaseController
{
    private String prefix = "business/parent";

    @Autowired
    private ITbUserParentInfoService tbUserParentInfoService;

    @RequiresPermissions("system:parent:view")
    @GetMapping()
    public String info()
    {
        return prefix + "/parent";
    }

    /**
     * 查询用户父母信息列表
     */
    @RequiresPermissions("system:parent:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserParentInfo tbUserParentInfo)
    {
        startPage();
        List<TbUserParentInfo> list = tbUserParentInfoService.selectTbUserParentInfoList(tbUserParentInfo);
        return getDataTable(list);
    }

    /**
     * 导出用户父母信息列表
     */
    @RequiresPermissions("system:parent:export")
    @Log(title = "用户父母信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUserParentInfo tbUserParentInfo)
    {
        List<TbUserParentInfo> list = tbUserParentInfoService.selectTbUserParentInfoList(tbUserParentInfo);
        ExcelUtil<TbUserParentInfo> util = new ExcelUtil<TbUserParentInfo>(TbUserParentInfo.class);
        return util.exportExcel(list, "用户父母信息数据");
    }

    /**
     * 新增用户父母信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户父母信息
     */
    @RequiresPermissions("system:parent:add")
    @Log(title = "用户父母信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserParentInfo tbUserParentInfo)
    {
        return toAjax(tbUserParentInfoService.insertTbUserParentInfo(tbUserParentInfo));
    }

    /**
     * 修改用户父母信息
     */
    @RequiresPermissions("system:parent:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserParentInfo tbUserParentInfo = tbUserParentInfoService.selectTbUserParentInfoById(id);
        mmap.put("tbUserParentInfo", tbUserParentInfo);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户父母信息
     */
    @RequiresPermissions("system:parent:edit")
    @Log(title = "用户父母信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserParentInfo tbUserParentInfo)
    {
        return toAjax(tbUserParentInfoService.updateTbUserParentInfo(tbUserParentInfo));
    }

    /**
     * 删除用户父母信息
     */
    @RequiresPermissions("system:parent:remove")
    @Log(title = "用户父母信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserParentInfoService.deleteTbUserParentInfoByIds(ids));
    }
}
