package com.ruoyi.web.controller.apply;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUserWorkExperience;
import com.ruoyi.system.service.ITbUserWorkExperienceService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户工作经历Controller
 * 
 * @author ruoyi
 * @date 2023-01-05
 */
@Controller
@RequestMapping("/system/experience")
public class TbUserWorkExperienceController extends BaseController
{
    private String prefix = "business/work";

    @Autowired
    private ITbUserWorkExperienceService tbUserWorkExperienceService;

    @RequiresPermissions("system:experience:view")
    @GetMapping()
    public String experience()
    {
        return prefix + "/experience";
    }

    /**
     * 查询用户工作经历列表
     */
    @RequiresPermissions("system:experience:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUserWorkExperience tbUserWorkExperience)
    {
        startPage();
        List<TbUserWorkExperience> list = tbUserWorkExperienceService.selectTbUserWorkExperienceList(tbUserWorkExperience);
        return getDataTable(list);
    }

    /**
     * 导出用户工作经历列表
     */
    @RequiresPermissions("system:experience:export")
    @Log(title = "用户工作经历", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUserWorkExperience tbUserWorkExperience)
    {
        List<TbUserWorkExperience> list = tbUserWorkExperienceService.selectTbUserWorkExperienceList(tbUserWorkExperience);
        ExcelUtil<TbUserWorkExperience> util = new ExcelUtil<TbUserWorkExperience>(TbUserWorkExperience.class);
        return util.exportExcel(list, "用户工作经历数据");
    }

    /**
     * 新增用户工作经历
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户工作经历
     */
    @RequiresPermissions("system:experience:add")
    @Log(title = "用户工作经历", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUserWorkExperience tbUserWorkExperience)
    {
        return toAjax(tbUserWorkExperienceService.insertTbUserWorkExperience(tbUserWorkExperience));
    }

    /**
     * 修改用户工作经历
     */
    @RequiresPermissions("system:experience:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUserWorkExperience tbUserWorkExperience = tbUserWorkExperienceService.selectTbUserWorkExperienceById(id);
        mmap.put("tbUserWorkExperience", tbUserWorkExperience);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户工作经历
     */
    @RequiresPermissions("system:experience:edit")
    @Log(title = "用户工作经历", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUserWorkExperience tbUserWorkExperience)
    {
        return toAjax(tbUserWorkExperienceService.updateTbUserWorkExperience(tbUserWorkExperience));
    }

    /**
     * 删除用户工作经历
     */
    @RequiresPermissions("system:experience:remove")
    @Log(title = "用户工作经历", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserWorkExperienceService.deleteTbUserWorkExperienceByIds(ids));
    }
}
