package com.ruoyi.web.controller.business;

import java.util.List;

import com.ruoyi.common.utils.ShiroUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbConsultantChange;
import com.ruoyi.system.service.ITbConsultantChangeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 顾问变更申请Controller
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
@Controller
@RequestMapping("/business/change")
public class TbConsultantChangeController extends BaseController
{
    private String prefix = "business/change";

    @Autowired
    private ITbConsultantChangeService tbConsultantChangeService;

    @RequiresPermissions("business:change:view")
    @GetMapping()
    public String change()
    {
        return prefix + "/change";
    }

    /**
     * 查询顾问变更申请列表
     */
    @RequiresPermissions("business:change:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbConsultantChange tbConsultantChange)
    {
        tbConsultantChange.setChangeProposer(ShiroUtils.getUserId());
        startPage();
        List<TbConsultantChange> list = tbConsultantChangeService.selectTbConsultantChangeList(tbConsultantChange);
        return getDataTable(list);
    }

    /**
     * 导出顾问变更申请列表
     */
    @RequiresPermissions("business:change:export")
    @Log(title = "顾问变更申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbConsultantChange tbConsultantChange)
    {
        List<TbConsultantChange> list = tbConsultantChangeService.selectTbConsultantChangeList(tbConsultantChange);
        ExcelUtil<TbConsultantChange> util = new ExcelUtil<TbConsultantChange>(TbConsultantChange.class);
        return util.exportExcel(list, "顾问变更申请数据");
    }

    /**
     * 新增顾问变更申请
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存顾问变更申请
     */
    @RequiresPermissions("business:change:add")
    @Log(title = "顾问变更申请", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbConsultantChange tbConsultantChange)
    {
        return toAjax(tbConsultantChangeService.insertTbConsultantChange(tbConsultantChange));
    }

    /**
     * 修改顾问变更申请
     */
    @RequiresPermissions("business:change:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbConsultantChange tbConsultantChange = tbConsultantChangeService.selectTbConsultantChangeById(id);
        mmap.put("tbConsultantChange", tbConsultantChange);
        return prefix + "/edit";
    }

    /**
     * 修改保存顾问变更申请
     */
    @RequiresPermissions("business:change:edit")
    @Log(title = "顾问变更申请", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbConsultantChange tbConsultantChange)
    {
        return toAjax(tbConsultantChangeService.updateTbConsultantChange(tbConsultantChange));
    }

    /**
     * 删除顾问变更申请
     */
    @RequiresPermissions("business:change:remove")
    @Log(title = "顾问变更申请", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbConsultantChangeService.deleteTbConsultantChangeByIds(ids));
    }

}
