package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbConsultant;
import com.ruoyi.system.service.ITbConsultantService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 顾问Controller
 * 
 * @author ruoyi
 * @date 2023-05-19
 */
@Controller
@RequestMapping("/business/consultant")
public class TbConsultantController extends BaseController
{
    private String prefix = "business/consultant";

    @Autowired
    private ITbConsultantService tbConsultantService;

    @RequiresPermissions("business:consultant:view")
    @GetMapping()
    public String consultant()
    {
        return prefix + "/consultant";
    }

    /**
     * 查询顾问列表
     */
    @RequiresPermissions("business:consultant:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbConsultant tbConsultant)
    {
        startPage();
        List<TbConsultant> list = tbConsultantService.selectTbConsultantList(tbConsultant);
        return getDataTable(list);
    }

    /**
     * 查询顾问列表
     */
    @GetMapping("/all")
    @ResponseBody
    public List<TbConsultant> list()
    {
        List<TbConsultant> list = tbConsultantService.selectTbConsultantList(new TbConsultant());
        return list;
    }

    /**
     * 导出顾问列表
     */
    @RequiresPermissions("business:consultant:export")
    @Log(title = "顾问", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbConsultant tbConsultant)
    {
        List<TbConsultant> list = tbConsultantService.selectTbConsultantList(tbConsultant);
        ExcelUtil<TbConsultant> util = new ExcelUtil<TbConsultant>(TbConsultant.class);
        return util.exportExcel(list, "顾问数据");
    }

    /**
     * 新增顾问
     */
    @GetMapping("/add")
    public String add(ModelMap mmap)
    {
        TbConsultant consultant=new TbConsultant();
        mmap.put("consultant",consultant);
        return prefix + "/add";
    }

    /**
     * 新增保存顾问
     */
    @RequiresPermissions("business:consultant:add")
    @Log(title = "顾问", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbConsultant tbConsultant)
    {
        return toAjax(tbConsultantService.insertTbConsultant(tbConsultant));
    }

    /**
     * 修改顾问
     */
    @RequiresPermissions("business:consultant:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbConsultant tbConsultant = tbConsultantService.selectTbConsultantById(id);
        mmap.put("tbConsultant", tbConsultant);
        return prefix + "/edit";
    }

    /**
     * 修改保存顾问
     */
    @RequiresPermissions("business:consultant:edit")
    @Log(title = "顾问", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbConsultant tbConsultant)
    {
        return toAjax(tbConsultantService.updateTbConsultant(tbConsultant));
    }

    /**
     * @Author : fanxiaolong
     * @Description : 删除顾问
     * @DateTime : 2023/5/22 10:52
     * @param : ids
     * @return : com.ruoyi.common.core.domain.AjaxResult
     */
    @RequiresPermissions("business:consultant:remove")
    @Log(title = "顾问", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {

        return toAjax(tbConsultantService.deleteTbConsultantByIds(ids));
    }

    /**
     * @Author : fanxiaolong
     * @Description : 上传微信二维码图片
     * @DateTime : 2023/5/19 17:15
     * @param : mmap
     * @return : java.lang.String
     */
    @GetMapping("/uploadQRImage")
    public String uploadQRImage(ModelMap mmap)
    {

        TbConsultant consultant=new TbConsultant();
        mmap.put("consultant",consultant);
        return prefix + "/uploadQRImage";
    }
}
