package com.ruoyi.web.controller.business;

import java.util.List;
import com.alibaba.fastjson.JSONArray;
import com.ruoyi.system.res.CustomerserviceRecordRes;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbCustomerserviceRecord;
import com.ruoyi.system.service.ITbCustomerserviceRecordService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import javax.servlet.http.HttpServletRequest;

/**
 * 客服聊天记录Controller
 * 
 * @author ruoyi
 * @date 2023-05-11
 */
@Controller
@RequestMapping("/business/chatRecord")
public class TbCustomerserviceRecordController extends BaseController
{
    private String prefix = "business/chatRecord";

    @Autowired
    private ITbCustomerserviceRecordService tbCustomerserviceRecordService;

    @RequiresPermissions("business:chatRecord:view")
    @GetMapping("/customer")
    public String chatRecord()
    {
//        return prefix + "/chatRecord";
        return prefix + "/customer";
    }

    /**
     * 查询客服聊天记录列表
     */
    @RequiresPermissions("business:chatRecord:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbCustomerserviceRecord tbCustomerserviceRecord)
    {
        startPage();
        List<TbCustomerserviceRecord> list = tbCustomerserviceRecordService.selectTbCustomerserviceRecordList(tbCustomerserviceRecord);
        return getDataTable(list);
    }

    /**
     * 查询客服聊天记录列表
     */
//    @RequiresPermissions("business:chatRecord:list")
    @GetMapping("/list/{userid}")
    @ResponseBody
    public String list(@PathVariable("userid") String userid, HttpServletRequest request)
    {
        startPage();
        List<CustomerserviceRecordRes> list = tbCustomerserviceRecordService.queryListByUserid(userid);
//        return list.get(0);
//        return list;
        String callback = request.getParameter("callback");
        JSONArray jsonArray=new JSONArray();
//        int i=0;
//        while(i>0){
//            jsonArray.add(list.get(i-1));
//            i--;
//        }
        for(int i=0;i<list.size();i++){
            jsonArray.add(i,list.get(i));
        }
        return callback + "(" + jsonArray.toString() + ")";
    }

    /**
     * 导出客服聊天记录列表
     */
    @RequiresPermissions("business:chatRecord:export")
    @Log(title = "客服聊天记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbCustomerserviceRecord tbCustomerserviceRecord)
    {
        List<TbCustomerserviceRecord> list = tbCustomerserviceRecordService.selectTbCustomerserviceRecordList(tbCustomerserviceRecord);
        ExcelUtil<TbCustomerserviceRecord> util = new ExcelUtil<TbCustomerserviceRecord>(TbCustomerserviceRecord.class);
        return util.exportExcel(list, "客服聊天记录数据");
    }

    /**
     * 新增客服聊天记录
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存客服聊天记录
     */
    @RequiresPermissions("business:chatRecord:add")
    @Log(title = "客服聊天记录", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbCustomerserviceRecord tbCustomerserviceRecord)
    {
        return toAjax(tbCustomerserviceRecordService.insertTbCustomerserviceRecord(tbCustomerserviceRecord));
    }

    /**
     * 修改客服聊天记录
     */
    @RequiresPermissions("business:chatRecord:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbCustomerserviceRecord tbCustomerserviceRecord = tbCustomerserviceRecordService.selectTbCustomerserviceRecordById(id);
        mmap.put("tbCustomerserviceRecord", tbCustomerserviceRecord);
        return prefix + "/edit";
    }

    /**
     * 修改保存客服聊天记录
     */
    @RequiresPermissions("business:chatRecord:edit")
    @Log(title = "客服聊天记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbCustomerserviceRecord tbCustomerserviceRecord)
    {
        return toAjax(tbCustomerserviceRecordService.updateTbCustomerserviceRecord(tbCustomerserviceRecord));
    }

    /**
     * 删除客服聊天记录
     */
    @RequiresPermissions("business:chatRecord:remove")
    @Log(title = "客服聊天记录", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbCustomerserviceRecordService.deleteTbCustomerserviceRecordByIds(ids));
    }
}
