package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbHomepage;
import com.ruoyi.system.service.ITbHomepageService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 首页文案，bannerController
 * 
 * @author ruoyi
 * @date 2023-06-06
 */
@Controller
@RequestMapping("/business/homepage")
public class TbHomepageController extends BaseController
{
    private String prefix = "business/homepage";

    @Autowired
    private ITbHomepageService tbHomepageService;

    @RequiresPermissions("business:homepage:view")
    @GetMapping()
    public String homepage()
    {
        return prefix + "/homepage";
    }

    /**
     * 查询首页文案，banner列表
     */
    @RequiresPermissions("business:homepage:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbHomepage tbHomepage)
    {
        startPage();
        List<TbHomepage> list = tbHomepageService.selectTbHomepageList(tbHomepage);
        return getDataTable(list);
    }

    /**
     * 导出首页文案，banner列表
     */
    @RequiresPermissions("business:homepage:export")
    @Log(title = "首页文案，banner", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbHomepage tbHomepage)
    {
        List<TbHomepage> list = tbHomepageService.selectTbHomepageList(tbHomepage);
        ExcelUtil<TbHomepage> util = new ExcelUtil<TbHomepage>(TbHomepage.class);
        return util.exportExcel(list, "首页文案，banner数据");
    }

    @GetMapping("/uploadBanner1")
    public String uploadBanner1(ModelMap modelMap){
        TbHomepage homepage=new TbHomepage();
        modelMap.put("homepage",homepage);
        return prefix + "/uploadBanner1";
    }

    @GetMapping("/uploadBanner2")
    public String uploadBanner2(ModelMap modelMap){
        TbHomepage homepage=new TbHomepage();
        modelMap.put("homepage",homepage);
        return prefix + "/uploadBanner2";
    }

    @GetMapping("/uploadService")
    public String uploadService(ModelMap modelMap){
        TbHomepage homepage=new TbHomepage();
        modelMap.put("homepage",homepage);
        return prefix + "/uploadService";
    }
    @GetMapping("/uploadSchool")
    public String uploadSchool(ModelMap modelMap){
        TbHomepage homepage=new TbHomepage();
        modelMap.put("homepage",homepage);
        return prefix + "/uploadSchool";
    }
    @GetMapping("/uploadMajor")
    public String uploadMajor(ModelMap modelMap){
        TbHomepage homepage=new TbHomepage();
        modelMap.put("homepage",homepage);
        return prefix + "/uploadMajor";
    }
    @GetMapping("/uploadMaterial")
    public String uploadMaterial(ModelMap modelMap){
        TbHomepage homepage=new TbHomepage();
        modelMap.put("homepage",homepage);
        return prefix + "/uploadMaterial";
    }

    /**
     * 新增首页文案，banner
     */
    @GetMapping("/add")
    public String add(ModelMap mmap)
    {
        TbHomepage homepage=new TbHomepage();
        mmap.put("homepage",homepage);
        return prefix + "/add";
    }

    /**
     * 新增保存首页文案，banner
     */
    @RequiresPermissions("business:homepage:add")
    @Log(title = "首页文案，banner", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbHomepage tbHomepage)
    {
        return toAjax(tbHomepageService.insertTbHomepage(tbHomepage));
    }

    /**
     * 修改首页文案，banner
     */
    @RequiresPermissions("business:homepage:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbHomepage tbHomepage = tbHomepageService.selectTbHomepageById(id);
        mmap.put("tbHomepage", tbHomepage);
        return prefix + "/edit";
    }

    /**
     * 修改保存首页文案，banner
     */
    @RequiresPermissions("business:homepage:edit")
    @Log(title = "首页文案，banner", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbHomepage tbHomepage)
    {
        return toAjax(tbHomepageService.updateTbHomepage(tbHomepage));
    }

    /**
     * 删除首页文案，banner
     */
    @RequiresPermissions("business:homepage:remove")
    @Log(title = "首页文案，banner", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbHomepageService.deleteTbHomepageByIds(ids));
    }
}
