package com.ruoyi.web.controller.business;

import java.util.List;

import com.ruoyi.system.domain.TbNews;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbInformationPlatform;
import com.ruoyi.system.service.ITbInformationPlatformService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 海外国家人文，交通，饮食信息Controller
 * 
 * @author ruoyi
 * @date 2024-02-29
 */
@Controller
@RequestMapping("/system/platform")
public class TbInformationPlatformController extends BaseController
{
    private String prefix = "business/platform";

    @Autowired
    private ITbInformationPlatformService tbInformationPlatformService;

    @RequiresPermissions("system:platform:view")
    @GetMapping()
    public String platform()
    {
        return prefix + "/platform";
    }

    /**
     * 查询海外国家人文，交通，饮食信息列表
     */
    @RequiresPermissions("system:platform:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbInformationPlatform tbInformationPlatform)
    {
        startPage();
        List<TbInformationPlatform> list = tbInformationPlatformService.selectTbInformationPlatformList(tbInformationPlatform);
        return getDataTable(list);
    }

    /**
     * 导出海外国家人文，交通，饮食信息列表
     */
    @RequiresPermissions("system:platform:export")
    @Log(title = "海外国家人文，交通，饮食信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbInformationPlatform tbInformationPlatform)
    {
        List<TbInformationPlatform> list = tbInformationPlatformService.selectTbInformationPlatformList(tbInformationPlatform);
        ExcelUtil<TbInformationPlatform> util = new ExcelUtil<TbInformationPlatform>(TbInformationPlatform.class);
        return util.exportExcel(list, "海外国家人文，交通，饮食信息数据");
    }

    /**
     * 新增海外国家人文，交通，饮食信息
     */
    @GetMapping("/add")
    public String add(ModelMap mmap)
    {
        TbInformationPlatform platform=new TbInformationPlatform();
        mmap.put("platform",platform);
        return prefix + "/add";
    }

    @GetMapping("/uploadCover")
    public String uploadImages(ModelMap mmap)
    {
        TbInformationPlatform platform=new TbInformationPlatform();
        mmap.put("platform",platform);
        return prefix + "/uploadPlatformCover";
    }

    /**
     * 新增保存海外国家人文，交通，饮食信息
     */
    @RequiresPermissions("system:platform:add")
    @Log(title = "海外国家人文，交通，饮食信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbInformationPlatform tbInformationPlatform)
    {
        tbInformationPlatform.setCreator(getUserId());
        return toAjax(tbInformationPlatformService.insertTbInformationPlatform(tbInformationPlatform));
    }

    /**
     * 修改海外国家人文，交通，饮食信息
     */
    @RequiresPermissions("system:platform:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbInformationPlatform tbInformationPlatform = tbInformationPlatformService.selectTbInformationPlatformById(id);
        mmap.put("tbInformationPlatform", tbInformationPlatform);
        return prefix + "/edit";
    }

    /**
     * 修改保存海外国家人文，交通，饮食信息
     */
    @RequiresPermissions("system:platform:edit")
    @Log(title = "海外国家人文，交通，饮食信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbInformationPlatform tbInformationPlatform)
    {
        return toAjax(tbInformationPlatformService.updateTbInformationPlatform(tbInformationPlatform));
    }

    /**
     * 删除海外国家人文，交通，饮食信息
     */
    @RequiresPermissions("system:platform:remove")
    @Log(title = "海外国家人文，交通，饮食信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbInformationPlatformService.deleteTbInformationPlatformByIds(ids));
    }
}
