package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbLivingExpense;
import com.ruoyi.system.service.ITbLivingExpenseService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 生活成本Controller
 * 
 * @author Fan xiaolong
 * @date 2025-04-03
 */
@Controller
@RequestMapping("/business/expense")
public class TbLivingExpenseController extends BaseController
{
    private String prefix = "system/expense";

    @Autowired
    private ITbLivingExpenseService tbLivingExpenseService;

    @RequiresPermissions("business:expense:view")
    @GetMapping()
    public String expense()
    {
        return prefix + "/expense";
    }

    /**
     * 查询生活成本列表
     */
    @RequiresPermissions("business:expense:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbLivingExpense tbLivingExpense)
    {
        startPage();
        List<TbLivingExpense> list = tbLivingExpenseService.selectTbLivingExpenseList(tbLivingExpense);
        return getDataTable(list);
    }

    /**
     * 导出生活成本列表
     */
    @RequiresPermissions("business:expense:export")
    @Log(title = "生活成本", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbLivingExpense tbLivingExpense)
    {
        List<TbLivingExpense> list = tbLivingExpenseService.selectTbLivingExpenseList(tbLivingExpense);
        ExcelUtil<TbLivingExpense> util = new ExcelUtil<TbLivingExpense>(TbLivingExpense.class);
        return util.exportExcel(list, "生活成本数据");
    }

    /**
     * 新增生活成本
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存生活成本
     */
    @RequiresPermissions("business:expense:add")
    @Log(title = "生活成本", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbLivingExpense tbLivingExpense)
    {
        return toAjax(tbLivingExpenseService.insertTbLivingExpense(tbLivingExpense));
    }

    /**
     * 修改生活成本
     */
    @RequiresPermissions("business:expense:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbLivingExpense tbLivingExpense = tbLivingExpenseService.selectTbLivingExpenseById(id);
        mmap.put("tbLivingExpense", tbLivingExpense);
        return prefix + "/edit";
    }

    /**
     * 修改保存生活成本
     */
    @RequiresPermissions("business:expense:edit")
    @Log(title = "生活成本", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbLivingExpense tbLivingExpense)
    {
        return toAjax(tbLivingExpenseService.updateTbLivingExpense(tbLivingExpense));
    }

    /**
     * 删除生活成本
     */
    @RequiresPermissions("business:expense:remove")
    @Log(title = "生活成本", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbLivingExpenseService.deleteTbLivingExpenseByIds(ids));
    }
}
