package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbPrivacyAndLegal;
import com.ruoyi.system.service.ITbPrivacyAndLegalService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 隐私及法律条款Controller
 * 
 * @author ruoyi
 * @date 2023-05-17
 */
@Controller
@RequestMapping("/business/legal")
public class TbPrivacyAndLegalController extends BaseController
{
    private String prefix = "business/legal";

    @Autowired
    private ITbPrivacyAndLegalService tbPrivacyAndLegalService;

    @RequiresPermissions("business:legal:view")
    @GetMapping()
    public String legal()
    {
        return prefix + "/legal";
    }

    /**
     * 查询隐私及法律条款列表
     */
    @RequiresPermissions("business:legal:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbPrivacyAndLegal tbPrivacyAndLegal)
    {
        startPage();
        List<TbPrivacyAndLegal> list = tbPrivacyAndLegalService.selectTbPrivacyAndLegalList(tbPrivacyAndLegal);
        return getDataTable(list);
    }

    /**
     * 导出隐私及法律条款列表
     */
    @RequiresPermissions("business:legal:export")
    @Log(title = "隐私及法律条款", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbPrivacyAndLegal tbPrivacyAndLegal)
    {
        List<TbPrivacyAndLegal> list = tbPrivacyAndLegalService.selectTbPrivacyAndLegalList(tbPrivacyAndLegal);
        ExcelUtil<TbPrivacyAndLegal> util = new ExcelUtil<TbPrivacyAndLegal>(TbPrivacyAndLegal.class);
        return util.exportExcel(list, "隐私及法律条款数据");
    }

    /**
     * 新增隐私及法律条款
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存隐私及法律条款
     */
    @RequiresPermissions("business:legal:add")
    @Log(title = "隐私及法律条款", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbPrivacyAndLegal tbPrivacyAndLegal)
    {
        return toAjax(tbPrivacyAndLegalService.insertTbPrivacyAndLegal(tbPrivacyAndLegal));
    }

    /**
     * 修改隐私及法律条款
     */
    @RequiresPermissions("business:legal:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbPrivacyAndLegal tbPrivacyAndLegal = tbPrivacyAndLegalService.selectTbPrivacyAndLegalById(id);
        mmap.put("tbPrivacyAndLegal", tbPrivacyAndLegal);
        return prefix + "/edit";
    }

    /**
     * 修改保存隐私及法律条款
     */
    @RequiresPermissions("business:legal:edit")
    @Log(title = "隐私及法律条款", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbPrivacyAndLegal tbPrivacyAndLegal)
    {
        return toAjax(tbPrivacyAndLegalService.updateTbPrivacyAndLegal(tbPrivacyAndLegal));
    }

    /**
     * 删除隐私及法律条款
     */
    @RequiresPermissions("business:legal:remove")
    @Log(title = "隐私及法律条款", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbPrivacyAndLegalService.deleteTbPrivacyAndLegalByIds(ids));
    }
}
