package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbUseHelp;
import com.ruoyi.system.service.ITbUseHelpService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 使用帮助Controller
 * 
 * @author ruoyi
 * @date 2023-05-17
 */
@Controller
@RequestMapping("/business/help")
public class TbUseHelpController extends BaseController
{
    private String prefix = "business/help";

    @Autowired
    private ITbUseHelpService tbUseHelpService;

    @RequiresPermissions("business:help:view")
    @GetMapping()
    public String help()
    {
        return prefix + "/help";
    }

    /**
     * 查询使用帮助列表
     */
    @RequiresPermissions("business:help:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUseHelp tbUseHelp)
    {
        startPage();
        List<TbUseHelp> list = tbUseHelpService.selectTbUseHelpList(tbUseHelp);
        return getDataTable(list);
    }

    /**
     * 导出使用帮助列表
     */
    @RequiresPermissions("business:help:export")
    @Log(title = "使用帮助", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUseHelp tbUseHelp)
    {
        List<TbUseHelp> list = tbUseHelpService.selectTbUseHelpList(tbUseHelp);
        ExcelUtil<TbUseHelp> util = new ExcelUtil<TbUseHelp>(TbUseHelp.class);
        return util.exportExcel(list, "使用帮助数据");
    }

    /**
     * 新增使用帮助
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存使用帮助
     */
    @RequiresPermissions("business:help:add")
    @Log(title = "使用帮助", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUseHelp tbUseHelp)
    {
        return toAjax(tbUseHelpService.insertTbUseHelp(tbUseHelp));
    }

    /**
     * 修改使用帮助
     */
    @RequiresPermissions("business:help:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbUseHelp tbUseHelp = tbUseHelpService.selectTbUseHelpById(id);
        mmap.put("tbUseHelp", tbUseHelp);
        return prefix + "/edit";
    }

    /**
     * 修改保存使用帮助
     */
    @RequiresPermissions("business:help:edit")
    @Log(title = "使用帮助", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUseHelp tbUseHelp)
    {
        return toAjax(tbUseHelpService.updateTbUseHelp(tbUseHelp));
    }

    /**
     * 删除使用帮助
     */
    @RequiresPermissions("business:help:remove")
    @Log(title = "使用帮助", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUseHelpService.deleteTbUseHelpByIds(ids));
    }
}
