package com.ruoyi.web.controller.common;

import java.awt.image.BufferedImage;
import java.util.ArrayList;
import java.util.List;
import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.system.domain.TbRegion;
import com.ruoyi.system.service.impl.CommonServiceImpl;
import net.coobird.thumbnailator.Thumbnails;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.config.ServerConfig;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;


/**
 * 通用请求处理
 * 
 * @author ruoyi
 */
@Controller
@RequestMapping("/common")
public class CommonController
{
    private static final Logger log = LoggerFactory.getLogger(CommonController.class);

    @Autowired
    private ServerConfig serverConfig;

    private static final String FILE_DELIMETER = ",";

    @Autowired
    private CommonServiceImpl commonService;

    /**
     * 通用下载请求
     * 
     * @param fileName 文件名称
     * @param delete 是否删除
     */
    @GetMapping("/download")
    public void fileDownload(String fileName, Boolean delete, HttpServletResponse response, HttpServletRequest request)
    {
        try
        {
            if (!FileUtils.checkAllowDownload(fileName))
            {
                throw new Exception(StringUtils.format("文件名称({})非法，不允许下载。 ", fileName));
            }
            String realFileName = System.currentTimeMillis() + fileName.substring(fileName.indexOf("_") + 1);
            String filePath = RuoYiConfig.getDownloadPath() + fileName;

            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, realFileName);
            FileUtils.writeBytes(filePath, response.getOutputStream());
            if (delete)
            {
                FileUtils.deleteFile(filePath);
            }
        }
        catch (Exception e)
        {
            log.error("下载文件失败", e);
        }
    }

    /**
     * 通用上传请求（单个）
     */
    @PostMapping("/upload")
    @ResponseBody
    public AjaxResult uploadFile(MultipartFile file)
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileName);
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return ajax;
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }

    /**
     * 通用上传请求（多个）
     */
    @PostMapping("/uploads")
    @ResponseBody
    public AjaxResult uploadFiles(List<MultipartFile> files) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            List<String> urls = new ArrayList<String>();
            List<String> fileNames = new ArrayList<String>();
            List<String> newFileNames = new ArrayList<String>();
            List<String> originalFilenames = new ArrayList<String>();
            for (MultipartFile file : files)
            {
                // 上传并返回新文件名称
                String fileName = FileUploadUtils.upload(filePath, file);
                String url = serverConfig.getUrl() + fileName;
                urls.add(url);
                fileNames.add(fileName);
                newFileNames.add(FileUtils.getName(fileName));
                originalFilenames.add(file.getOriginalFilename());
            }
            AjaxResult ajax = AjaxResult.success();
            ajax.put("urls", StringUtils.join(urls, FILE_DELIMETER));
            ajax.put("fileNames", StringUtils.join(fileNames, FILE_DELIMETER));
            ajax.put("newFileNames", StringUtils.join(newFileNames, FILE_DELIMETER));
            ajax.put("originalFilenames", StringUtils.join(originalFilenames, FILE_DELIMETER));
            return ajax;
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }

    /**
     * 上传学校封面
     */
    @PostMapping("/uploadSchoolCover")
    @ResponseBody
    public AjaxResult uploadSchoolCover(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String fileFullPath=filePath+fileName.substring(fileName.indexOf("/upload/")+7);
//            //scale 图片的压缩比例 值在0-1之间，1f就是原图，0.5就是原图的一半大小
//            //outputQuality 图片压缩的质量 值在0-1 之间，越接近1质量越好，越接近0 质量越差
//            Thumbnails.of(fileFullPath).scale(0.25f).outputQuality(0.8f).toFile(thumbnailsName);
//            Thumbnails.of(fileFullPath).scale(0.5f).outputQuality(0.8f).toFile(thumbnailsName1);
            //生成专业列表页面 520 * 500
            String majorPage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/majorPage_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(520,500).keepAspectRatio(false).toFile(majorPage);
            String majorPageRelativePath=majorPage.replace(filePath,Constants.RESOURCE_PREFIX1);

            //生成学校列表页面 340 * 200
            String schoolPage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/schoolPage_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(340,200).keepAspectRatio(false).toFile(schoolPage);
            String schoolPageRelativePath=schoolPage.replace(filePath,Constants.RESOURCE_PREFIX1);

            //首页模糊查询页面 452 * 197
            String homePage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/homePage_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(452,197).keepAspectRatio(false).toFile(homePage);
            String homePageRelativePath=homePage.replace(filePath,Constants.RESOURCE_PREFIX1);

            StringBuffer fileNames=new StringBuffer();
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileNames.append(fileName).append(",").
                    append(majorPageRelativePath).append(",").
                    append(schoolPageRelativePath).append(",").
                    append(homePageRelativePath).toString()
            );
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return ajax;
        }
        catch (Exception e)
        {
            System.out.println(e.getMessage());
            return AjaxResult.error(e.getMessage());
        }


//        try
//        {
//            // 上传文件路径
//            String filePath = RuoYiConfig.getUploadPath();
//            TbSchool tbSchool1=new TbSchool();
//            List<TbSchool> tbSchools = tbSchoolService.selectTbSchoolList(tbSchool1);
//            for(TbSchool tbSchool : tbSchools){
//                if(ObjectUtils.isNotEmpty(tbSchool.getSchoolCover())){
//                    String fileName = tbSchool.getSchoolCover();
//                    String suffix=fileName.substring(fileName.lastIndexOf("."));
//                    String fileFullPath=filePath+fileName.substring(fileName.indexOf("/upload/")+7);
//                    String majorPage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
//                            "/majorPage_"+FileUtils.getName(fileName).substring(0,FileUtils.getName(fileName).lastIndexOf("."));
//                    Thumbnails.of(fileFullPath).size(520,500).keepAspectRatio(false).toFile(majorPage);
//                    String schoolPage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
//                            "/schoolPage_"+FileUtils.getName(fileName).substring(0,FileUtils.getName(fileName).lastIndexOf("."));
//                    Thumbnails.of(fileFullPath).size(340,200).keepAspectRatio(false).toFile(schoolPage);
//                    String homePage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
//                            "/homePage_"+FileUtils.getName(fileName).substring(0,FileUtils.getName(fileName).lastIndexOf("."));
//                    Thumbnails.of(fileFullPath).size(452,197).keepAspectRatio(false).toFile(homePage);
//                    log.info(">>>>>>>>>>>\n"+fileFullPath+"\n"+majorPage+suffix+"\n"+schoolPage+suffix+"\n"+homePage+suffix);
//                    TbSchool tbSchool2=new TbSchool();
//                    tbSchool2.setId(tbSchool.getId());
//                    tbSchool2.setMajorPage(majorPage+suffix);
//                    tbSchool2.setSchoolPage(schoolPage+suffix);
//                    tbSchool2.setHomePage(homePage+suffix);
//                    tbSchoolService.updateTbSchool(tbSchool2);
//                }
//            }
//            AjaxResult ajax = AjaxResult.success();
//            return ajax;
//        }
//        catch (Exception e)
//        {
//            return AjaxResult.error(e.getMessage());
//        }
    }

    /**
     * 上传图册封面
     */
    @PostMapping("/uploadAtlasCover")
    @ResponseBody
    public AjaxResult uploadAtlasCover(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String fileFullPath=filePath+fileName.substring(fileName.indexOf("/upload/")+7);
            //院校主页，校园图册页面封面大小 444 * 271
            String atlas1=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/atlas1_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(444,271).keepAspectRatio(false).toFile(atlas1);
            String relativeAtlas1=atlas1.replace(filePath,Constants.RESOURCE_PREFIX1);

            //院校图库页面封面大小 300 * 200
            String atlas2=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/atlas2_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(300,200).keepAspectRatio(false).toFile(atlas2);
            String relativeAtlas2=atlas2.replace(filePath,Constants.RESOURCE_PREFIX1);

            StringBuffer fileNames=new StringBuffer();
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileNames.append(fileName).append(",").
                    append(relativeAtlas1).append(",").
                    append(relativeAtlas2).append(",").toString());
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return ajax;
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }


//        try
//        {
//            // 上传文件路径
//            String filePath = RuoYiConfig.getUploadPath();
//            TbSchool tbSchool1=new TbSchool();
//            List<TbSchool> tbSchools = tbSchoolService.selectTbSchoolList(tbSchool1);
//            for(TbSchool tbSchool : tbSchools){
//                if(ObjectUtils.isNotEmpty(tbSchool.getSchoolCover())){
//                    String fileName = tbSchool.getSchoolCover();
//                    String suffix=fileName.substring(fileName.lastIndexOf("."));
//                    String fileFullPath=filePath+fileName.substring(fileName.indexOf("/upload/")+7);
//                    String majorPage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
//                            "/majorPage_"+FileUtils.getName(fileName).substring(0,FileUtils.getName(fileName).lastIndexOf("."));
//                    Thumbnails.of(fileFullPath).size(520,500).keepAspectRatio(false).toFile(majorPage);
//                    String schoolPage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
//                            "/schoolPage_"+FileUtils.getName(fileName).substring(0,FileUtils.getName(fileName).lastIndexOf("."));
//                    Thumbnails.of(fileFullPath).size(340,200).keepAspectRatio(false).toFile(schoolPage);
//                    String homePage=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
//                            "/homePage_"+FileUtils.getName(fileName).substring(0,FileUtils.getName(fileName).lastIndexOf("."));
//                    Thumbnails.of(fileFullPath).size(452,197).keepAspectRatio(false).toFile(homePage);
//                    log.info(">>>>>>>>>>>\n"+fileFullPath+"\n"+majorPage+suffix+"\n"+schoolPage+suffix+"\n"+homePage+suffix);
//                    TbSchool tbSchool2=new TbSchool();
//                    tbSchool2.setId(tbSchool.getId());
//                    tbSchool2.setMajorPage(majorPage+suffix);
//                    tbSchool2.setSchoolPage(schoolPage+suffix);
//                    tbSchool2.setHomePage(homePage+suffix);
//                    tbSchoolService.updateTbSchool(tbSchool2);
//                }
//            }
//            AjaxResult ajax = AjaxResult.success();
//            return ajax;
//        }
//        catch (Exception e)
//        {
//            return AjaxResult.error(e.getMessage());
//        }
    }

    /**
     * 上传学校材料封面
     */
    @PostMapping("/uploadMaterialCover")
    @ResponseBody
    public AjaxResult uploadMaterialCover(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String fileFullPath=filePath+fileName.substring(fileName.indexOf("/upload/")+7);
            //院校主页，校园图册页面封面大小 330 * 200
            String materialCover1=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/materialCover1_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(330,200).keepAspectRatio(false).toFile(materialCover1);

            StringBuffer fileNames=new StringBuffer();
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileNames.append(fileName).append(",").
                    append(materialCover1).append(",").toString());
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return ajax;
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }

    /**
     * 上传新闻封面
     */
    @PostMapping("/uploadNewsCover")
    @ResponseBody
    public AjaxResult uploadNewsCover(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getNewsPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String fileFullPath=filePath+fileName.substring(fileName.indexOf("/news/")+5);
            //封面1大小 608 * 380
            String newsCover1=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/newsCover1_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(608,380).keepAspectRatio(false).toFile(newsCover1);
            String relativePath1=newsCover1.replace(filePath,Constants.RESOURCE_PREFIX2);

            //封面2大小 456 * 324
            String newsCover2=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/newsCover2_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(456,324).keepAspectRatio(false).toFile(newsCover2);
            String relativePath2=newsCover2.replace(filePath,Constants.RESOURCE_PREFIX2);

            StringBuffer fileNames=new StringBuffer();
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileNames.append(fileName).append(",").
                    append(relativePath1).append(",").
                    append(relativePath2).toString())
            ;
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return ajax;
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }

    /**
     * 上传材料封面
     */
    @PostMapping("/uploadMaterialDemoCover")
    @ResponseBody
    public AjaxResult uploadMaterialDemoCover(MultipartFile file) throws Exception {
        try {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String fileFullPath = filePath + fileName.substring(fileName.indexOf("/upload/") + 7);
//            //scale 图片的压缩比例 值在0-1之间，1f就是原图，0.5就是原图的一半大小
//            //outputQuality 图片压缩的质量 值在0-1 之间，越接近1质量越好，越接近0 质量越差
//            Thumbnails.of(fileFullPath).scale(0.25f).outputQuality(0.8f).toFile(thumbnailsName);
//            Thumbnails.of(fileFullPath).scale(0.5f).outputQuality(0.8f).toFile(thumbnailsName1);
//            Thumbnails.of(fileFullPath).size(280, 380).keepAspectRatio(false).toFile(coverThumbnails);
            String coverThumbnails = fileFullPath.substring(0, fileFullPath.lastIndexOf("/")) +
                    "/thumbnails_" + FileUtils.getName(fileName);
            BufferedImage sourceImg = ImageIO.read(file.getInputStream());
            int width = sourceImg.getWidth();
            if(width<=280){
                coverThumbnails=fileFullPath;
            }else{
                float l= 280f / Float.parseFloat(String.valueOf(width));
                Thumbnails.of(fileFullPath).scale(l).outputQuality(0.8f).toFile(coverThumbnails);
            }
            String coverRelativePath = coverThumbnails.replace(filePath, Constants.RESOURCE_PREFIX1);
            StringBuffer fileNames = new StringBuffer();
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileNames.append(fileName).append(",").append(coverRelativePath).toString());
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return ajax;
        } catch (Exception e) {
            System.out.println("上传材料封面报错："+e.getMessage());
            return AjaxResult.error(e.getMessage());
        }
    }

    /**
     * 上传信息平台封面
     */
    @PostMapping("/uploadPlatformCover")
    @ResponseBody
    public AjaxResult uploadPlatformCover(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getInfoPlatformPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String fileFullPath=filePath+fileName.substring(fileName.indexOf("/info/")+5);
            //封面2大小 456 * 324
            String newsCover2=fileFullPath.substring(0,fileFullPath.lastIndexOf("/"))+
                    "/PlatformCover1_"+FileUtils.getName(fileName);
            Thumbnails.of(fileFullPath).size(456,324).keepAspectRatio(false).toFile(newsCover2);
            String relativePath2=newsCover2.replace(filePath,Constants.RESOURCE_PREFIX3);

            StringBuffer fileNames=new StringBuffer();
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", relativePath2);
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return ajax;
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }

    @RequestMapping("/del")
    @ResponseBody
    public AjaxResult del(){
        return AjaxResult.success();
    }

    /**
     * 本地资源通用下载
     */
    @GetMapping("/download/resource")
    public void resourceDownload(String resource, HttpServletRequest request, HttpServletResponse response)
            throws Exception
    {
        try
        {
            if (!FileUtils.checkAllowDownload(resource))
            {
                throw new Exception(StringUtils.format("资源文件({})非法，不允许下载。 ", resource));
            }
            // 本地资源路径
            String localPath = RuoYiConfig.getProfile();
            // 数据库资源地址
            String downloadPath = localPath + StringUtils.substringAfter(resource, Constants.RESOURCE_PREFIX);
            // 下载名称
            String downloadName = StringUtils.substringAfterLast(downloadPath, "/");
            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, downloadName);
            FileUtils.writeBytes(downloadPath, response.getOutputStream());
        }
        catch (Exception e)
        {
            log.error("下载文件失败", e);
        }
    }

    @GetMapping("/getDict/{dictType}")
    @ResponseBody
    public List<SysDictData> getDictList(@PathVariable String dictType){
        return DictUtils.getDictCache(dictType);
    }

    @GetMapping("/getCountryList")
    @ResponseBody
    public List<TbRegion> selectCountryList(){
        return commonService.selectCountryList();
    }

    @GetMapping("/getRegionByParentCode")
    @ResponseBody
    public List<TbRegion> queryRegionByParentCode(Integer code){
        return commonService.queryRegionByParentCode(code);
    }

}
