package com.ruoyi.web.controller.contentCheck;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbConsultantChange;
import com.ruoyi.system.service.ITbConsultantChangeService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

/**
 * 顾问变更申请Controller
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
@Controller
@RequestMapping("/business/changeCheck")
public class ConsultantChangeCheckController extends BaseController
{
    private String prefix = "business/change";

    @Autowired
    private ITbConsultantChangeService tbConsultantChangeService;

    @RequiresPermissions("business:change:checkListView")
    @GetMapping()
    public String checkList()
    {
        return prefix + "/checkList";
    }

    /**
     * 审核人员查询顾问变更申请列表
     */
    @RequiresPermissions("business:change:checkList")
    @PostMapping("/checkList")
    @ResponseBody
    public TableDataInfo checkList(TbConsultantChange tbConsultantChange)
    {
        startPage();
        List<TbConsultantChange> list = tbConsultantChangeService.selectTbConsultantChangeCheckList(tbConsultantChange);
        return getDataTable(list);
    }

    /**
     * 审核
     */
    @RequiresPermissions("business:change:check")
    @GetMapping("/check/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbConsultantChange tbConsultantChange = tbConsultantChangeService.selectTbConsultantChangeById(id);
        mmap.put("tbConsultantChange", tbConsultantChange);
        return prefix + "/checkApply";
    }

    /**
     * 保存顾问变更申请
     */
    @RequiresPermissions("business:change:check")
    @Log(title = "保存变更顾问审核结果", businessType = BusinessType.UPDATE)
    @PostMapping("/check")
    @ResponseBody
    public AjaxResult editSave(TbConsultantChange tbConsultantChange)
    {
        tbConsultantChange.setExamineTime(new Date());
        return toAjax(tbConsultantChangeService.updateTbConsultantChange(tbConsultantChange));
    }
}
