package com.ruoyi.web.controller.contentCheck;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbInformationPlatform;
import com.ruoyi.system.service.ITbInformationPlatformService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import java.util.List;

/**
 * 海外国家人文，交通，饮食信息Controller
 * 
 * @author ruoyi
 * @date 2024-02-29
 */
@Controller
@RequestMapping("/system/platformCheck")
public class TbInformationPlatformCheckController extends BaseController
{
    private String prefix = "business/platform";

    @Autowired
    private ITbInformationPlatformService tbInformationPlatformService;

    @RequiresPermissions("system:platform:view")
    @GetMapping()
    public String platform()
    {
        return prefix + "/platformCheck";
    }

    /**
     * 查询海外国家人文，交通，饮食信息列表
     */
    @RequiresPermissions("system:platform:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbInformationPlatform tbInformationPlatform)
    {
        startPage();
        List<TbInformationPlatform> list = tbInformationPlatformService.selectTbInformationPlatformNotPassList(tbInformationPlatform);
        return getDataTable(list);
    }

    /**
     * 修改海外国家人文，交通，饮食信息
     */
    @RequiresPermissions("system:platform:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbInformationPlatform tbInformationPlatform = tbInformationPlatformService.selectTbInformationPlatformById(id);
        mmap.put("tbInformationPlatform", tbInformationPlatform);
        return prefix + "/editCheckStatus";
    }

    /**
     * 修改保存海外国家人文，交通，饮食信息
     */
    @RequiresPermissions("system:platform:edit")
    @Log(title = "海外国家人文，交通，饮食信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbInformationPlatform tbInformationPlatform)
    {
        tbInformationPlatform.setChecker(getUserId());
        return toAjax(tbInformationPlatformService.updateCheckStatus(tbInformationPlatform));
    }

}
