package com.ruoyi.web.controller.school;

import java.util.List;

import com.ruoyi.system.domain.TbSchool;
import com.ruoyi.system.domain.TbSchoolMajor;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbEnrollmentTime;
import com.ruoyi.system.service.ITbEnrollmentTimeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 入学时间Controller
 * 
 * @author ruoyi
 * @date 2022-09-05
 */
@Controller
@RequestMapping("/system/time")
public class TbEnrollmentTimeController extends BaseController
{
    private String prefix = "system/time";

    @Autowired
    private ITbEnrollmentTimeService tbEnrollmentTimeService;

    @RequiresPermissions("system:time:view")
    @GetMapping()
    public String time()
    {
        return prefix + "/time";
    }

    /**
     * 查询入学时间列表
     */
    @RequiresPermissions("system:time:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbEnrollmentTime tbEnrollmentTime)
    {
        startPage();
        List<TbEnrollmentTime> list = tbEnrollmentTimeService.selectTbEnrollmentTimeList(tbEnrollmentTime);
        return getDataTable(list);
    }

    /**
     * 查询入学时间列表
     */
    @RequiresPermissions("system:time:list")
    @PostMapping("/notPassList")
    @ResponseBody
    public TableDataInfo selectEnrollmentTimeNotPassList(TbEnrollmentTime tbEnrollmentTime)
    {
        startPage();
        List<TbEnrollmentTime> list = tbEnrollmentTimeService.selectEnrollmentTimeNotPassList(tbEnrollmentTime);
        return getDataTable(list);
    }

    /**
     * 导出入学时间列表
     */
    @RequiresPermissions("system:time:export")
    @Log(title = "入学时间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbEnrollmentTime tbEnrollmentTime)
    {
        List<TbEnrollmentTime> list = tbEnrollmentTimeService.selectTbEnrollmentTimeList(tbEnrollmentTime);
        ExcelUtil<TbEnrollmentTime> util = new ExcelUtil<TbEnrollmentTime>(TbEnrollmentTime.class);
        return util.exportExcel(list, "入学时间数据");
    }

    /**
     * 新增入学时间
     */
    @GetMapping("/add")
    public String add(@RequestParam Long schoolId,@RequestParam Integer degreeType,ModelMap mmap)
    {
        mmap.put("schoolId",schoolId);
        mmap.put("degreeType",degreeType);
        return prefix + "/add";
    }

    /**
     * 新增保存入学时间
     */
    @RequiresPermissions("system:time:add")
    @Log(title = "入学时间", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbEnrollmentTime tbEnrollmentTime)
    {
        tbEnrollmentTime.setCreator(getUserId());
        tbEnrollmentTimeService.insertTbEnrollmentTimeBatch(tbEnrollmentTime);
        return AjaxResult.success();
    }

    /**
     * 根据学校id和学位类型查询入学时间，申请时间等信息
     * @param id
     * @param mmap
     * @return
     */
    @RequiresPermissions("system:time:edit")
    @GetMapping("/add/{id}")
    public String add(@PathVariable("id") String id, ModelMap mmap)
    {
        String[] strArray=id.split("&");
        TbEnrollmentTime tbEnrollmentTime=new TbEnrollmentTime();
        tbEnrollmentTime.setSchoolId(Long.parseLong(strArray[0]));
        tbEnrollmentTime.setDegreeType(Integer.parseInt(strArray[1]));
        tbEnrollmentTime.setSchoolCnName(strArray[2]);
        List<TbEnrollmentTime> tbEnrollmentTimes = tbEnrollmentTimeService.selectTbEnrollmentTimeListBySchoolAndDegree(tbEnrollmentTime);
        mmap.put("list", tbEnrollmentTimes);
        mmap.put("schoolId", strArray[0]);
        mmap.put("degreeType", strArray[1]);
        return prefix + "/show";
    }

    /**
     * 修改入学时间
     */
    @RequiresPermissions("system:time:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Integer id, ModelMap mmap)
    {
        TbEnrollmentTime tbEnrollmentTime = tbEnrollmentTimeService.selectTbEnrollmentTimeById(id);
        mmap.put("tbEnrollmentTime", tbEnrollmentTime);
        return prefix + "/edit";
    }

    /**
     * 修改保存入学时间
     */
    @RequiresPermissions("system:time:edit")
    @Log(title = "入学时间", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbEnrollmentTime tbEnrollmentTime)
    {
        tbEnrollmentTime.setModifiedBy(getUserId());
        return toAjax(tbEnrollmentTimeService.updateTbEnrollmentTime(tbEnrollmentTime));
    }

    /**
     * 修改保存入学时间
     */
    @RequiresPermissions("system:time:edit")
    @Log(title = "根据uuid修改入学时间", businessType = BusinessType.UPDATE)
    @PostMapping("/editByUuid")
    @ResponseBody
    public AjaxResult editByUuid(TbEnrollmentTime tbEnrollmentTime)
    {
        tbEnrollmentTime.setModifiedBy(getUserId());
        return toAjax(tbEnrollmentTimeService.updateTbEnrollmentTimeByUuid(tbEnrollmentTime));
    }

    /**
     * 修改入学时间
     */
    @RequiresPermissions("system:time:edit")
    @Log(title = "入学时间", businessType = BusinessType.UPDATE)
    @GetMapping("/editByUuid/{uuid}")
    public String editByUuid(@PathVariable String uuid, ModelMap mmap)
    {
        mmap.put("tbEnrollmentTime",tbEnrollmentTimeService.selectTbEnrollmentTimeByUuid(uuid));
        return prefix + "/edit";
    }

    /**
     * 删除入学时间
     */
    @RequiresPermissions("system:time:remove")
    @Log(title = "入学时间", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbEnrollmentTimeService.deleteTbEnrollmentTimeByIds(ids));
    }

    @RequiresPermissions("system:time:remove")
    @Log(title = "根据uuid删除入学时间数据", businessType = BusinessType.DELETE)
    @PostMapping( "/removeByUuid")
    @ResponseBody
    public AjaxResult deleteTbEnrollmentTimeByUuid(String uuid)
    {
        return toAjax(tbEnrollmentTimeService.deleteTbEnrollmentTimeByUuid(uuid));
    }

    /**
     * @Author : fanxiaolong
     * @Description :  根据学校id查询校区
     * @DateTime : 2022/9/7 10:51
     * @param : id
     * @return : java.util.List<java.lang.String>
     */
    @RequiresPermissions("system:time:list")
    @GetMapping("/selectSchool/{id}")
    @ResponseBody
    public List<TbSchool> selectSchoolCampusByID(@PathVariable Long id){

        return tbEnrollmentTimeService.selectSchoolCampusByID(id);
    }

    /**
     * @Author : fanxiaolong
     * @Description :  根据学校id查询专业信息
     * @DateTime : 2022/9/7 11:13
     * @param : id
     * @return : java.util.List<com.ruoyi.system.domain.TbSchoolMajor>
     */
    @RequiresPermissions("system:time:list")
    @GetMapping("/selectMajor/{id}")
    @ResponseBody
    public List<TbSchoolMajor> selectMajorBySchoolId(@PathVariable Long id){

        return tbEnrollmentTimeService.selectSchoolMajorBySchoolId(id);
    }

    @RequiresPermissions("system:time:list")
    @GetMapping("/selectDegree/{schoolId}/{majorCnName}")
    @ResponseBody
    public List<TbSchoolMajor> selectDegreeBySchooIdAndMajorName(@PathVariable Long schoolId,@PathVariable String majorCnName){
        TbSchoolMajor tbSchoolMajor=new TbSchoolMajor();
        tbSchoolMajor.setSchoolId(schoolId);
        tbSchoolMajor.setMajorCnName(majorCnName);
        return tbEnrollmentTimeService.selectDegreeBySchooIdAndMajorName(tbSchoolMajor);
    }

    @RequiresPermissions("system:time:list")
    @GetMapping("/selectDegrees/{schoolId}/{degreeType}")
    @ResponseBody
    public List<TbSchoolMajor> selectDegreeBySchoolIdAndDegreeType(@PathVariable Long schoolId,@PathVariable String degreeType){
        TbSchoolMajor tbSchoolMajor=new TbSchoolMajor();
        tbSchoolMajor.setSchoolId(schoolId);
        tbSchoolMajor.setDegreeType(degreeType);
        return tbEnrollmentTimeService.selectDegreeBySchoolIdAndDegreeType(tbSchoolMajor);
    }

    @RequiresPermissions("system:time:list")
    @GetMapping("/query")
    @ResponseBody
    public List<TbEnrollmentTime> selectDegreeBySchoolIdAndDegreeType(@RequestParam Long schoolId, @RequestParam Integer degreeType){
        TbEnrollmentTime enrollmentTime=new TbEnrollmentTime();
        enrollmentTime.setSchoolId(schoolId);
        enrollmentTime.setDegreeType(degreeType);
        return tbEnrollmentTimeService.selectTbEnrollmentTimeListBySchoolAndDegree(enrollmentTime);
    }
}
