package com.ruoyi.web.controller.school;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbMajorSorted;
import com.ruoyi.system.service.ITbMajorSortedService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 专业类型Controller
 * 
 * @author ruoyi
 * @date 2022-12-19
 */
@Controller
@RequestMapping("/system/sorted")
public class TbMajorSortedController extends BaseController
{
    private String prefix = "system/sorted";

    @Autowired
    private ITbMajorSortedService tbMajorSortedService;

    @RequiresPermissions("system:sorted:view")
    @GetMapping()
    public String sorted()
    {
        return prefix + "/sorted";
    }

    /**
     * 查询专业类型列表
     */
    @RequiresPermissions("system:sorted:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbMajorSorted tbMajorSorted)
    {
        startPage();
        List<TbMajorSorted> list = tbMajorSortedService.selectTbMajorSortedList(tbMajorSorted);
        return getDataTable(list);
    }

    /**
     * @Author : fanxiaolong
     * @Description : 查询顶级专业
     * @DateTime : 2022/12/21 11:09
     * @param :
     * @return : java.util.List<com.ruoyi.system.domain.TbMajorSorted>
     */
    @RequiresPermissions("system:sorted:list")
    @GetMapping("/queryTopLevel")
    @ResponseBody
    public List<TbMajorSorted> queryTopLevel(){

        TbMajorSorted tbMajorSorted=new TbMajorSorted();
        tbMajorSorted.setMajorLevel(0L);
        List<TbMajorSorted> list = tbMajorSortedService.selectTbMajorSortedList(tbMajorSorted);
        return list;
    }

    /**
     * @Author : fanxiaolong
     * @Description :
     * @DateTime : 2022/12/21 11:11
     * @param : parentCode
     * @return : java.util.List<com.ruoyi.system.domain.TbMajorSorted>
     */
    @RequiresPermissions("system:sorted:list")
    @GetMapping("/queryByParentCode/{parentCode}")
    @ResponseBody
    public List<TbMajorSorted> queryByParentCode(@PathVariable String parentCode){

        TbMajorSorted tbMajorSorted=new TbMajorSorted();
        tbMajorSorted.setMajorParentCode(Long.parseLong(parentCode));
        List<TbMajorSorted> list = tbMajorSortedService.selectTbMajorSortedList(tbMajorSorted);
        return list;
    }

    /**
     * 导出专业类型列表
     */
    @RequiresPermissions("system:sorted:export")
    @Log(title = "专业类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbMajorSorted tbMajorSorted)
    {
        List<TbMajorSorted> list = tbMajorSortedService.selectTbMajorSortedList(tbMajorSorted);
        ExcelUtil<TbMajorSorted> util = new ExcelUtil<TbMajorSorted>(TbMajorSorted.class);
        return util.exportExcel(list, "专业类型数据");
    }

    /**
     * 新增专业类型
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存专业类型
     */
    @RequiresPermissions("system:sorted:add")
    @Log(title = "专业类型", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbMajorSorted tbMajorSorted)
    {
        tbMajorSorted.setMajorLevel(2L);
        return toAjax(tbMajorSortedService.insertTbMajorSorted(tbMajorSorted));
    }

    /**
     * 修改专业类型
     */
    @RequiresPermissions("system:sorted:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbMajorSorted tbMajorSorted = tbMajorSortedService.selectTbMajorSortedById(id);
        mmap.put("tbMajorSorted", tbMajorSorted);
        return prefix + "/edit";
    }

    /**
     * 修改保存专业类型
     */
    @RequiresPermissions("system:sorted:edit")
    @Log(title = "专业类型", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbMajorSorted tbMajorSorted)
    {
        return toAjax(tbMajorSortedService.updateTbMajorSorted(tbMajorSorted));
    }

    /**
     * 删除专业类型
     */
    @RequiresPermissions("system:sorted:remove")
    @Log(title = "专业类型", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbMajorSortedService.deleteTbMajorSortedByIds(ids));
    }
}
