package com.ruoyi.web.controller.studentFile;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.req.StudentFileReq;
import com.ruoyi.system.res.StudentFileRes;
import com.ruoyi.system.service.IStudentFileService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 学生档案Controller
 * 
 * @author ruoyi
 * @date 2023-01-05
 */
@Controller
@RequestMapping("/business/studentFile")
public class StudentFileController extends BaseController
{
    //html路径
    private String prefix = "business/studentFile";

    @Autowired
    private IStudentFileService studentFileService;

    @RequiresPermissions("business:studentFile:view")
    @GetMapping()
    public String info()
    {
        return prefix + "/show";
    }

    /**
     * 查询用户基本信息列表
     */
    @RequiresPermissions("business:studentFile:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(StudentFileReq req)
    {
        startPage();
        List<StudentFileRes> list= studentFileService.selectUserBasicInfo(req);
        return getDataTable(list);
    }

    /**
     * 导出学生基本信息列表
     */
    @RequiresPermissions("business:studentFile:export")
    @Log(title = "学生申请院校相关资料", businessType = BusinessType.EXPORT)
    @GetMapping("/export/{applyId}")
    @ResponseBody
    public void export(@PathVariable("applyId") String applyId, HttpServletResponse response)
    {
        studentFileService.exportByApplyId(applyId,response);
    }

    /**
     * 根据学生id查询申请进度
     */
    @RequiresPermissions("business:studentFile:edit")
    @GetMapping("/edit/{id}")
//    @ResponseBody
    public String edit(@PathVariable("id") Integer id, ModelMap mmap)
    {
        startPage();
        List<StudentFileRes> studentFileRes = studentFileService.queryApplyByUserID(id);
        mmap.put("student", studentFileRes);
        return prefix + "/show";
    }
}
