package com.ruoyi.web.controller.system;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.config.ServerConfig;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.system.domain.TbMaterialDemo;
import com.ruoyi.system.mapper.TbMaterialDemoMapper;
import net.coobird.thumbnailator.Thumbnails;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.subject.Subject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.ServletUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.framework.web.service.ConfigService;

import java.awt.image.BufferedImage;
import java.io.File;
import java.util.List;

/**
 * 登录验证
 * 
 * @author ruoyi
 */
@Controller
public class SysLoginController extends BaseController
{
    /**
     * 是否开启记住我功能
     */
    @Value("${shiro.rememberMe.enabled: false}")
    private boolean rememberMe;

    @Autowired
    private ConfigService configService;

    @Resource
    private TbMaterialDemoMapper mapper;

    @GetMapping("/login")
    public String login(HttpServletRequest request, HttpServletResponse response, ModelMap mmap)
    {
        // 如果是Ajax请求，返回Json字符串。
        if (ServletUtils.isAjaxRequest(request))
        {
            return ServletUtils.renderString(response, "{\"code\":\"1\",\"msg\":\"未登录或登录超时。请重新登录\"}");
        }
        // 是否开启记住我
        mmap.put("isRemembered", rememberMe);
        // 是否开启用户注册
        mmap.put("isAllowRegister", Convert.toBool(configService.getKey("sys.account.registerUser"), false));
        return "login";
    }

    @PostMapping("/login")
    @ResponseBody
    public AjaxResult ajaxLogin(String username, String password, Boolean rememberMe)
    {
        //临时代码，转换图片 begin
//        List<TbMaterialDemo> tbMaterialDemos = mapper.selectTbMaterialDemoList(new TbMaterialDemo());
//        tbMaterialDemos.stream().forEach(tbMaterialDemo -> {
//            try {
//                // 上传文件路径
//                String filePath = RuoYiConfig.getUploadPath();
//                // 上传并返回新文件名称
//                String fileName = tbMaterialDemo.getMaterialCover();
//                String fileFullPath = filePath + fileName.substring(fileName.indexOf("/upload/") + 7);
//                //生成专业封面缩略图 280 * 380
//                String coverThumbnails = fileFullPath.substring(0, fileFullPath.lastIndexOf("/")) +
//                        "/thumbnails_" + FileUtils.getName(fileName);
//                BufferedImage sourceImg = ImageIO.read(new File(fileFullPath));
//                int width = sourceImg.getWidth();
//                if(width<=280){
//                    coverThumbnails=fileFullPath;
//                }else{
//                    float l= 280f / Float.parseFloat(String.valueOf(width));
//                    Thumbnails.of(fileFullPath).scale(l).outputQuality(0.8f).toFile(coverThumbnails);
//                }
//                String coverRelativePath = coverThumbnails.replace(filePath, Constants.RESOURCE_PREFIX1);
//                tbMaterialDemo.setMaterialCoverThumbnails(coverRelativePath);
//                mapper.updateTbMaterialDemo(tbMaterialDemo);
//            } catch (Exception e) {
//                System.out.println(e.getMessage());
//            }
//        });
        //临时代码，转换图片 end
        UsernamePasswordToken token = new UsernamePasswordToken(username, password, rememberMe);
        Subject subject = SecurityUtils.getSubject();
        try
        {
            subject.login(token);
            return success();
        }
        catch (AuthenticationException e)
        {
            String msg = "用户或密码错误";
            if (StringUtils.isNotEmpty(e.getMessage()))
            {
                msg = e.getMessage();
            }
            return error(msg);
        }
    }

    @GetMapping("/unauth")
    public String unauth()
    {
        return "error/unauth";
    }
}
