package com.ruoyi.common.utils;

import java.util.Random;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @Author：fanxiaolong
 * @Date： 2023-01-17 11:54
 * @Description：
 */
public class DataUtils {
    /**
     * 验证手机号格式是否正确
     *
     * @param phone 手机号
     * @return true为正确 false为不正确
     */
    public static Boolean isPhone(String phone) {
        Pattern p = Pattern.compile("^1([358][0-9]|4[579]|66|7[0135678]|9[589])[0-9]{8}$");
        Matcher m = p.matcher(phone);
        return m.matches();
    }

    /**
     * @Author : fanxiaolong
     * @Description : 判断是否是合法身份证号
     * @DateTime : 2023/1/17 11:50
     * @param : identity_card
     * @return : java.lang.Boolean
     */
    public static Boolean isIdCard(String identity_card){

        //校验身份证号码格式通过
        // 定义判别用户身份证号的正则表达式（15位或者18位，最后一位可以为字母）
        String regularExpression = "(^[1-9]\\d{5}(18|19|20)\\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\\d{3}[0-9Xx]$)|" +
                "(^[1-9]\\d{5}\\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\\d{3}$)";
        boolean matches = identity_card.matches(regularExpression);
        Boolean identityCardRegular=false;
        if(matches){
            if(identity_card.length()==18){
                char[] charArray = identity_card.toCharArray();
                //前十七位加权因子
                int[] idCardWi = {7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2};
                //这是除以11后，可能产生的11位余数对应的验证码
                String[] idCardY = {"1", "0", "X", "9", "8", "7", "6", "5", "4", "3", "2"};
                int sum = 0;
                for (int i = 0; i < idCardWi.length; i++) {
                    int current = Integer.parseInt(String.valueOf(charArray[i]));
                    int count = current * idCardWi[i];
                    sum += count;
                }
                char idCardLast = charArray[17];
                int idCardMod = sum % 11;
                if (idCardY[idCardMod].toUpperCase().equals(String.valueOf(idCardLast).toUpperCase())) {
                    identityCardRegular=true;
                }
            }
        }
        return identityCardRegular;
    }

    /**
     * @Author : fanxiaolong
     * @Description : 生成指定位数的字符串
     * @DateTime : 2023/7/27 11:44
     * @param : num
     * @return : java.lang.String
     */
    public static String getPwdRandom(Integer num) {

        String val = "";
        Random random = new Random();

        //参数length，表示生成几位随机数
        for(int i = 0; i < num; i++) {

            String charOrNum = random.nextInt(2) % 2 == 0 ? "char" : "num";
            //输出字母还是数字
            if( "char".equalsIgnoreCase(charOrNum) ) {
                //输出是大写字母还是小写字母
                int temp = random.nextInt(2) % 2 == 0 ? 65 : 97;
                val += (char)(random.nextInt(26) + temp);
            } else if( "num".equalsIgnoreCase(charOrNum) ) {
                val += String.valueOf(random.nextInt(10));
            }
        }
        return val;
    }
}
