package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.TbSchool;
import com.ruoyi.system.res.SchoolInfoRes;
import org.apache.ibatis.annotations.Insert;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

/**
 * 学校信息Mapper接口
 * 
 * @author ruoyi
 * @date 2022-08-29
 */
@Mapper
public interface TbSchoolMapper 
{
    /**
     * 查询学校信息
     * 
     * @param id 学校信息主键
     * @return 学校信息
     */
    public TbSchool selectTbSchoolById(Long id);

    /**
     * 查询学校信息列表
     * 
     * @param tbSchool 学校信息
     * @return 学校信息集合
     */
    public List<TbSchool> selectTbSchoolList(TbSchool tbSchool);

    public List<TbSchool> selectTbSchoolNotPassList(TbSchool tbSchool);

    public List<TbSchool> selectAllTbSchoolList();

    /**
     * 新增学校信息
     * 
     * @param tbSchool 学校信息
     * @return 结果
     */
    public int insertTbSchool(TbSchool tbSchool);

    /**
     * 修改学校信息
     * 
     * @param tbSchool 学校信息
     * @return 结果
     */
    public int updateTbSchool(TbSchool tbSchool);

    public int updateCheckStatus(TbSchool tbSchool);

    /**
     * 删除学校信息
     * 
     * @param id 学校信息主键
     * @return 结果
     */
    public int deleteTbSchoolById(Long id);

    /**
     * 批量删除学校信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbSchoolByIds(String[] ids);

    /**
     * 查询学校的校区
     * @param id
     * @return
     */
    public List<TbSchool> selectSchoolCampusByID(Long id);

    public int deleteTbPerCollectBySchoolId(Long id);
    public int deleteTbPerCollectBySchoolIds(String[] ids);

    public int deleteTbPerCollectByMajorId(Long id);
    public int deleteTbPerCollectByMajorIds(String[] ids);

    @Insert("<script>insert into tb_school (school_cn_name,school_en_name,school_birthday," +
            "school_cn_country,school_cn_city,school_type," +
            "school_logo,school_cover,school_advantage,school_campus,school_introduction,\n" +
            "creator,create_time,check_status,qs_world,qs_area,school_area,live_type,airport_pickup,search_count," +
            "background_image,employment_rate,qs_employability,teaching_language,internship,\n" +
            "gov_auth,lng,lat,address,phone,website,apply_price,admission_difficulty,video_link) \n" +
            "select school_cn_name,school_en_name,school_birthday,school_cn_country,school_cn_city,school_type," +
            "school_logo," +
            "school_cover,school_advantage,school_campus,school_introduction,\n" +
            "creator,create_time,"+1+",qs_world,qs_area,school_area,live_type,airport_pickup,search_count," +
            "background_image,employment_rate,qs_employability,teaching_language,internship,\n" +
            "gov_auth,lng,lat,address,phone,website,apply_price,admission_difficulty,video_link \n" +
            "from tb_school \n" +
            "where id=#{id}</script>")
    public int copy(Long id);

    @Update("update tb_school\n" +
            "set undergraduate_enrollment=(undergraduate_enrollment+1)\n" +
            "where id=#{schoolId}")
    void updateUndergraduateEnrollment(Long schoolId);

    @Update("update tb_school\n" +
            "set master_and_doctoral_enrollment=(master_and_doctoral_enrollment+1)\n" +
            "where id=#{schoolId}")
    void updateMasterDoctoralEnrollment(Long schoolId);

    @Select("<script>select id,school_cn_name as schoolCnName,school_campus as schoolCampus\n" +
            "from tb_school\n" +
            "<if test=\"id != null and id != ''\">\n" +
            "where id=#{id}"+
            "</if>"+
            "</script>")
    List<SchoolInfoRes> querySimpleSchoolInfo(Long id);
}
