package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.TbUserApply;
import com.ruoyi.system.res.UserApplyRes;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

import java.util.List;

/**
 * 用户申请Mapper接口
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Mapper
public interface TbUserApplyMapper
{
    /**
     * 查询用户申请信息
     * 
     * @param id 用户申请信息主键
     * @return 用户申请信息
     */
    @Select("select id,user_id as userId,major_id as majorId\n" +
            "from tb_user_apply\n" +
            "where id=#{id}")
    UserApplyRes selectTbUserApplyById(String id);

    /**
     * 查询用户申请信息
     *
     * @param id 用户申请信息主键
     * @return 用户申请信息
     */
    @Select("select t2.major_Cn_Name as majorCnName,t1.enrollment_id as enrollmentId," +
            "t2.degree_Cn_Name as degreeCnName,concat(t3.school_cn_name,'(',t3.school_campus,')') as schoolCnName\n" +
            "from tb_user_apply t1\n" +
            "left join tb_school_major t2 on t1.major_id=t2.id\n" +
            "left join tb_school t3 on t2.school_id=t3.id\n"+
            "where t1.id=#{id}")
    UserApplyRes selectUserApplyById(String id);

    /**
     * 查询用户申请信息列表
     * 
     * @param tbUserApply 用户申请信息
     * @return 用户申请信息集合
     */
    @Select("<script>" +
            "select id,user_id as userId,major_id as majorId,enrollment_id as enrollmentId," +
            "apply_phase as applyPhase,apply_progress as applyProgress," +
            "apply_date as applyDate,apply_status as applyStatus\n" +
            "from tb_user_apply \n" +
            "where apply_status=#{tbUserApply.applyStatus}\n"+
            "<if test=\"tbUserApply.id !=null and tbUserApply.id !=''\">"+
            "and id=#{tbUserApply.id}"+
            "</if>"+
            "<if test=\"tbUserApply.userId !=null and tbUserApply.userId !=''\">"+
            "and user_id=#{tbUserApply.userId}"+
            "</if>" +
            "order by applyDate desc"+
            "</script>")
    List<UserApplyRes> selectTbUserApplyList(@Param("tbUserApply") TbUserApply tbUserApply);

    @Update("<script>" +
            "update tb_user_apply \n" +
            "<trim prefix=\"SET\" suffixOverrides=\",\">\n" +
            "<if test=\"tbUserApply.applyStatus != null and tbUserApply.applyStatus != ''\">" +
            "   apply_status = #{tbUserApply.applyStatus}," +
            "</if>\n" +
            "<if test=\"tbUserApply.applyProgress != null and tbUserApply.applyProgress != ''\">" +
            "   apply_progress = #{tbUserApply.applyProgress}," +
            "</if>\n" +
            "<if test=\"tbUserApply.applyState != null and tbUserApply.applyState != ''\">" +
            "   apply_state = #{tbUserApply.applyState}," +
            "</if>\n" +
            "</trim>"+
            "where id=#{tbUserApply.id}" +
            "</script>")
    int updateTbUserApplyStatusById(@Param("tbUserApply") TbUserApply tbUserApply);

    @Update("<script>" +
            "update tb_user_apply\n" +
            "set apply_progress=#{tbUserApply.applyProgress}\n"+
            "where id=#{tbUserApply.id}" +
            "</script>")
    int updateTbUserApplyProgressById(@Param("tbUserApply") TbUserApply tbUserApply);

}
