package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.TbUserBasicInfo;
import com.ruoyi.system.req.StudentFileReq;
import com.ruoyi.system.res.StudentFileRes;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

/**
 * 用户基本信息Mapper接口
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Mapper
public interface TbUserBasicInfoMapper
{
    /**
     * 查询用户基本信息
     * 
     * @param id 用户基本信息主键
     * @return 用户基本信息
     */
    public TbUserBasicInfo selectTbUserBasicInfoById(Long id);

    TbUserBasicInfo selectTbUserBasicInfoByApplyId(String applyId);

    @Select("select concat(surname,name) as userName \n" +
            "from tb_user_basic_info \n" +
            "where apply_id=#{applyId}")
    String selectUserNameByApplyId(String applyId);
    /**
     * 查询用户基本信息列表
     * 
     * @param tbUserBasicInfo 用户基本信息
     * @return 用户基本信息集合
     */
    public List<TbUserBasicInfo> selectTbUserBasicInfoList(TbUserBasicInfo tbUserBasicInfo);

    TbUserBasicInfo selectTbUserBasicInfoByUserid(Long userid);

    /**
     * 新增用户基本信息
     * 
     * @param tbUserBasicInfo 用户基本信息
     * @return 结果
     */
    public int insertTbUserBasicInfo(TbUserBasicInfo tbUserBasicInfo);

    /**
     * 修改用户基本信息
     * 
     * @param tbUserBasicInfo 用户基本信息
     * @return 结果
     */
    public int updateTbUserBasicInfo(TbUserBasicInfo tbUserBasicInfo);

    /**
     * 删除用户基本信息
     * 
     * @param id 用户基本信息主键
     * @return 结果
     */
    public int deleteTbUserBasicInfoById(Long id);

    /**
     * 批量删除用户基本信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbUserBasicInfoByIds(String[] ids);

    @Update("update tb_user_basic_info\n" +
            "set is_modify=#{state}\n" +
            "where apply_id=#{applyId}")
    void updateModifyState(@Param("state") String state, @Param("applyId") String applyId);

    @Select("<script>" +
            "select t1.userid,CONCAT(t1.surname,t1.name) as userName,t1.apply_id as applyId,t2.id_card as idCard," +
            "t2.mobilePhone,t3.major_id as majorId\n" +
            " FROM tb_user_basic_info t1\n" +
            "LEFT JOIN tb_user_detail_info t2\n" +
            "ON t1.apply_id=t2.apply_id \n" +
            "RIGHT JOIN tb_user_apply t3 \n" +
            "ON t1.apply_id=t3.id\n "+
            "<where>\n" +
    "            and t3.apply_status>=8\n" +
    "            <if test=\"req.userId != null and req.userId !=''\"> and t1.userid = #{req.userId}</if>\n" +
    "            <if test=\"req.applyId != null  and req.applyId != ''\"> and t1.apply_id = #{req.applyId}</if>\n" +
    "            <if test=\"req.idCard != null  and req.idCard != ''\"> and t2.id_card = #{req.idCard}</if>\n" +
    "            <if test=\"req.mobilePhone != null  and req.mobilePhone != ''\"> and t2.mobilePhone=#{req.mobilePhone}</if>\n" +
    "        </where>" +
            "</script>")
    List<StudentFileRes> selectUserBasicInfo(@Param("req") StudentFileReq req);

    @Select("<script>" +
            "select t1.userid,CONCAT(t1.surname,t1.name) as userName,t1.apply_id as applyId,t2.id_card as idCard," +
            "t2.mobilePhone,t3.major_id as majorId,t3.apply_date as applyDate,t3.apply_status as applyStatus\n" +
            "FROM tb_user_basic_info t1\n" +
            "LEFT JOIN tb_user_detail_info t2\n" +
            "ON t1.apply_id=t2.apply_id \n" +
            "RIGHT JOIN tb_user_apply t3 \n" +
            "ON t1.apply_id=t3.id\n "+
            "where t1.userid = #{id} order by t3.apply_date desc\n" +
            "</script>")
    List<StudentFileRes> queryApplyByUserID(@Param("id") Integer id);
}
