package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.TbUserDetailInfo;
import com.ruoyi.system.res.StudentInfo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

/**
 * 用户详细信息Mapper接口
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Mapper
public interface TbUserDetailInfoMapper 
{
    /**
     * 查询用户详细信息
     * 
     * @param id 用户详细信息主键
     * @return 用户详细信息
     */
    public TbUserDetailInfo selectTbUserDetailInfoById(Long id);

    TbUserDetailInfo selectTbUserDetailInfoByApplyId(String applyId);

    /**
     * 查询用户详细信息列表
     * 
     * @param tbUserDetailInfo 用户详细信息
     * @return 用户详细信息集合
     */
    List<TbUserDetailInfo> selectTbUserDetailInfoList(TbUserDetailInfo tbUserDetailInfo);

    TbUserDetailInfo selectTbUserDetailInfoByUserid(Long userid);

    /**
     * 新增用户详细信息
     * 
     * @param tbUserDetailInfo 用户详细信息
     * @return 结果
     */
    public int insertTbUserDetailInfo(TbUserDetailInfo tbUserDetailInfo);

    /**
     * 修改用户详细信息
     * 
     * @param tbUserDetailInfo 用户详细信息
     * @return 结果
     */
    public int updateTbUserDetailInfo(TbUserDetailInfo tbUserDetailInfo);

    /**
     * 删除用户详细信息
     * 
     * @param id 用户详细信息主键
     * @return 结果
     */
    public int deleteTbUserDetailInfoById(Long id);

    /**
     * 批量删除用户详细信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbUserDetailInfoByIds(String[] ids);

    @Update("update tb_user_detail_info\n" +
            "set is_modify=#{state}\n" +
            "where apply_id=#{applyId}")
    void updateModifyState(@Param("state") String state, @Param("applyId") String applyId);

    /**
     * 根据手机号或者护照号或者身份证号查询用户的姓名
     * @param vagueParam
     * @return
     */
    @Select("<script>" +
            "select t2.userid,concat(t2.surname,t2.name) as userName\n" +
            "from tb_user_detail_info t1\n" +
            "left join tb_user_basic_info t2\n" +
            "on t1.userid=t2.userid\n" +
            "where t1.passport_number=#{vagueParam} or t1.id_card=#{vagueParam} or t1.mobilephone=#{vagueParam}\n" +
            "limit 1" +
            "</script>")
    StudentInfo queryUserName(@Param("vagueParam") String vagueParam);
}
