package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.TbUserMaterial;
import com.ruoyi.system.res.UserMaterialRes;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

/**
 * 用户提交的材料Mapper接口
 * 
 * @author ruoyi
 * @date 2023-04-10
 */
@Mapper
public interface TbUserMaterialMapper 
{
    /**
     * 查询用户提交的材料
     * 
     * @param id 用户提交的材料主键
     * @return 用户提交的材料
     */
    TbUserMaterial selectTbUserMaterialById(Long id);

    /**
     * 查询用户提交的材料列表
     * 
     * @param tbUserMaterial 用户提交的材料
     * @return 用户提交的材料集合
     */
    List<TbUserMaterial> selectTbUserMaterialList(TbUserMaterial tbUserMaterial);

    @Select("<script>" +
            "select id,material_type as materialType,apply_id as applyId\n" +
            "from tb_user_material\n" +
            "<where>\n" +
            "and apply_id is not null\n"+
            "            <if test=\"userMaterial.userid != null \"> and userid = #{userMaterial.userid}</if>\n" +
            "            <if test=\"userMaterial.applyId != null  and userMaterial.applyId != ''\"> and apply_id = #{userMaterial.applyId}</if>\n" +
            "            <if test=\"userMaterial.materialType != null  and userMaterial.materialType != ''\"> and material_type = #{userMaterial.materialType}</if>\n" +
            "</where>"+
            "</script>")
    List<UserMaterialRes> selectUserMaterialList(@Param("userMaterial") TbUserMaterial tbUserMaterial);

    /**
     * 新增用户提交的材料
     * 
     * @param tbUserMaterial 用户提交的材料
     * @return 结果
     */
    int insertTbUserMaterial(TbUserMaterial tbUserMaterial);

    /**
     * 修改用户提交的材料
     * 
     * @param tbUserMaterial 用户提交的材料
     * @return 结果
     */
    int updateTbUserMaterial(TbUserMaterial tbUserMaterial);

    /**
     * 删除用户提交的材料
     * 
     * @param id 用户提交的材料主键
     * @return 结果
     */
    int deleteTbUserMaterialById(Long id);

    /**
     * 批量删除用户提交的材料
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteTbUserMaterialByIds(String[] ids);

    /**************审核页面查询用sql begin**************/
    @Select("<script>" +
            "select id as applyId,apply_date as applyDate\n" +
            "from tb_user_apply\n" +
            "<where>  \n" +
            "and apply_status=8"+
            "            <if test=\"userMaterial.userid != null \"> and user_id = #{userMaterial.userid}</if>\n" +
            "            <if test=\"userMaterial.applyId != null  and userMaterial.applyId != ''\"> and id = #{userMaterial.applyId}</if>\n" +
            "        </where>\n" +
            "order by applyDate desc"+
            "</script>")
    List<UserMaterialRes> selectUserMaterialListForCheck(@Param("userMaterial") TbUserMaterial tbUserMaterial);

    @Select("<script>" +
            "select apply_id as applyId,userid,files,material_type as materialType\n" +
            "from tb_user_material\n" +
            "where apply_id=#{applyId}" +
            "</script>")
    List<TbUserMaterial> selectUserMaterialByApplyId(String applyId);
    /**************审核页面查询用sql end**************/
}
