package com.ruoyi.system.service.impl;

import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.TbEnrollmentTime;
import com.ruoyi.system.domain.TbUserApply;
import com.ruoyi.system.domain.TbUserMaterial;
import com.ruoyi.system.mapper.*;
import com.ruoyi.system.res.UserApplyRes;
import com.ruoyi.system.res.UserMaterial1Res;
import com.ruoyi.system.res.UserMaterialRes;
import com.ruoyi.system.service.ICheckUserMaterialService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @Author：fanxiaolong
 * @Date： 2023-04-12 11:14
 * @Description：审核用户上传的材料
 */
@Service
public class CheckUserMaterialServiceImpl implements ICheckUserMaterialService {

    @Autowired
    private TbUserMaterialMapper tbUserMaterialMapper;
    @Autowired
    private TbMaterialDemoMapper materialDemoMapper;
    @Autowired
    private TbUserBasicInfoMapper userBasicInfoMapper;
    @Autowired
    private TbUserApplyMapper userApplyMapper;
    @Resource
    private TbEnrollmentTimeMapper enrollmentTimeMapper;

    @Override
    public List<UserMaterialRes> selectUserMaterialListForCheck(TbUserMaterial tbUserMaterial) {
        List<UserMaterialRes> originList=tbUserMaterialMapper.selectUserMaterialListForCheck(tbUserMaterial);
        if(null != originList && !originList.isEmpty()){
            for(UserMaterialRes userMaterialRes : originList){
//                userMaterialRes.setMaterialTypeDesc(
//                        materialDemoMapper.selectTbMaterialDemoById(userMaterialRes.getMaterialType()).getMaterialName()
//                );
                userMaterialRes.setUserName(userBasicInfoMapper.selectUserNameByApplyId(userMaterialRes.getApplyId()));
                UserApplyRes tbUserApply = userApplyMapper.selectUserApplyById(userMaterialRes.getApplyId());
                userMaterialRes.setSchoolName(tbUserApply.getSchoolCnName());
                userMaterialRes.setMajorName(tbUserApply.getMajorCnName());
                userMaterialRes.setDegreeName(tbUserApply.getDegreeCnName());
                TbEnrollmentTime tbEnrollmentTime = enrollmentTimeMapper.selectTbEnrollmentTimeById(tbUserApply.getEnrollmentId());
                int i = DateUtils.differentDaysByMillisecond(userMaterialRes.getApplyDate(), tbEnrollmentTime.getApplyEndDate());
                if(i<=30){
                    userMaterialRes.setRemark("紧急申请");
                }
                long between = DateUtil.between(new Date(), tbEnrollmentTime.getApplyStartDate(), DateUnit.DAY,false);
                if(between>0){
                    userMaterialRes.setRemark("该专业目前还未放开申请");
                }
            }
            return originList;
        }
        return new ArrayList<>();
    }

    /**
     * @Author : fanxiaolong
     * @Description : 根据申请id查询所有材料
     * @DateTime : 2023/4/11 14:02
     * @param : applyId
     * @return : com.ruoyi.system.res.UserMaterial1Res
     */
    @Override
    public UserMaterial1Res selectUserMaterialList(String applyId){

        UserMaterial1Res userMaterial1Res=new UserMaterial1Res();
        List<TbUserMaterial> originList=tbUserMaterialMapper.selectUserMaterialByApplyId(applyId);
        StringBuffer sb=new StringBuffer();
        for(TbUserMaterial userMaterialRes : originList){
            if(StringUtils.isNotEmpty(userMaterialRes.getFiles())){
                for(String str : userMaterialRes.getFiles().split(",")){
                    sb.append(materialDemoMapper.selectTbMaterialDemoById(userMaterialRes.getMaterialType()).getMaterialName()).
                            append("<fxl>").
                            append(str).
                            append(",");
                }
            }
        }
        String s=sb.toString();
        userMaterial1Res.setUserid(originList.get(0).getUserid());
        userMaterial1Res.setApplyId(originList.get(0).getApplyId());
        userMaterial1Res.setFiles(s.substring(0,s.length()-1));
        return userMaterial1Res;
    }
}
