package com.ruoyi.system.service.impl;

import cn.hutool.core.util.ZipUtil;
import com.itextpdf.text.*;
import com.itextpdf.text.Font;
import com.itextpdf.text.Image;
import com.itextpdf.text.pdf.*;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.io.TBCell;
import com.ruoyi.common.utils.CacheUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.*;
import com.ruoyi.system.mapper.*;
import com.ruoyi.system.req.StudentFileReq;
import com.ruoyi.system.res.StudentFileRes;
import com.ruoyi.system.res.UserApplyRes;
import com.ruoyi.system.service.IStudentFileService;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletResponse;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.*;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Author：fanxiaolong
 * @Date： 2023-04-21 15:45
 * @Description：查询学生信息，导出pdf
 */
@Service
public class StudentFileServiceImpl implements IStudentFileService {

    @Autowired
    private TbUserApplyMapper userApplyMapper;

    @Autowired
    private TbUserBasicInfoMapper userBasicInfoMapper;

    @Autowired
    private TbSchoolMajorMapper schoolMajorMapper;

    @Autowired
    private TbUserDetailInfoMapper tbUserDetailInfoMapper;

    @Autowired
    private TbUserEducationBackgroundMapper tbUserEducationBackgroundMapper;

    @Autowired
    private TbUserWorkExperienceMapper tbUserWorkExperienceMapper;

    @Autowired
    private TbUserLanguageBackgroundMapper tbUserLanguageBackgroundMapper;

    @Autowired
    private TbUserParentInfoMapper tbUserParentInfoMapper;

    @Autowired
    private TbUserMaterialMapper userMaterialMapper;

    /**
     * @Author : fanxiaolong
     * @Description : 根据用户id查询用户基本信息
     * @DateTime : 2023/4/21 15:52
     * @param :
     * @return : java.util.List<com.ruoyi.system.domain.TbUserBasicInfo>
     */
    @Override
    public List<StudentFileRes> selectUserBasicInfo(StudentFileReq req) {

        List<StudentFileRes> tbUserBasicInfos = userBasicInfoMapper.selectUserBasicInfo(req);
        tbUserBasicInfos.stream().filter(studentFileRes -> {
            TbSchoolMajor tbSchoolMajor = schoolMajorMapper.selectTbSchoolMajorById(studentFileRes.getMajorId());
            studentFileRes.setDegreeName(tbSchoolMajor.getDegreeCnName());
            studentFileRes.setSchoolName(tbSchoolMajor.getSchoolCnName());
            return true;
        }).collect(Collectors.toList());
        return tbUserBasicInfos;
    }

    /**
     * @Author : fanxiaolong
     * @Description : 根据id查询用户申请信息
     * @DateTime : 2023/7/28 15:37
     * @param : id
     * @return : java.util.List<com.ruoyi.system.res.StudentFileRes>
     */
    @Override
    public List<StudentFileRes> queryApplyByUserID(Integer id){
        List<StudentFileRes> studentFileRes = userBasicInfoMapper.queryApplyByUserID(id);
        List<SysDictData> dictList=(List<SysDictData>) CacheUtils.get(Constants.SYS_DICT_CACHE, Constants.SYS_DICT_KEY + Constants.BUSINESS_APPLY_STATUS);
        //补充申请院校信息和申请进度信息
        for(StudentFileRes sfr : studentFileRes){
            //通过专业id查询专业和学校信息
            TbSchoolMajor tbSchoolMajor = schoolMajorMapper.selectTbSchoolMajorById(sfr.getMajorId());
            sfr.setSchoolName(tbSchoolMajor.getSchoolCnName());
            sfr.setDegreeName(tbSchoolMajor.getDegreeCnName());
            for(SysDictData sdd : dictList){
                if(sdd.getDictValue().equals(sfr.getApplyStatus().toString())){
                    sfr.setApplyStatusDesc(sdd.getDictLabel());
                }
            }
        }
        return studentFileRes;
    }

    /**
     * @Author : fanxiaolong
     * @Description : 导出申请信息和文件
     * @DateTime : 2023/4/23 15:21
     * @param : applyId
     * @param : response
     * @return : void
     */
    @Override
    public void exportByApplyId(String applyId, HttpServletResponse response){

        UserApplyRes tbUserApply=userApplyMapper.selectUserApplyById(applyId);
        //查询基本信息
        TbUserBasicInfo tbUserBasicInfo=userBasicInfoMapper.selectTbUserBasicInfoByApplyId(applyId);
        convertBasicInfo(tbUserBasicInfo);

        TbUserDetailInfo tbUserDetailInfo=tbUserDetailInfoMapper.selectTbUserDetailInfoByApplyId(applyId);
        convertDetailInfo(tbUserDetailInfo);

        List<TbUserEducationBackground> educationBackgroundList = tbUserEducationBackgroundMapper.selectTbUserEducationBackgroundListByApplyId(applyId);
        educationBackgroundList.stream().filter(tbUserEducationBackground -> {
            convertEducationInfo(tbUserEducationBackground);
            return true;
        }).collect(Collectors.toList());

        List<TbUserWorkExperience> workExperienceList = tbUserWorkExperienceMapper.selectTbUserWorkExperienceListByApplyId(applyId);
        workExperienceList.stream().filter(workExperience -> {
            convertWorkExperience(workExperience);
            return true;
        }).collect(Collectors.toList());

        TbUserLanguageBackground tbUserLanguageBackground = tbUserLanguageBackgroundMapper.selectTbUserLanguageBackgroundByApplyId(applyId);

        List<TbUserParentInfo> parentInfoList = tbUserParentInfoMapper.selectTbUserParentInfoListByApplyId(applyId);
        parentInfoList.stream().filter(parentInfo -> {
            convertParentInfo(parentInfo);
            return true;
        }).collect(Collectors.toList());

        String fileName= tbUserBasicInfo.getSurname()+tbUserBasicInfo.getName()+"-"+
                tbUserApply.getSchoolCnName()+"-"+
                tbUserApply.getDegreeCnName();

        String rootPath=RuoYiConfig.getProfile()+"/"+applyId+"/";
        String filePath=rootPath+fileName+".pdf";
        //生成pdf文档
        try
        {
            //创建文档
            Document document = new Document(PageSize.A4,5, 5, 36, 36);
            File file=new File(filePath);
            if(!file.getParentFile().exists()){
                file.getParentFile().mkdirs();
            }
            FileOutputStream out=new FileOutputStream(file);
            PdfWriter writer=PdfWriter.getInstance(document,out);
//            writer.setPageEvent(new CustomEvent("人才职业网",ip,port));// 水印

            document.open();
            Paragraph title = new Paragraph(18f, fileName,myfont(18,Font.NORMAL));
            title.setAlignment(Element.ALIGN_CENTER);
            document.add(title);
            //加入空行
            document.add(blankRow(30));

            //基本信息
            writeBasicInfo(document,tbUserBasicInfo);
            //详细信息
            writeDetailInfo(document,tbUserDetailInfo);
            //教育背景
            writeEducationInfo(document,educationBackgroundList);
            //工作经验
            if(ObjectUtils.isNotEmpty(workExperienceList) && !workExperienceList.isEmpty()){
                writeWorkInfo(document,workExperienceList);
            }
            //语言成绩
            if(ObjectUtils.isNotEmpty(tbUserLanguageBackground)){
                convertLanguageInfo(tbUserLanguageBackground);
                writeLanguageInfo(document,tbUserLanguageBackground);
            }
            //父母信息
            writeParentInfo(document,parentInfoList);

            document.close();
            writer.close();
            out.close();
        } catch (Exception ex){
            ex.printStackTrace();
        }
        //下载文件
        List<TbUserMaterial> tbUserMaterials = userMaterialMapper.selectUserMaterialByApplyId(applyId);
        for(TbUserMaterial userMaterial : tbUserMaterials){
            if(ObjectUtils.isNotEmpty(userMaterial.getFiles())){
                String dirName=CacheUtils.get(Constants.BUSINESS_MATERIAL_TYPE_CACHE,
                        Constants.BUSINESS_MATERIAL_TYPE_KEY+userMaterial.getMaterialType()).toString();
                String fileName1=userMaterial.getFiles().substring(userMaterial.getFiles().lastIndexOf("/"));
                String filePath1=rootPath+dirName+"/"+fileName1;
                File origionFile=new File(RuoYiConfig.getProfile()+userMaterial.getFiles().substring(userMaterial.getFiles().indexOf("/",1)));
                File newFile=new File(filePath1);
                if(!newFile.getParentFile().exists()){
                    newFile.getParentFile().mkdirs();
                }
                //复制文件
                try {
                    FileUtils.copyFile(origionFile,newFile);
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        //打包，传输
        ZipUtil.zip(rootPath);
        String zipPath=RuoYiConfig.getProfile()+"/"+applyId+".zip";
        String zipName=applyId+".zip";
        //写入流下载
        OutputStream out = null;
        try {
            out = response.getOutputStream();
            InputStream is=new FileInputStream(zipPath);
            //接收压缩包字节
            response.reset();
            response.addHeader("Access-Control-Allow-Origin", "*");
            response.setHeader("Access-Control-Expose-Headers", "*");
            response.setHeader("Content-Disposition", "attachment;filename*=utf-8''" + zipName);
            response.setContentType("application/octet-stream;charset=UTF-8");
//                response.addHeader("Content-Length", "" + file.length());
            response.setHeader("filename",zipName);
            byte[] bytes=new byte[10240];
            while(is.read(bytes) != -1){
                out.write(bytes);
            }
            out.flush();
            out.close();
            is.close();
            FileUtils.delete(new File(zipPath));
            FileUtils.deleteDirectory(new File(rootPath));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void writeBasicInfo(Document document,TbUserBasicInfo tbUserBasicInfo) throws Exception {
        document.add(add_headtitle_1("基础信息"));
        //加入空行
        document.add(blankRow(5));
        //主体
        PdfPTable basicInfo = new PdfPTable(1);
        //配置单元格跨页显示
        basicInfo.setSplitLate(false);
        basicInfo.setSplitRows(true);

        int basicInfoTableWidth[] = {100};
        basicInfo.setWidths(basicInfoTableWidth);
        basicInfo.getDefaultCell().setBorder(0);
        basicInfo.addCell(add_cell("姓名："+tbUserBasicInfo.getSurname()+tbUserBasicInfo.getName(), 10));
        basicInfo.addCell(add_cell("称呼："+tbUserBasicInfo.getCallDesc(), 10));
        basicInfo.addCell(add_cell("出生日期："+tbUserBasicInfo.getBirthday(), 10));
        basicInfo.addCell(add_cell("性别："+tbUserBasicInfo.getSexDesc(), 10));
        basicInfo.addCell(add_cell("婚姻状况："+tbUserBasicInfo.getMarriageDesc(), 10));
        basicInfo.addCell(add_cell("国籍："+tbUserBasicInfo.getNationalityDesc(), 10));
        basicInfo.addCell(add_cell("宗教信仰："+tbUserBasicInfo.getReligiousBeliefDesc(), 10));
        basicInfo.addCell(add_cell("是否需要医疗帮助："+(
                ObjectUtils.isNotEmpty(tbUserBasicInfo.getNeedMedicalDesc()) ? tbUserBasicInfo.getNeedMedicalDesc() : "否"
                ), 10));

        document.add(basicInfo);
        //加入空行
        document.add(blankRow());
    }

    public void writeDetailInfo(Document document,TbUserDetailInfo tbUserDetailInfo) throws Exception {
        document.add(add_headtitle_1("详细信息"));
        //主体
        PdfPTable detailInfo = new PdfPTable(1);
        //配置单元格跨页显示
        detailInfo.setSplitLate(false);
        detailInfo.setSplitRows(true);

        int detailInfoTableWidth[] = {100};
        detailInfo.setWidths(detailInfoTableWidth);
        detailInfo.getDefaultCell().setBorder(0);

        detailInfo.addCell(add_cell("护照号："+(
                ObjectUtils.isNotEmpty(tbUserDetailInfo.getPassportNumber()) ? tbUserDetailInfo.getPassportNumber() :""
                ),10));
        detailInfo.addCell(add_cell("护照签发日期："+(
                ObjectUtils.isNotEmpty(tbUserDetailInfo.getPassportIssueDate()) ? tbUserDetailInfo.getPassportIssueDate() : ""
                ),10));
        detailInfo.addCell(add_cell("护照有效期至："+(
                ObjectUtils.isNotEmpty(tbUserDetailInfo.getPassportValid()) ? tbUserDetailInfo.getPassportValid() : ""
                ),10));
        detailInfo.addCell(add_cell("护照签发地："+(
                ObjectUtils.isNotEmpty(tbUserDetailInfo.getPassportIssuePlace()) ? tbUserDetailInfo.getPassportIssuePlace() : ""
                ),10));
        detailInfo.addCell(add_cell("身份证号："+tbUserDetailInfo.getIdCard(),10));
        detailInfo.addCell(add_cell("签证类型："+(
                ObjectUtils.isNotEmpty(tbUserDetailInfo.getVisaTypeDesc()) ? tbUserDetailInfo.getVisaTypeDesc()+""+
                        tbUserDetailInfo.getVisaTypeExplain() : ""
                ),10));
        detailInfo.addCell(add_cell("签证到期日期："+(
                ObjectUtils.isNotEmpty(tbUserDetailInfo.getVisaValid()) ? tbUserDetailInfo.getVisaValid() :""
                ),10));
        detailInfo.addCell(add_cell("电子邮箱："+tbUserDetailInfo.getEmail(),10));
        detailInfo.addCell(add_cell("家庭电话："+tbUserDetailInfo.getHomePhone(),10));
        detailInfo.addCell(add_cell("移动电话："+tbUserDetailInfo.getMobilephone(),10));
        detailInfo.addCell(add_cell("所在地区："+tbUserDetailInfo.getCountryProvinceCity(),10));
        detailInfo.addCell(add_cell("家庭详细地址："+tbUserDetailInfo.getAddress(),10));
        detailInfo.addCell(add_cell("邮编："+tbUserDetailInfo.getPostalCode(),10));

        document.add(detailInfo);
        //加入空行
        document.add(blankRow());
    }

    public void writeEducationInfo(Document document,List<TbUserEducationBackground> list) throws Exception {
        document.add(add_headtitle_1("教育背景"));
        document.add(blankRow(5));
        //主体 Begin
        for (TbUserEducationBackground educationBackground : list) {
            PdfPTable edu = new PdfPTable(1);
            // 实现单元格跨页显示
            edu.setSplitLate(false);
            edu.setSplitRows(true);
            int eduWidth[] = {100};
            edu.setWidths(eduWidth);
            edu.getDefaultCell().setBorder(0);
            edu.addCell(add_cell("学历类型："+educationBackground.getEducationTypeDesc(), 10));
            edu.addCell(add_cell("学校名称："+educationBackground.getSchoolName(), 10));
            edu.addCell(add_cell("专业名称："+educationBackground.getMajorName(), 10));
            edu.addCell(add_cell("成绩类型："+educationBackground.getScoreTypeDesc(), 10));
            edu.addCell(add_cell("分数："+educationBackground.getSumScore(), 10));
            edu.addCell(add_cell("入学时间："+educationBackground.getStartSchool(), 10));
            edu.addCell(add_cell("毕业时间："+educationBackground.getFinishSchool(), 10));
            edu.addCell(add_cell("学校所在地区："+educationBackground.getCountryProvinceCity(), 10));
            edu.addCell(add_cell("学校详细地址："+educationBackground.getSchoolAddress(), 10));
            edu.addCell(add_cell("邮编："+educationBackground.getPostalCode(), 10));
            document.add(edu);
            //加入空行
            document.add(blankRow(10));
        }
        document.add(blankRow(30));
    }

    public void writeWorkInfo(Document document,List<TbUserWorkExperience> list) throws Exception {
        document.add(add_headtitle_1("工作经历"));
        document.add(blankRow(5));
        for (TbUserWorkExperience userWorkExperience : list) {
            PdfPTable workExpTable = new PdfPTable(1);
            // 实现单元格跨页显示
            workExpTable.setSplitLate(false);
            workExpTable.setSplitRows(true);
            int workExpTableWidth[] = {100};
            workExpTable.setWidths(workExpTableWidth);
            workExpTable.getDefaultCell().setBorder(0);
            workExpTable.addCell(add_cell("企业名称："+userWorkExperience.getEnterpriseName(), 10));
            workExpTable.addCell(add_cell("职位名称："+userWorkExperience.getPositionName(), 10));
            workExpTable.addCell(add_cell("入职时间："+userWorkExperience.getStartTime(), 10));
            workExpTable.addCell(add_cell("离职时间："+userWorkExperience.getEndTime(), 10));

            document.add(workExpTable);
            document.add(blankRow(5));
        }
        document.add(blankRow());
    }

    public void writeLanguageInfo(Document document,TbUserLanguageBackground userLanguageBackground) throws Exception {
        document.add(add_headtitle_1("语言背景"));
        document.add(blankRow(5));

        PdfPTable language = new PdfPTable(1);
        // 实现单元格跨页显示
        language.setSplitLate(false);
        language.setSplitRows(true);
        int workExpTableWidth[] = {100};
        language.setWidths(workExpTableWidth);
        language.getDefaultCell().setBorder(0);

        language.addCell(add_cell("考试类型："+userLanguageBackground.getExamTypeDesc(), 10));
        language.addCell(add_cell("考试成绩："+userLanguageBackground.getExamScore(), 10));
        language.addCell(add_cell("考试时间："+userLanguageBackground.getExamTime(), 10));
        language.addCell(add_cell("成绩到期时间："+userLanguageBackground.getScoreExpire(), 10));

        document.add(language);
        document.add(blankRow());
    }

    public void writeParentInfo(Document document,List<TbUserParentInfo> list) throws Exception {
        document.add(add_headtitle_1("父母信息"));
        document.add(blankRow(5));
        for (TbUserParentInfo parentInfo : list) {
            PdfPTable parent = new PdfPTable(1);
            //配置单元格跨页显示
            parent.setSplitLate(false);
            parent.setSplitRows(true);
            int workExpTableWidth[] = {100};
            parent.setWidths(workExpTableWidth);
            parent.getDefaultCell().setBorder(0);
            parent.addCell(add_cell("姓名："+parentInfo.getParentName(),10));
            parent.addCell(add_cell("关系："+parentInfo.getParentRelation(),10));
            parent.addCell(add_cell("职位："+parentInfo.getParentPosition(),10));
            parent.addCell(add_cell("护照号："+parentInfo.getParentPassportNumber(),10));
            parent.addCell(add_cell("电子邮箱："+parentInfo.getParentEmail(),10));
            parent.addCell(add_cell("移动电话："+parentInfo.getParentMobilephone(),10));
            parent.addCell(add_cell("所在地区："+parentInfo.getParentCountryProvinceCity(),10));
            parent.addCell(add_cell("详细地址："+parentInfo.getParentAddress(),10));
            parent.addCell(add_cell("邮编："+parentInfo.getParentPostal(),10));

            document.add(parent);
            document.add(blankRow(5));
        }
        document.add(blankRow());
    }

    private void convertBasicInfo(TbUserBasicInfo tbUserBasicInfo1){
        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getSex())){
            tbUserBasicInfo1.setSexDesc(DictUtils.getDictLabel(Constants.SYS_USER_SEX,tbUserBasicInfo1.getSex()));
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getMarriage())){
            tbUserBasicInfo1.setMarriageDesc(
                    DictUtils.getDictLabel(
                            Constants.BUSINESS_MARRIAGE_STATUS,tbUserBasicInfo1.getMarriage()
                    )
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getReligiousBelief())){
            tbUserBasicInfo1.setReligiousBeliefDesc(
                    DictUtils.getDictLabel(Constants.BUSINESS_RELIGION_TYPE,tbUserBasicInfo1.getReligiousBelief())
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getBirthdayYear())){
            tbUserBasicInfo1.setBirthday(
                    tbUserBasicInfo1.getBirthdayYear()+"."+
                            tbUserBasicInfo1.getBirthdayMonth()+"."+
                            tbUserBasicInfo1.getBirthdayDay()
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getCall())){
            tbUserBasicInfo1.setCallDesc(
                    DictUtils.getDictLabel(
                            Constants.BUSINESS_CALL_TYPE,tbUserBasicInfo1.getCall()
                    )
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getNationality())){
            tbUserBasicInfo1.setNationalityDesc(
                    String.valueOf(
                            CacheUtils.get(
                                    Constants.BUSINESS_REGION_CACHE,
                                    Constants.BUSINESS_REGION_KEY+tbUserBasicInfo1.getNationality()
                            )
                    )
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getNeedMedical())){
            tbUserBasicInfo1.setNeedMedical( DictUtils.getDictLabel(
                    Constants.SYS_YES_NO,tbUserBasicInfo1.getNeedMedical()
            ));
        }

    }

    private void convertDetailInfo(TbUserDetailInfo tbUserDetailInfo){
        if(ObjectUtils.isNotEmpty(tbUserDetailInfo.getHoldPassport())){
            tbUserDetailInfo.setHoldPassportDesc(DictUtils.getDictLabel(
                    Constants.SYS_YES_NO,tbUserDetailInfo.getHoldPassport()
            ));
            if(tbUserDetailInfo.getHoldPassport().equals(Constants.YES)){
                tbUserDetailInfo.setPassportIssueDate(
                        tbUserDetailInfo.getPassportIssueDateYear()+"."+
                                tbUserDetailInfo.getPassportIssueDateMonth()+"."+
                                tbUserDetailInfo.getPassportIssueDateDay()
                );
                tbUserDetailInfo.setPassportValid(
                        tbUserDetailInfo.getPassportValidYear()+"."+
                                tbUserDetailInfo.getPassportValidMonth()+"."+
                                tbUserDetailInfo.getPassportValidDay()
                );
            }
        }

        if(ObjectUtils.isNotEmpty(tbUserDetailInfo.getHoldVisa())){
            tbUserDetailInfo.setHoldVisaDesc(
                    DictUtils.getDictLabel(
                            Constants.SYS_YES_NO,tbUserDetailInfo.getHoldVisa()
                    )
            );
            if(tbUserDetailInfo.getHoldVisa().equals(Constants.YES)){
                tbUserDetailInfo.setVisaTypeDesc(
                        DictUtils.getDictLabel(Constants.BUSINESS_VISA_TYPE,tbUserDetailInfo.getVisaType())
                );
                tbUserDetailInfo.setVisaValid(
                        tbUserDetailInfo.getVisaValidYear()+"."+
                                tbUserDetailInfo.getVisaValidMonth()+"."+
                                tbUserDetailInfo.getVisaValidDay()
                );
            }
        }

        if(ObjectUtils.isNotEmpty(tbUserDetailInfo.getCountry())){
            tbUserDetailInfo.setCountryDesc(
                    String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,Constants.BUSINESS_REGION_KEY+tbUserDetailInfo.getCountry()))
            );
            tbUserDetailInfo.setCountryCode(
                    tbUserDetailInfo.getCountry()
            );
            String str=String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,Constants.BUSINESS_REGION_KEY+tbUserDetailInfo.getProvince()));
            tbUserDetailInfo.setProvinceDesc(
                    str.equals("null") ? "" : str
            );
            tbUserDetailInfo.setProvinceCode(
                    tbUserDetailInfo.getProvince()
            );
            String str1=String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,Constants.BUSINESS_REGION_KEY+tbUserDetailInfo.getCity()));
            tbUserDetailInfo.setCityDesc(
                    str1.equals("null") ? "" : str1
            );
            tbUserDetailInfo.setCityCode(
                    tbUserDetailInfo.getCity()
            );
            tbUserDetailInfo.setCountryProvinceCity(
                    tbUserDetailInfo.getCountryDesc()+
                            (ObjectUtils.isNotEmpty(tbUserDetailInfo.getProvinceDesc()) ? tbUserDetailInfo.getProvinceDesc() : "")+
                            (ObjectUtils.isNotEmpty(tbUserDetailInfo.getCityDesc()) ? tbUserDetailInfo.getCityDesc() : "")
            );
        }
    }

    private void convertEducationInfo(TbUserEducationBackground userEducationBackground){
        userEducationBackground.setEducationTypeDesc(
                DictUtils.getDictLabel(Constants.BUSINESS_EDUCATION_TYPE,userEducationBackground.getEducationType())
        );
        userEducationBackground.setScoreTypeDesc(
                DictUtils.getDictLabel(Constants.BUSINESS_SCORE_TYPE,userEducationBackground.getScoreType())
        );
        if(StringUtils.isNotNull(userEducationBackground.getGpaType()) && StringUtils.isNotEmpty(userEducationBackground.getGpaType())){
            userEducationBackground.setGpaTypeDesc(
                    DictUtils.getDictLabel(
                            Constants.BUSINESS_GPA_TYPE,userEducationBackground.getGpaType()
                    )
            );
            userEducationBackground.setScoreTypeDesc(
                    userEducationBackground.getScoreTypeDesc()+" "+
                            userEducationBackground.getGpaTypeDesc()
            );
        }
        userEducationBackground.setCountryDesc(
                String.valueOf(
                        CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                                Constants.BUSINESS_REGION_KEY+userEducationBackground.getCountry()))
        );
        userEducationBackground.setCountryCode(userEducationBackground.getCountry());
        String str1=String.valueOf(
                CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+userEducationBackground.getProvince())
        );
        userEducationBackground.setProvinceDesc(
                str1.equals("null") ? "" :str1
        );
        userEducationBackground.setProvinceCode(userEducationBackground.getProvince());
        String str=String.valueOf(
                CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+userEducationBackground.getCity())
        );
        userEducationBackground.setCityDesc(
                str.equals("null") ? " " : str
        );
        userEducationBackground.setCityCode(userEducationBackground.getCity());
        userEducationBackground.setCountryProvinceCity(
                userEducationBackground.getCountryDesc()+
                        (ObjectUtils.isNotEmpty(userEducationBackground.getProvinceDesc()) ? userEducationBackground.getProvinceDesc() : "")+
                        (ObjectUtils.isNotEmpty(userEducationBackground.getCityDesc()) ? userEducationBackground.getCityDesc() : "")
        );
        userEducationBackground.setStartSchool(
                userEducationBackground.getStartSchoolYear()+"."+
                        userEducationBackground.getStartSchoolMonth()
        );
        userEducationBackground.setFinishSchool(
                userEducationBackground.getFinishSchoolYear()+"."+
                        userEducationBackground.getFinishSchoolMonth()
        );
    }

    private void convertLanguageInfo(TbUserLanguageBackground tbUserLanguageBackground){
        if(StringUtils.isNotEmpty(tbUserLanguageBackground.getExamType())){
            if(StringUtils.isNotNull(tbUserLanguageBackground.getSpecialExamType()) && StringUtils.isNotEmpty(tbUserLanguageBackground.getSpecialExamType())){
                tbUserLanguageBackground.setExamTypeDesc(tbUserLanguageBackground.getSpecialExamType());
            }else{
                tbUserLanguageBackground.setExamTypeDesc(
                        DictUtils.getDictLabel(
                                Constants.BUSINESS_LANGUAGE_EXAM_TYPE,
                                tbUserLanguageBackground.getExamType()
                        )
                );
            }
            tbUserLanguageBackground.setExamTypeCode(tbUserLanguageBackground.getExamType());
            tbUserLanguageBackground.setExamTime(
                    tbUserLanguageBackground.getExamTimeYear()+"."+
                            tbUserLanguageBackground.getExamTimeMonth()+"."+
                            tbUserLanguageBackground.getExamTimeDay()
            );
            tbUserLanguageBackground.setScoreExpire(
                    tbUserLanguageBackground.getScoreExpireYear()+"."+
                            tbUserLanguageBackground.getScoreExpireMonth()+"."+
                            tbUserLanguageBackground.getScoreExpireDay()
            );
        }
    }

    private void convertWorkExperience(TbUserWorkExperience workExperience){
        workExperience.setStartTime(
                workExperience.getStartTimeYear()+"."+
                workExperience.getStartTimeMonth()+"."+
                workExperience.getStartTimeDay());
        if(ObjectUtils.isNotEmpty(workExperience.getEndTimeYear())){
            workExperience.setEndTime(
                    workExperience.getEndTimeYear()+"."+
                    workExperience.getEndTimeMonth()+"."+
                    workExperience.getEndTimeDay()
            );
        }else{
            workExperience.setEndTime("至今");
        }
    }

    private void convertParentInfo(TbUserParentInfo parentInfo){
        parentInfo.setParentCountryCode(parentInfo.getParentCountry());
        parentInfo.setParentProvinceCode(parentInfo.getParentProvince());
        parentInfo.setParentCityCode(parentInfo.getParentCity());

        parentInfo.setParentCountryDesc(
                String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+parentInfo.getParentCountry()))
        );
        String str= String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                Constants.BUSINESS_REGION_KEY+parentInfo.getParentProvince()));
        parentInfo.setParentProvinceDesc(
               str.equals("null") ? "" : str
        );

        String str1=String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                Constants.BUSINESS_REGION_KEY+parentInfo.getParentCity()));
        parentInfo.setParentCityDesc(
                str1.equals("null") ? "" : str1
        );
        parentInfo.setParentCountryProvinceCity(
                parentInfo.getParentCountryDesc()+
                        (ObjectUtils.isNotEmpty(parentInfo.getParentProvinceDesc()) ? parentInfo.getParentProvinceDesc() :"")+
                        (ObjectUtils.isNotEmpty(parentInfo.getParentCityDesc()) ? parentInfo.getParentCityDesc() :"")
        );
    }

    private void convertMaterial(TbUserMaterial userMaterial){
        userMaterial.setMaterialTypeDesc(
                CacheUtils.get(Constants.BUSINESS_MATERIAL_TYPE_CACHE,userMaterial.getId()).toString()
        );
    }


    private static final String splitVline = "  |  ";
    private static final String TAB = "    ";
    //判断是否为16进制颜色
    public static boolean isHexColor(String color) {
        String HEX_PATTERN = "[0-9A-Fa-f]+";
        return color != null && color.length() == 6 && color.matches(HEX_PATTERN);
    }
    //将16进制颜色转换为Color对象
    private static BaseColor myColor(String hexColor) {
        hexColor = hexColor.replace("#", "");
        if(hexColor.length()==3) {
            hexColor = hexColor+hexColor;
        }
        if(!isHexColor(hexColor)) {
            hexColor = "ffffff";
        }
        int r= Integer.valueOf( hexColor.substring( 0, 2 ), 16 );
        int g= Integer.valueOf( hexColor.substring( 2, 4 ), 16 );
        int b= Integer.valueOf( hexColor.substring( 4, 6 ), 16 );
        return new BaseColor(r,g,b);
    }
    /**
     * 设置字体，及大小
     * @param size
     * @param style
     * @return
     * @throws DocumentException
     * @throws IOException
     */
    private Font myfont(float size,int style) throws DocumentException, IOException {
        BaseFont bfChinese = BaseFont.createFont(RuoYiConfig.getFontpath()+",0",BaseFont.IDENTITY_H, BaseFont.EMBEDDED);//C:/Windows/Fonts/simsun.ttc
        com.itextpdf.text.Font myFont = new com.itextpdf.text.Font(bfChinese, size, style);
        return myFont;
    }
    private Font myfont(float size,int style,String color) throws DocumentException, IOException {
        BaseFont bfChinese = BaseFont.createFont(RuoYiConfig.getFontpath()+",0",BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
        com.itextpdf.text.Font myFont = new com.itextpdf.text.Font(bfChinese, size, style);
        myFont.setColor(myColor(color));
        return myFont;
    }
    /**
     * 标题一
     * @param text
     * @return
     * @throws DocumentException
     * @throws IOException
     */
    private Paragraph h1(String text) throws DocumentException, IOException {
        Paragraph p = new Paragraph(text,myfont(16,Font.BOLD));
        return p;
    }
    /**
     * 带前导图的标题
     * @param text 标题文字
     * @return
     * @throws Exception
     */
    private PdfPTable add_headtitle_1(String text) throws Exception{
        PdfPTable table = new PdfPTable(2);
        // 实现单元格跨页显示
        table.setSplitLate(false);
        table.setSplitRows(true);
        //设置每列宽度比例
        int width_ht1[] = {2,98};
        table.setWidths(width_ht1);
        table.getDefaultCell().setBorder(0);
        //带前导图(方法2)用Java画
        BufferedImage image = new BufferedImage(2, 11,BufferedImage.TYPE_INT_RGB);
        Graphics g = image.getGraphics();
        g.setColor(new Color(83, 202, 195)); // #53cac3
        g.fillRect(0, 0, 2, 11);
        Image image21 = Image.getInstance(image,null);

        PdfPCell cellHt1img=new PdfPCell();
        cellHt1img.setBorder(0);
        cellHt1img.setImage(image21);
        cellHt1img.setFixedHeight(1);
        cellHt1img.setPaddingTop(5);
        PdfPCell cellHt1Content = new PdfPCell(h1(text));
        cellHt1Content.setBorder(0);
        table.addCell(cellHt1img);
        table.addCell(cellHt1Content);
        return table;
    }
    private Paragraph blankRow() throws Exception{
        Paragraph blankRow = new Paragraph(20f, " ", myfont(20,Font.BOLD));
        return blankRow;
    }
    /**
     * 空行
     * @param leading 行间距
     * @return
     * @throws Exception
     */
    private Paragraph blankRow(float leading) throws Exception{
        Paragraph blankRow = new Paragraph(leading, " ", myfont(20,Font.BOLD));
        return blankRow;
    }
    private PdfPCell add_cell(Object obj,float lead) throws Exception{
        PdfPCell cell = new PdfPCell(new Paragraph(obj+"",myfont(12,Font.NORMAL)));
        cell.setBorder(0);
        cell.setLeading(lead, 1);
        return cell;
    }
    private PdfPCell add_cell(Object obj,float lead,int size) throws Exception{
        PdfPCell cell = new PdfPCell(new Paragraph(obj+"",myfont(size,Font.NORMAL)));
        cell.setBorder(0);
        cell.setLeading(lead, 1);
        return cell;
    }
    private PdfPCell add_cell(Object obj,String color,float lead) throws Exception{
        color = color==null?"#000000":color;
        PdfPCell cell = new PdfPCell(new Paragraph(obj+"",myfont(12,Font.NORMAL,color)));
        cell.setBorder(0);
        cell.setLeading(lead, 1);
        return cell;
    }
    private PdfPCell add_cell(Object obj, TBCell tbCell) throws Exception{
        PdfPCell cell = new PdfPCell(new Paragraph(obj+"",myfont(tbCell.getFontSize(),tbCell.getFontStyle(),tbCell.getTextColor())));
        cell.setBorder(tbCell.getBorder());
        cell.setLeading(tbCell.getLead(), 1);
        if(tbCell.getBgcolor()!=null && !"".equals(tbCell.getBgcolor())) {
            cell.setBackgroundColor(myColor(tbCell.getBgcolor()));
        }
        if(tbCell.getColspan()!=0) {
            cell.setColspan(tbCell.getColspan());
        }
        if(tbCell.getRowspan()!=0) {
            cell.setRowspan(tbCell.getRowspan());
        }
        if(tbCell.getBorderColor()!=null && !"".equals(tbCell.getBorderColor())) {
            cell.setBorderColor(myColor(tbCell.getBorderColor()));
        }
        if(tbCell.getIndent()>0) {
            cell.setIndent(tbCell.getIndent());
        }
        return cell;
    }
    private PdfPCell add_cell_speace(TBCell tbCell) throws Exception{
        PdfPCell cell = new PdfPCell(new Paragraph(" ",myfont(tbCell.getFontSize(),tbCell.getFontStyle(),tbCell.getTextColor())));
        cell.setBorder(tbCell.getBorder());
        cell.setLeading(tbCell.getLead(), 1);
        if(tbCell.getBgcolor()!=null && !"".equals(tbCell.getBgcolor())) {
            cell.setBackgroundColor(myColor(tbCell.getBgcolor()));
        }
        if(tbCell.getColspan()!=0) {
            cell.setColspan(tbCell.getColspan());
        }
        if(tbCell.getRowspan()!=0) {
            cell.setRowspan(tbCell.getRowspan());
        }
        if(tbCell.getBorderColor()!=null && !"".equals(tbCell.getBorderColor())) {
            cell.setBorderColor(myColor(tbCell.getBorderColor()));
        }
        if(tbCell.getIndent()>0) {
            cell.setIndent(tbCell.getIndent());
        }
        return cell;
    }
}
