package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.List;

import cn.hutool.core.util.ObjectUtil;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.ShiroUtils;
import com.ruoyi.system.domain.TbConsultant;
import com.ruoyi.system.domain.TbUser;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.system.mapper.TbConsultantMapper;
import com.ruoyi.system.mapper.TbUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbConsultantChangeMapper;
import com.ruoyi.system.domain.TbConsultantChange;
import com.ruoyi.system.service.ITbConsultantChangeService;
import com.ruoyi.common.core.text.Convert;

import javax.annotation.Resource;

/**
 * 顾问变更申请Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
@Service
public class TbConsultantChangeServiceImpl implements ITbConsultantChangeService 
{
    @Autowired
    private TbConsultantChangeMapper tbConsultantChangeMapper;
    @Resource
    private SysUserMapper sysUserMapper;
    @Resource
    private TbConsultantMapper consultantMapper;
    @Resource
    private TbUserMapper tbUserMapper;

    /**
     * 查询顾问变更申请
     * 
     * @param id 顾问变更申请主键
     * @return 顾问变更申请
     */
    @Override
    public TbConsultantChange selectTbConsultantChangeById(Long id)
    {
        TbConsultantChange tbConsultantChange = tbConsultantChangeMapper.selectTbConsultantChangeById(id);
        SysUser sysUser = sysUserMapper.selectUserById(tbConsultantChange.getChangeProposer());
        tbConsultantChange.setChangeProposerDesc(sysUser.getUserName());

        TbConsultant consultant = consultantMapper.selectTbConsultantById(tbConsultantChange.getOriginalConsultant());
        tbConsultantChange.setOriginalConsultantDesc(consultant.getConsultantName());

        TbConsultant consultant1 = consultantMapper.selectTbConsultantById(tbConsultantChange.getNewConsultant());
        tbConsultantChange.setNewConsultantDesc(consultant1.getConsultantName());

        TbUser tbUser = tbUserMapper.selectTbUserById(tbConsultantChange.getChangeUser());
        tbConsultantChange.setChangeUserDesc(tbUser.getUsername());
        return tbConsultantChange;
    }

    /**
     * 查询顾问变更申请列表
     * 
     * @param tbConsultantChange 顾问变更申请
     * @return 顾问变更申请
     */
    @Override
    public List<TbConsultantChange> selectTbConsultantChangeList(TbConsultantChange tbConsultantChange)
    {
        if(ObjectUtil.isNotNull(tbConsultantChange.getChangeProposerDesc()) && ObjectUtil.isNotEmpty(tbConsultantChange.getChangeProposerDesc())){
            SysUser su=new SysUser();
            su.setUserName(tbConsultantChange.getChangeProposerDesc());
            List<SysUser> sysUsers = sysUserMapper.selectUserList(su);
            if(ObjectUtil.isNotNull(sysUsers) && !sysUsers.isEmpty()){
                SysUser sysUser = sysUsers.get(0);
                tbConsultantChange.setChangeProposer(sysUser.getUserId());
            }else{
                return new ArrayList<TbConsultantChange>();
            }
        }

        if(ObjectUtil.isNotNull(tbConsultantChange.getChangeUserDesc()) && ObjectUtil.isNotEmpty(tbConsultantChange.getChangeUserDesc())){
            TbUser user=new TbUser();
            user.setUsername(tbConsultantChange.getChangeUserDesc());
            List<TbUser> tbUsers = tbUserMapper.selectTbUserList(user);
            if(ObjectUtil.isNotNull(tbUsers) && !tbUsers.isEmpty()){
                TbUser tbUser = tbUsers.get(0);
                tbConsultantChange.setChangeUser(tbUser.getId());
            }else{
                return new ArrayList<TbConsultantChange>();
            }
        }

        List<TbConsultantChange> tbConsultantChanges = tbConsultantChangeMapper.selectTbConsultantChangeList(tbConsultantChange);
        tbConsultantChanges.stream().forEach(tbConsultantChange1 -> {
            if(ObjectUtil.isNotNull(tbConsultantChange1.getExamineUser()) && ObjectUtil.isNotEmpty(tbConsultantChange1.getExamineUser())){
                SysUser sysUser = sysUserMapper.selectUserById(tbConsultantChange1.getExamineUser());
                tbConsultantChange1.setExamineUserDesc(sysUser.getUserName());
            }
            //审批结果，0 未通过，1 通过，2 待审批
            if(tbConsultantChange1.getExamineResult().equals(Constants.SUCCESS)){
                tbConsultantChange1.setExamineResultDesc("未通过审批");
            }else if(tbConsultantChange1.getExamineResult().equals(Constants.FAIL)){
                tbConsultantChange1.setExamineResultDesc("审批通过");
            }else{
                tbConsultantChange1.setExamineResultDesc("待审批");
            }
            SysUser sysUser = sysUserMapper.selectUserById(tbConsultantChange1.getChangeProposer());
            tbConsultantChange1.setChangeProposerDesc(sysUser.getUserName());

            TbConsultant consultant = consultantMapper.selectTbConsultantById(tbConsultantChange1.getOriginalConsultant());
            tbConsultantChange1.setOriginalConsultantDesc(consultant.getConsultantName());

            TbConsultant consultant1 = consultantMapper.selectTbConsultantById(tbConsultantChange1.getNewConsultant());
            tbConsultantChange1.setNewConsultantDesc(consultant1.getConsultantName());

            TbUser tbUser = tbUserMapper.selectTbUserById(tbConsultantChange1.getChangeUser());
            tbConsultantChange1.setChangeUserDesc(tbUser.getUsername());

        });
        return tbConsultantChanges;
    }

    /**
     * @Author : fanxiaolong
     * @Description : 查询待审核的申请
     * @DateTime : 2023/8/4 17:09
     * @param : tbConsultantChange
     * @return : java.util.List<com.ruoyi.system.domain.TbConsultantChange>
     */
    @Override
    public List<TbConsultantChange> selectTbConsultantChangeCheckList(TbConsultantChange tbConsultantChange){

        List<TbConsultantChange> tbConsultantChanges = tbConsultantChangeMapper.selectTbConsultantChangeCheckList(tbConsultantChange);
        tbConsultantChanges.stream().forEach(tbConsultantChange1 -> {
            if(ObjectUtil.isNotNull(tbConsultantChange1.getExamineUser()) && ObjectUtil.isNotEmpty(tbConsultantChange1.getExamineUser())){
                SysUser sysUser = sysUserMapper.selectUserById(tbConsultantChange1.getExamineUser());
                tbConsultantChange1.setExamineUserDesc(sysUser.getUserName());
            }
            //审批结果，0 未通过，1 通过，2 待审批
            if(tbConsultantChange1.getExamineResult().equals(Constants.SUCCESS)){
                tbConsultantChange1.setExamineResultDesc("未通过审批");
            }else if(tbConsultantChange1.getExamineResult().equals(Constants.FAIL)){
                tbConsultantChange1.setExamineResultDesc("审批通过");
            }else{
                tbConsultantChange1.setExamineResultDesc("待审批");
            }
            SysUser sysUser = sysUserMapper.selectUserById(tbConsultantChange1.getChangeProposer());
            tbConsultantChange1.setChangeProposerDesc(sysUser.getUserName());

            TbConsultant consultant = consultantMapper.selectTbConsultantById(tbConsultantChange1.getOriginalConsultant());
            tbConsultantChange1.setOriginalConsultantDesc(consultant.getConsultantName());

            TbConsultant consultant1 = consultantMapper.selectTbConsultantById(tbConsultantChange1.getNewConsultant());
            tbConsultantChange1.setNewConsultantDesc(consultant1.getConsultantName());

            TbUser tbUser = tbUserMapper.selectTbUserById(tbConsultantChange1.getChangeUser());
            tbConsultantChange1.setChangeUserDesc(tbUser.getUsername());

        });
        return tbConsultantChanges;
    }

    /**
     * 新增顾问变更申请
     * 
     * @param tbConsultantChange 顾问变更申请
     * @return 结果
     */
    @Override
    public int insertTbConsultantChange(TbConsultantChange tbConsultantChange)
    {
        tbConsultantChange.setChangeProposer(ShiroUtils.getUserId());
        SysUser sysUser = sysUserMapper.selectUserByLoginName(Constants.BOSS_NAME);
        tbConsultantChange.setExamineUser(sysUser.getUserId());
        return tbConsultantChangeMapper.insertTbConsultantChange(tbConsultantChange);
    }

    /**
     * 修改顾问变更申请
     * 
     * @param tbConsultantChange 顾问变更申请
     * @return 结果
     */
    @Override
    public int updateTbConsultantChange(TbConsultantChange tbConsultantChange)
    {
        //如果审批通过，修改tb_user表
        if(ObjectUtil.isNotNull(tbConsultantChange.getExamineResult()) && tbConsultantChange.getExamineResult().equals(Constants.FAIL)){
            TbUser tbUser=new TbUser();
            tbUser.setId(tbConsultantChange.getChangeUser());
            tbUser.setConsultant(tbConsultantChange.getNewConsultant());
            tbUserMapper.updateTbUser(tbUser);
        }else{
            tbConsultantChange.setExamineResult("2");
        }
        return tbConsultantChangeMapper.updateTbConsultantChange(tbConsultantChange);
    }

    /**
     * 批量删除顾问变更申请
     * 
     * @param ids 需要删除的顾问变更申请主键
     * @return 结果
     */
    @Override
    public int deleteTbConsultantChangeByIds(String ids)
    {
        return tbConsultantChangeMapper.deleteTbConsultantChangeByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除顾问变更申请信息
     * 
     * @param id 顾问变更申请主键
     * @return 结果
     */
    @Override
    public int deleteTbConsultantChangeById(Long id)
    {
        return tbConsultantChangeMapper.deleteTbConsultantChangeById(id);
    }
}
