package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.mapper.SysUserMapper;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbInformationPlatformMapper;
import com.ruoyi.system.domain.TbInformationPlatform;
import com.ruoyi.system.service.ITbInformationPlatformService;
import com.ruoyi.common.core.text.Convert;

import javax.annotation.Resource;

/**
 * 海外国家人文，交通，饮食信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-02-29
 */
@Service
public class TbInformationPlatformServiceImpl implements ITbInformationPlatformService 
{
    @Autowired
    private TbInformationPlatformMapper tbInformationPlatformMapper;
    @Autowired
    private CommonServiceImpl commonService;
    @Resource
    private SysUserMapper sysUserMapper;

    /**
     * 查询海外国家人文，交通，饮食信息
     * 
     * @param id 海外国家人文，交通，饮食信息主键
     * @return 海外国家人文，交通，饮食信息
     */
    @Override
    public TbInformationPlatform selectTbInformationPlatformById(Long id)
    {
        TbInformationPlatform platform = tbInformationPlatformMapper.selectTbInformationPlatformById(id);
        List<SysDictData> dictCache = DictUtils.getDictCache("business_content_type");
        SysDictData sysDictData = dictCache.stream().filter(sysDictData1 -> {
            if(sysDictData1.getDictValue().equals(platform.getContentType())){
                return true;
            }
            return false;
        }).findFirst().get();
        platform.setContentTypeDesc(sysDictData.getDictLabel());
        return platform;
    }

    /**
     * 查询海外国家人文，交通，饮食信息列表
     * 
     * @param tbInformationPlatform 海外国家人文，交通，饮食信息
     * @return 海外国家人文，交通，饮食信息
     */
    @Override
    public List<TbInformationPlatform> selectTbInformationPlatformList(TbInformationPlatform tbInformationPlatform)
    {
        List<TbInformationPlatform> list = tbInformationPlatformMapper.selectTbInformationPlatformList(tbInformationPlatform);
        if(ObjectUtils.isNotEmpty(list)){
            List<SysDictData> dictCache = DictUtils.getDictCache("business_content_type");
            list.stream().forEach(platform -> {
                platform.setCreateBy(commonService.getUserName(platform.getCreator()));
                SysDictData sysDictData = dictCache.stream().filter(sysDictData1 -> {
                    if(sysDictData1.getDictValue().equals(platform.getContentType())){
                        return true;
                    }
                    return false;
                }).findFirst().get();
                platform.setContentType(sysDictData.getDictLabel());
            });
        }
        return list;
    }

    @Override
    public List<TbInformationPlatform> selectTbInformationPlatformNotPassList(TbInformationPlatform tbInformationPlatform){
        List<TbInformationPlatform> list = tbInformationPlatformMapper.selectTbInformationPlatformNotPassList(tbInformationPlatform);
        if(ObjectUtils.isNotEmpty(list)){
            List<SysDictData> dictCache = DictUtils.getDictCache("business_content_type");
            list.stream().forEach(platform -> {
//                platform.setCreateBy(commonService.getUserName(platform.getCreator()));
                SysDictData sysDictData = dictCache.stream().filter(sysDictData1 -> {
                    if(sysDictData1.getDictValue().equals(platform.getContentType())){
                        return true;
                    }
                    return false;
                }).findFirst().get();
                platform.setContentType(sysDictData.getDictLabel());
                convertCheckStatusToString(platform);
                convertUserIDToString(platform);
            });
        }
        return list;
    }

    /**
     * @Author : fanxiaolong
     * @Description :  学校审核状态转换成文字
     * @DateTime : 2022/9/2 16:51
     * @param : tbSchool
     * @param : dictDataList
     * @return : void
     */
    private void convertCheckStatusToString(TbInformationPlatform tbInformationPlatform){
        List<SysDictData> checkStatusList=DictUtils.getDictCache(Constants.BUSINESS_CHECK_STATUS);
        checkStatusList.stream().forEach(sysDictData -> {
            if(StringUtils.compare(String.valueOf(tbInformationPlatform.getCheckStatus()),sysDictData.getDictValue())==0){
                tbInformationPlatform.setCheckStatusDesc(sysDictData.getDictLabel());
            }
        });
    }

    /**
     * @Author : fanxiaolong
     * @Description :  转换userID为loginName
     * @DateTime : 2022/9/5 10:48
     * @param : tbSchool
     * @return : void
     */
    private void convertUserIDToString(TbInformationPlatform tbInformationPlatform){

        SysUser su=null;
        su=sysUserMapper.selectUserById(tbInformationPlatform.getCreator());
        tbInformationPlatform.setCreatorDesc(su.getLoginName());
        su=sysUserMapper.selectUserById(tbInformationPlatform.getModifiedBy());
        if(ObjectUtils.isNotEmpty(su)){
            tbInformationPlatform.setModifiedByDesc(su.getLoginName());
        }
        su=sysUserMapper.selectUserById(tbInformationPlatform.getChecker());
        if(ObjectUtils.isNotEmpty(su)){
            tbInformationPlatform.setCheckerDesc(su.getLoginName());
        }
    }

    /**
     * 新增海外国家人文，交通，饮食信息
     * 
     * @param tbInformationPlatform 海外国家人文，交通，饮食信息
     * @return 结果
     */
    @Override
    public int insertTbInformationPlatform(TbInformationPlatform tbInformationPlatform)
    {
        return tbInformationPlatformMapper.insertTbInformationPlatform(tbInformationPlatform);
    }

    /**
     * 修改海外国家人文，交通，饮食信息
     * 
     * @param tbInformationPlatform 海外国家人文，交通，饮食信息
     * @return 结果
     */
    @Override
    public int updateTbInformationPlatform(TbInformationPlatform tbInformationPlatform)
    {
        return tbInformationPlatformMapper.updateTbInformationPlatform(tbInformationPlatform);
    }

    /**
     * 批量删除海外国家人文，交通，饮食信息
     * 
     * @param ids 需要删除的海外国家人文，交通，饮食信息主键
     * @return 结果
     */
    @Override
    public int deleteTbInformationPlatformByIds(String ids)
    {
        return tbInformationPlatformMapper.deleteTbInformationPlatformByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除海外国家人文，交通，饮食信息信息
     * 
     * @param id 海外国家人文，交通，饮食信息主键
     * @return 结果
     */
    @Override
    public int deleteTbInformationPlatformById(Long id)
    {
        return tbInformationPlatformMapper.deleteTbInformationPlatformById(id);
    }

    @Override
    public int updateCheckStatus(TbInformationPlatform tbInformationPlatform){
        return tbInformationPlatformMapper.updateCheckStatus(tbInformationPlatform);
    }
}
