package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.TbSchool;
import com.ruoyi.system.mapper.TbSchoolMapper;
import com.ruoyi.system.req.TbNewsReq;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbNewsMapper;
import com.ruoyi.system.domain.TbNews;
import com.ruoyi.system.service.ITbNewsService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

/**
 * 新闻与活动Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-10-25
 */
@Service
public class TbNewsServiceImpl implements ITbNewsService 
{
    @Autowired
    private TbNewsMapper tbNewsMapper;

    @Resource
    private TbSchoolMapper tbSchoolMapper;

    @Autowired
    private CommonServiceImpl commonService;

    /**
     * 查询新闻与活动
     * 
     * @param id 新闻与活动主键
     * @return 新闻与活动
     */
    @Override
    public TbNews selectTbNewsById(Long id)
    {
        TbNews tn=tbNewsMapper.selectTbNewsById(id);
        tn.setCreatorDesc(commonService.getUserName(tn.getCreator()));
        if(ObjectUtils.isNotEmpty(tn.getModifiedBy())){
            tn.setModifiedByDesc(commonService.getUserName(tn.getModifiedBy()));
        }
        return tn;
    }

    /**
     * 查询新闻与活动列表
     * 
     * @param tbNews 新闻与活动
     * @return 新闻与活动
     */
    @Override
    public List<TbNews> selectTbNewsList(TbNews tbNews)
    {
        List<TbNews> list=tbNewsMapper.selectTbNewsList(tbNews);
        list.stream().filter(tbNews1 -> {
            tbNews1.setCreatorDesc(commonService.getUserName(tbNews1.getCreator()));
            if(ObjectUtils.isNotEmpty(tbNews1.getModifiedBy())){
                tbNews1.setModifiedByDesc(commonService.getUserName(tbNews1.getModifiedBy()));
            }
            return true;
        }).collect(Collectors.toList());
        return list;
    }

    /**
     * 新增新闻与活动
     * 
     * @param tbNews 新闻与活动
     * @return 结果
     */
    @Override
    public int insertTbNews(TbNewsReq tbNews)
    {
        if(tbNews.getNewsContent().contains(Constants.SERVERIP)){
            tbNews.setNewsContent(tbNews.getNewsContent().replace(Constants.SERVERIP,Constants.DOMAINNAME));
        }
        tbNews.setStatus(1);
        tbNews.setCreateTime(DateUtils.getNowDate());
        //判断该院校是否有多个分校，如果有，则将新闻一起复制到其他分校
        TbSchool tbSchool=new TbSchool();
        if(ObjectUtils.isNotEmpty(tbNews.getNewsSchoolCnName())){
            if(tbNews.getNewsSchoolCnName().contains("(")){
                tbSchool.setSchoolCnName(tbNews.getNewsSchoolCnName().split("\\(")[0]);
            }else{
                tbSchool.setSchoolCnName(tbNews.getNewsSchoolCnName());
            }
            List<TbSchool> tbSchools = tbSchoolMapper.selectTbSchoolList(tbSchool);
            if(tbSchools.size()>1){
                for(TbSchool tbSchool1 : tbSchools){
                    if(!tbSchool1.getId().equals(Long.valueOf(tbNews.getNewsSchool()))){
                        TbNews req=new TbNews();
                        BeanUtils.copyProperties(tbNews,req);
                        req.setNewsSchool(tbSchool1.getId().intValue());
                        tbNewsMapper.insertTbNews(req);
                    }
                }
            }
        }
        TbNews news1=new TbNews();
        BeanUtils.copyProperties(tbNews,news1);
        return tbNewsMapper.insertTbNews(news1);
    }

    /**
     * 修改新闻与活动
     * 
     * @param tbNews 新闻与活动
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTbNews(TbNews tbNews)
    {
        if(tbNews.getNewsContent().contains(Constants.SERVERIP)){
            tbNews.setNewsContent(tbNews.getNewsContent().replace(Constants.SERVERIP,Constants.DOMAINNAME));
        }
        tbNews.setUpdateTime(DateUtils.getNowDate());
        //判断该新闻是否有多条
        TbNews tbNews1=tbNewsMapper.selectTbNewsById(tbNews.getId());
        TbNews tbNews2=new TbNews();
        tbNews2.setNewsTitle(tbNews1.getNewsTitle());
        tbNews2.setNewsType(tbNews1.getNewsType());
        tbNews2.setNewsSummary(tbNews1.getNewsSummary());
        List<TbNews> list=tbNewsMapper.selectTbNewsList(tbNews2);
        for(TbNews tbNews3 : list){
            TbNews tbNews4=new TbNews();
            BeanUtils.copyProperties(tbNews,tbNews4);
            tbNews4.setId(tbNews3.getId());
            tbNews4.setNewsSchool(tbNews3.getNewsSchool());
            tbNewsMapper.updateTbNews(tbNews4);
        }
        return 1;
    }

    /**
     * 批量删除新闻与活动
     * 
     * @param ids 需要删除的新闻与活动主键
     * @return 结果
     */
    @Override
    public int deleteTbNewsByIds(String ids)
    {
        return tbNewsMapper.deleteTbNewsByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除新闻与活动信息
     * 
     * @param id 新闻与活动主键
     * @return 结果
     */
    @Override
    public int deleteTbNewsById(Long id)
    {
        return tbNewsMapper.deleteTbNewsById(id);
    }
}
