package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.CacheUtils;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbRegionMapper;
import com.ruoyi.system.domain.TbRegion;
import com.ruoyi.system.service.ITbRegionService;
import com.ruoyi.common.core.text.Convert;

import javax.annotation.PostConstruct;

/**
 * 区划管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-01-03
 */
@Service
public class TbRegionServiceImpl implements ITbRegionService 
{
    @Autowired
    private TbRegionMapper tbRegionMapper;

    /**
     * 项目启动时，初始化参数到缓存
     */
    @PostConstruct
    public void init()
    {
        loadingRegionCache();
    }

    /**
     * 查询区划管理
     * 
     * @param id 区划管理主键
     * @return 区划管理
     */
    @Override
    public TbRegion selectTbRegionById(Long id)
    {
        return tbRegionMapper.selectTbRegionById(id);
    }

    /**
     * 查询区划管理列表
     * 
     * @param tbRegion 区划管理
     * @return 区划管理
     */
    @Override
    public List<TbRegion> selectTbRegionList(TbRegion tbRegion)
    {
        return tbRegionMapper.selectTbRegionList(tbRegion);
    }

    /**
     * 新增区划管理
     * 
     * @param tbRegion 区划管理
     * @return 结果
     */
    @Override
    public int insertTbRegion(TbRegion tbRegion)
    {
        tbRegion.setCreateTime(DateUtils.getNowDate());
        return tbRegionMapper.insertTbRegion(tbRegion);
    }

    /**
     * 修改区划管理
     * 
     * @param tbRegion 区划管理
     * @return 结果
     */
    @Override
    public int updateTbRegion(TbRegion tbRegion)
    {
        tbRegion.setUpdateTime(DateUtils.getNowDate());
        return tbRegionMapper.updateTbRegion(tbRegion);
    }

    /**
     * 批量删除区划管理
     * 
     * @param ids 需要删除的区划管理主键
     * @return 结果
     */
    @Override
    public int deleteTbRegionByIds(String ids)
    {
        return tbRegionMapper.deleteTbRegionByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除区划管理信息
     * 
     * @param id 区划管理主键
     * @return 结果
     */
    @Override
    public int deleteTbRegionById(Long id)
    {
        return tbRegionMapper.deleteTbRegionById(id);
    }

    /**
     * 加载字典缓存数据
     */
    @Override
    public void loadingRegionCache(){
        List<TbRegion> list=tbRegionMapper.selectAllTbRegionList();
        for (TbRegion tbRegion : list)
        {
            CacheUtils.put(getCacheName(), getCacheKey(String.valueOf(tbRegion.getCode())), tbRegion.getName());
        }
    }

    /**
     * 获取cache name
     *
     * @return 缓存名
     */
    private String getCacheName()
    {
        return Constants.BUSINESS_REGION_CACHE;
    }

    /**
     * 设置cache key
     *
     * @param configKey 参数键
     * @return 缓存键key
     */
    private String getCacheKey(String configKey)
    {
        return Constants.BUSINESS_REGION_KEY + configKey;
    }
}
