package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.CacheUtils;
import com.ruoyi.common.utils.DictUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbUserBasicInfoMapper;
import com.ruoyi.system.domain.TbUserBasicInfo;
import com.ruoyi.system.service.ITbUserBasicInfoService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;

/**
 * 用户基本信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Service
public class TbUserBasicInfoServiceImpl implements ITbUserBasicInfoService 
{
    @Autowired
    private TbUserBasicInfoMapper tbUserBasicInfoMapper;

    /**
     * 查询用户基本信息
     * 
     * @param id 用户基本信息主键
     * @return 用户基本信息
     */
    @Override
    public TbUserBasicInfo selectTbUserBasicInfoById(Long id)
    {
        TbUserBasicInfo tbUserBasicInfo=tbUserBasicInfoMapper.selectTbUserBasicInfoById(id);
        convertInfo(tbUserBasicInfo);
        return tbUserBasicInfo;
    }

    @Override
    public TbUserBasicInfo selectTbUserBasicInfoByApplyId(String applyId){
        TbUserBasicInfo tbUserBasicInfo=tbUserBasicInfoMapper.selectTbUserBasicInfoByApplyId(applyId);
        convertInfo(tbUserBasicInfo);
        return tbUserBasicInfo;
    }
    /**
     * 查询用户基本信息列表
     * 
     * @param tbUserBasicInfo 用户基本信息
     * @return 用户基本信息
     */
    @Override
    public List<TbUserBasicInfo> selectTbUserBasicInfoList(TbUserBasicInfo tbUserBasicInfo)
    {
        List<TbUserBasicInfo> originalList=tbUserBasicInfoMapper.selectTbUserBasicInfoList(tbUserBasicInfo);
        originalList.stream().filter(tbUserBasicInfo1 -> {
            convertInfo(tbUserBasicInfo1);
            return true;
        }).collect(Collectors.toList());
        return originalList;
    }

    /**
     * 新增用户基本信息
     * 
     * @param tbUserBasicInfo 用户基本信息
     * @return 结果
     */
    @Override
    public int insertTbUserBasicInfo(TbUserBasicInfo tbUserBasicInfo)
    {
        return tbUserBasicInfoMapper.insertTbUserBasicInfo(tbUserBasicInfo);
    }

    /**
     * 修改用户基本信息
     * 
     * @param tbUserBasicInfo 用户基本信息
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTbUserBasicInfo(TbUserBasicInfo tbUserBasicInfo)
    {
        Long userid = tbUserBasicInfoMapper.selectTbUserBasicInfoById(tbUserBasicInfo.getId()).getUserid();
        TbUserBasicInfo tbUserBasicInfo1=tbUserBasicInfoMapper.selectTbUserBasicInfoByUserid(userid);
        TbUserBasicInfo userBasicInfo=new TbUserBasicInfo();
        //更新副本
        BeanUtils.copyProperties(tbUserBasicInfo,userBasicInfo);
        userBasicInfo.setId(tbUserBasicInfo1.getId());
        userBasicInfo.setApplyId(null);
        userBasicInfo.setFinishState(Constants.NO);
        userBasicInfo.setCountProgress(Constants.NO);
        userBasicInfo.setIsModify(Constants.YES);
        tbUserBasicInfoMapper.updateTbUserBasicInfo(userBasicInfo);

        return tbUserBasicInfoMapper.updateTbUserBasicInfo(tbUserBasicInfo);
    }

    /**
     * 批量删除用户基本信息
     * 
     * @param ids 需要删除的用户基本信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserBasicInfoByIds(String ids)
    {
        return tbUserBasicInfoMapper.deleteTbUserBasicInfoByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户基本信息信息
     * 
     * @param id 用户基本信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserBasicInfoById(Long id)
    {
        return tbUserBasicInfoMapper.deleteTbUserBasicInfoById(id);
    }

    private void convertInfo(TbUserBasicInfo tbUserBasicInfo1){
        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getSex())){
            tbUserBasicInfo1.setSexDesc(DictUtils.getDictLabel(Constants.SYS_USER_SEX,tbUserBasicInfo1.getSex()));
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getMarriage())){
            tbUserBasicInfo1.setMarriageDesc(
                    DictUtils.getDictLabel(
                            Constants.BUSINESS_MARRIAGE_STATUS,tbUserBasicInfo1.getMarriage()
                    )
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getReligiousBelief())){
            tbUserBasicInfo1.setReligiousBeliefDesc(
                    DictUtils.getDictLabel(Constants.BUSINESS_RELIGION_TYPE,tbUserBasicInfo1.getReligiousBelief())
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getBirthdayYear())){
            tbUserBasicInfo1.setBirthday(
                    tbUserBasicInfo1.getBirthdayYear()+"."+
                            tbUserBasicInfo1.getBirthdayMonth()+"."+
                            tbUserBasicInfo1.getBirthdayDay()
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getCall())){
            tbUserBasicInfo1.setCallDesc(
                    DictUtils.getDictLabel(
                            Constants.BUSINESS_CALL_TYPE,tbUserBasicInfo1.getCall()
                    )
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getNationality())){
            tbUserBasicInfo1.setNationalityDesc(
                    String.valueOf(
                            CacheUtils.get(
                                    Constants.BUSINESS_REGION_CACHE,
                                    Constants.BUSINESS_REGION_KEY+tbUserBasicInfo1.getNationality()
                            )
                    )
            );
        }

        if(ObjectUtils.isNotEmpty(tbUserBasicInfo1.getNeedMedical())){
            tbUserBasicInfo1.setNeedMedical( DictUtils.getDictLabel(
                    Constants.SYS_YES_NO,tbUserBasicInfo1.getNeedMedical()
            ));
        }

    }

    @Override
    public void updateModifyState(String applyId,String state){
        tbUserBasicInfoMapper.updateModifyState(state,applyId);
    }
}
