package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import cn.hutool.core.util.ObjectUtil;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.CacheUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.system.domain.TbConsultant;
import com.ruoyi.system.domain.TbUser;
import com.ruoyi.system.mapper.TbConsultantMapper;
import com.ruoyi.system.mapper.TbUserMapper;
import com.ruoyi.system.res.StudentInfo;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbUserDetailInfoMapper;
import com.ruoyi.system.domain.TbUserDetailInfo;
import com.ruoyi.system.service.ITbUserDetailInfoService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

/**
 * 用户详细信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Service
public class TbUserDetailInfoServiceImpl implements ITbUserDetailInfoService 
{
    @Autowired
    private TbUserDetailInfoMapper tbUserDetailInfoMapper;

    @Resource
    private TbUserMapper tbUserMapper;

    @Resource
    private TbConsultantMapper tbConsultantMapper;

    /**
     * 查询用户详细信息
     * 
     * @param id 用户详细信息主键
     * @return 用户详细信息
     */
    @Override
    public TbUserDetailInfo selectTbUserDetailInfoById(Long id)
    {
        TbUserDetailInfo tbUserDetailInfo=tbUserDetailInfoMapper.selectTbUserDetailInfoById(id);
        convertInfo(tbUserDetailInfo);
        return tbUserDetailInfo;
    }

    @Override
    public TbUserDetailInfo selectTbUserDetailInfoByApplyId(String applyId){
        TbUserDetailInfo tbUserDetailInfo=tbUserDetailInfoMapper.selectTbUserDetailInfoByApplyId(applyId);
        convertInfo(tbUserDetailInfo);
        return tbUserDetailInfo;
    }

    /**
     * 查询用户详细信息列表
     * 
     * @param tbUserDetailInfo 用户详细信息
     * @return 用户详细信息
     */
    @Override
    public List<TbUserDetailInfo> selectTbUserDetailInfoList(TbUserDetailInfo tbUserDetailInfo)
    {
        List<TbUserDetailInfo> list=tbUserDetailInfoMapper.selectTbUserDetailInfoList(tbUserDetailInfo);
        list.stream().filter(tbUserDetailInfo1 -> {
            convertInfo(tbUserDetailInfo1);
            return true;
        }).collect(Collectors.toList());
        return list;
    }

    /**
     * 新增用户详细信息
     * 
     * @param tbUserDetailInfo 用户详细信息
     * @return 结果
     */
    @Override
    public int insertTbUserDetailInfo(TbUserDetailInfo tbUserDetailInfo)
    {
        return tbUserDetailInfoMapper.insertTbUserDetailInfo(tbUserDetailInfo);
    }

    /**
     * 修改用户详细信息
     * 
     * @param tbUserDetailInfo 用户详细信息
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTbUserDetailInfo(TbUserDetailInfo tbUserDetailInfo)
    {
        Long userid = tbUserDetailInfoMapper.selectTbUserDetailInfoById(tbUserDetailInfo.getId()).getUserid();
        TbUserDetailInfo userDetailInfo=tbUserDetailInfoMapper.selectTbUserDetailInfoByUserid(userid);
        TbUserDetailInfo detailInfo=new TbUserDetailInfo();
        BeanUtils.copyProperties(tbUserDetailInfo,detailInfo);
        detailInfo.setId(userDetailInfo.getId());
        detailInfo.setApplyId(null);
        detailInfo.setFinishState(Constants.NO);
        detailInfo.setCountProgress(Constants.NO);
        detailInfo.setIsModify(Constants.YES);
        //更新副本
        tbUserDetailInfoMapper.updateTbUserDetailInfo(detailInfo);
        return tbUserDetailInfoMapper.updateTbUserDetailInfo(tbUserDetailInfo);
    }

    /**
     * 批量删除用户详细信息
     * 
     * @param ids 需要删除的用户详细信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserDetailInfoByIds(String ids)
    {
        return tbUserDetailInfoMapper.deleteTbUserDetailInfoByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户详细信息信息
     * 
     * @param id 用户详细信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserDetailInfoById(Long id)
    {
        return tbUserDetailInfoMapper.deleteTbUserDetailInfoById(id);
    }

    private void convertInfo(TbUserDetailInfo tbUserDetailInfo){
        if(ObjectUtils.isNotEmpty(tbUserDetailInfo.getHoldPassport())){
            tbUserDetailInfo.setHoldPassportDesc(DictUtils.getDictLabel(
                    Constants.SYS_YES_NO,tbUserDetailInfo.getHoldPassport()
            ));
            if(tbUserDetailInfo.getHoldPassport().equals(Constants.YES)){
                tbUserDetailInfo.setPassportIssueDate(
                        tbUserDetailInfo.getPassportIssueDateYear()+"."+
                                tbUserDetailInfo.getPassportIssueDateMonth()+"."+
                                tbUserDetailInfo.getPassportIssueDateDay()
                );
                tbUserDetailInfo.setPassportValid(
                        tbUserDetailInfo.getPassportValidYear()+"."+
                                tbUserDetailInfo.getPassportValidMonth()+"."+
                                tbUserDetailInfo.getPassportValidDay()
                );
            }
        }

        if(ObjectUtils.isNotEmpty(tbUserDetailInfo.getHoldVisa())){
            tbUserDetailInfo.setHoldVisaDesc(
                    DictUtils.getDictLabel(
                            Constants.SYS_YES_NO,tbUserDetailInfo.getHoldVisa()
                    )
            );
            if(tbUserDetailInfo.getHoldVisa().equals(Constants.YES)){
                tbUserDetailInfo.setVisaTypeDesc(
                        DictUtils.getDictLabel(Constants.BUSINESS_VISA_TYPE,tbUserDetailInfo.getVisaType())
                );
                tbUserDetailInfo.setVisaValid(
                        tbUserDetailInfo.getVisaValidYear()+"."+
                                tbUserDetailInfo.getVisaValidMonth()+"."+
                                tbUserDetailInfo.getVisaValidDay()
                );
            }
        }

        if(ObjectUtils.isNotEmpty(tbUserDetailInfo.getCountry())){
            tbUserDetailInfo.setCountryDesc(
                    String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,Constants.BUSINESS_REGION_KEY+tbUserDetailInfo.getCountry()))
            );
            tbUserDetailInfo.setCountryCode(
                    tbUserDetailInfo.getCountry()
            );
            tbUserDetailInfo.setProvinceDesc(
                    String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,Constants.BUSINESS_REGION_KEY+tbUserDetailInfo.getProvince()))
            );
            tbUserDetailInfo.setProvinceCode(
                    tbUserDetailInfo.getProvince()
            );
            tbUserDetailInfo.setCityDesc(
                    String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,Constants.BUSINESS_REGION_KEY+tbUserDetailInfo.getCity()))
            );
            tbUserDetailInfo.setCityCode(
                    tbUserDetailInfo.getCity()
            );
            tbUserDetailInfo.setCountryProvinceCity(
                    tbUserDetailInfo.getCountryDesc()+
                            tbUserDetailInfo.getProvinceDesc()+
                            tbUserDetailInfo.getCityDesc()
            );
        }
    }

    /**
     * @Author : fanxiaolong
     * @Description : 修改编辑状态
     * @DateTime : 2023/4/18 13:20
     * @param : applyId
     * @param : state
     * @return : void
     */
    @Override
    public void updateModifyState(String applyId,String state){

        tbUserDetailInfoMapper.updateModifyState(state,applyId);
    }

    /**
     * @Author : fanxiaolong
     * @Description : 根据手机号或者护照号或者身份证号查询用户的姓名
     * @DateTime : 2023/8/3 16:44
     * @param : vagueParam
     * @return : java.lang.String
     */
    @Override
    public StudentInfo queryUserName(@Param("vagueParam") String vagueParam){
        StudentInfo studentInfo = tbUserDetailInfoMapper.queryUserName(vagueParam);
        //加上顾问信息
        TbUser tbUser = tbUserMapper.selectTbUserById(studentInfo.getUserid());
        if(ObjectUtil.isNotNull(tbUser.getConsultant()) && ObjectUtil.isNotEmpty(tbUser.getConsultant())){
            TbConsultant consultant = tbConsultantMapper.selectTbConsultantById(tbUser.getConsultant());
            studentInfo.setConsultantId(tbUser.getConsultant());
            studentInfo.setConsultantName(consultant.getConsultantName());
        }
        return studentInfo;
    }
}
