package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.CacheUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbUserEducationBackgroundMapper;
import com.ruoyi.system.domain.TbUserEducationBackground;
import com.ruoyi.system.service.ITbUserEducationBackgroundService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;

/**
 * 用户教育背景Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Service
public class TbUserEducationBackgroundServiceImpl implements ITbUserEducationBackgroundService 
{
    @Autowired
    private TbUserEducationBackgroundMapper tbUserEducationBackgroundMapper;

    /**
     * 查询用户教育背景
     * 
     * @param id 用户教育背景主键
     * @return 用户教育背景
     */
    @Override
    public TbUserEducationBackground selectTbUserEducationBackgroundById(Long id)
    {
        TbUserEducationBackground tbUserEducationBackground=tbUserEducationBackgroundMapper.selectTbUserEducationBackgroundById(id);
        convert(tbUserEducationBackground);
        return tbUserEducationBackground;
    }

    /**
     * 查询用户教育背景列表
     * 
     * @param tbUserEducationBackground 用户教育背景
     * @return 用户教育背景
     */
    @Override
    public List<TbUserEducationBackground> selectTbUserEducationBackgroundList(TbUserEducationBackground tbUserEducationBackground)
    {
        List<TbUserEducationBackground> list=tbUserEducationBackgroundMapper.selectTbUserEducationBackgroundList(tbUserEducationBackground);
        list.stream().filter(tbUserEducationBackground1 -> {
            convert(tbUserEducationBackground1);
            return true;
        }).collect(Collectors.toList());
        return list;
    }

    @Override
    public List<TbUserEducationBackground> selectTbUserEducationBackgroundListByApplyId(String applyId){
        List<TbUserEducationBackground> list=tbUserEducationBackgroundMapper.selectTbUserEducationBackgroundListByApplyId(applyId);
        list.stream().filter(tbUserEducationBackground -> {
            convert(tbUserEducationBackground);
            return true;
        }).collect(Collectors.toList());
        return list;
    }

    /**
     * 新增用户教育背景
     * 
     * @param tbUserEducationBackground 用户教育背景
     * @return 结果
     */
    @Override
    public int insertTbUserEducationBackground(TbUserEducationBackground tbUserEducationBackground)
    {
        return tbUserEducationBackgroundMapper.insertTbUserEducationBackground(tbUserEducationBackground);
    }

    /**
     * 修改用户教育背景
     * 
     * @param tbUserEducationBackground 用户教育背景
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTbUserEducationBackground(TbUserEducationBackground tbUserEducationBackground)
    {
        TbUserEducationBackground educationBackground=tbUserEducationBackgroundMapper.selectTbUserEducationBackgroundListByMasterId(tbUserEducationBackground.getId());
        if(ObjectUtils.isNotEmpty(educationBackground)){
            //更新副本
            TbUserEducationBackground educationBackground1=new TbUserEducationBackground();
            BeanUtils.copyProperties(tbUserEducationBackground,educationBackground1);
            educationBackground1.setId(educationBackground.getId());
            educationBackground1.setMasterId(tbUserEducationBackground.getId());
            educationBackground1.setApplyId(null);
            educationBackground1.setIsModify(educationBackground.getIsModify());
            educationBackground1.setFinishState(educationBackground.getFinishState());
            educationBackground1.setCountProgress(educationBackground.getCountProgress());
            tbUserEducationBackgroundMapper.updateTbUserEducationBackground(educationBackground1);
        }
        return tbUserEducationBackgroundMapper.updateTbUserEducationBackground(tbUserEducationBackground);
    }

    /**
     * 批量删除用户教育背景
     * 
     * @param ids 需要删除的用户教育背景主键
     * @return 结果
     */
    @Override
    public int deleteTbUserEducationBackgroundByIds(String ids)
    {
        return tbUserEducationBackgroundMapper.deleteTbUserEducationBackgroundByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户教育背景信息
     * 
     * @param id 用户教育背景主键
     * @return 结果
     */
    @Override
    public int deleteTbUserEducationBackgroundById(Long id)
    {
        return tbUserEducationBackgroundMapper.deleteTbUserEducationBackgroundById(id);
    }

    private void convert(TbUserEducationBackground userEducationBackground){
        userEducationBackground.setEducationTypeDesc(
                DictUtils.getDictLabel(Constants.BUSINESS_EDUCATION_TYPE,userEducationBackground.getEducationType())
        );
        userEducationBackground.setScoreTypeDesc(
                DictUtils.getDictLabel(Constants.BUSINESS_SCORE_TYPE,userEducationBackground.getScoreType())
        );
        if(StringUtils.isNotNull(userEducationBackground.getGpaType()) && StringUtils.isNotEmpty(userEducationBackground.getGpaType())){
            userEducationBackground.setGpaTypeDesc(
                    DictUtils.getDictLabel(
                            Constants.BUSINESS_GPA_TYPE,userEducationBackground.getGpaType()
                    )
            );
            userEducationBackground.setScoreTypeDesc(
                    userEducationBackground.getScoreTypeDesc()+" "+
                            userEducationBackground.getGpaTypeDesc()
            );
        }
        userEducationBackground.setCountryDesc(
                String.valueOf(
                        CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+userEducationBackground.getCountry()))
        );
        userEducationBackground.setCountryCode(userEducationBackground.getCountry());
        userEducationBackground.setProvinceDesc(
                String.valueOf(
                        CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                                Constants.BUSINESS_REGION_KEY+userEducationBackground.getProvince())
                )
        );
        userEducationBackground.setProvinceCode(userEducationBackground.getProvince());
        String str=String.valueOf(
                CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+userEducationBackground.getCity())
        );
        userEducationBackground.setCityDesc(
                StringUtils.isEmpty(str) ? " " : str
        );
        userEducationBackground.setCityCode(userEducationBackground.getCity());
        userEducationBackground.setCountryProvinceCity(
                userEducationBackground.getCountryDesc()+
                        userEducationBackground.getProvinceDesc()+
                        userEducationBackground.getCityDesc()
        );
        userEducationBackground.setStartSchool(
                userEducationBackground.getStartSchoolYear()+"."+
                        userEducationBackground.getStartSchoolMonth()
        );
        userEducationBackground.setFinishSchool(
                userEducationBackground.getFinishSchoolYear()+"."+
                        userEducationBackground.getFinishSchoolMonth()
        );
    }

    /**
     * @Author : fanxiaolong
     * @Description : 修改编辑状态
     * @DateTime : 2023/4/18 13:21
     * @param : applyId
     * @param : state
     * @return : void
     */
    @Override
    public void updateModifyState(String applyId,String state){

        tbUserEducationBackgroundMapper.updateModifyState(state,applyId);
    }
}
