package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbUserLanguageBackgroundMapper;
import com.ruoyi.system.domain.TbUserLanguageBackground;
import com.ruoyi.system.service.ITbUserLanguageBackgroundService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.ModelMap;

/**
 * 用户语言背景Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Service
public class TbUserLanguageBackgroundServiceImpl implements ITbUserLanguageBackgroundService 
{
    @Autowired
    private TbUserLanguageBackgroundMapper tbUserLanguageBackgroundMapper;

    /**
     * 查询用户语言背景
     * 
     * @param id 用户语言背景主键
     * @return 用户语言背景
     */
    @Override
    public TbUserLanguageBackground selectTbUserLanguageBackgroundById(Long id)
    {
        TbUserLanguageBackground tbUserLanguageBackground = tbUserLanguageBackgroundMapper.selectTbUserLanguageBackgroundById(id);
        convert(tbUserLanguageBackground);
        return tbUserLanguageBackground;
    }

    @Override
    public TbUserLanguageBackground selectTbUserLanguageBackgroundByApplyId(String applyId){
        TbUserLanguageBackground tbUserLanguageBackground = tbUserLanguageBackgroundMapper.selectTbUserLanguageBackgroundByApplyId(applyId);
        convert(tbUserLanguageBackground);
        return tbUserLanguageBackground;
    }

    /**
     * 查询用户语言背景列表
     * 
     * @param tbUserLanguageBackground 用户语言背景
     * @return 用户语言背景
     */
    @Override
    public List<TbUserLanguageBackground> selectTbUserLanguageBackgroundList(TbUserLanguageBackground tbUserLanguageBackground)
    {
        List<TbUserLanguageBackground> languageBackgroundList = tbUserLanguageBackgroundMapper.selectTbUserLanguageBackgroundList(tbUserLanguageBackground);
        languageBackgroundList.stream().filter(tbUserLanguageBackground1 -> {
            convert(tbUserLanguageBackground1);
            return true;
        }).collect(Collectors.toList());
        return languageBackgroundList;
    }

    /**
     * 新增用户语言背景
     * 
     * @param tbUserLanguageBackground 用户语言背景
     * @return 结果
     */
    @Override
    public int insertTbUserLanguageBackground(TbUserLanguageBackground tbUserLanguageBackground)
    {
        return tbUserLanguageBackgroundMapper.insertTbUserLanguageBackground(tbUserLanguageBackground);
    }

    /**
     * 修改用户语言背景
     * 
     * @param tbUserLanguageBackground 用户语言背景
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTbUserLanguageBackground(TbUserLanguageBackground tbUserLanguageBackground)
    {
        Long userid = tbUserLanguageBackgroundMapper.selectTbUserLanguageBackgroundById(tbUserLanguageBackground.getId()).getUserid();
        TbUserLanguageBackground userLanguageBackground1=tbUserLanguageBackgroundMapper.selectTbUserLanguageBackgroundByUserId(userid);
        TbUserLanguageBackground userLanguageBackground=new TbUserLanguageBackground();
        BeanUtils.copyProperties(tbUserLanguageBackground,userLanguageBackground);
        userLanguageBackground.setId(userLanguageBackground1.getId());
        userLanguageBackground.setApplyId(null);
        userLanguageBackground.setCountProgress(Constants.NO);
        userLanguageBackground.setFinishState(Constants.NO);
        userLanguageBackground.setIsModify(Constants.YES);
        tbUserLanguageBackgroundMapper.updateTbUserLanguageBackground(userLanguageBackground);
        return tbUserLanguageBackgroundMapper.updateTbUserLanguageBackground(tbUserLanguageBackground);
    }

    /**
     * 批量删除用户语言背景
     * 
     * @param ids 需要删除的用户语言背景主键
     * @return 结果
     */
    @Override
    public int deleteTbUserLanguageBackgroundByIds(String ids)
    {
        return tbUserLanguageBackgroundMapper.deleteTbUserLanguageBackgroundByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户语言背景信息
     * 
     * @param id 用户语言背景主键
     * @return 结果
     */
    @Override
    public int deleteTbUserLanguageBackgroundById(Long id)
    {
        return tbUserLanguageBackgroundMapper.deleteTbUserLanguageBackgroundById(id);
    }

    private void convert(TbUserLanguageBackground tbUserLanguageBackground){
        if(StringUtils.isNotEmpty(tbUserLanguageBackground.getExamType())){
            if(StringUtils.isNotNull(tbUserLanguageBackground.getSpecialExamType()) && StringUtils.isNotEmpty(tbUserLanguageBackground.getSpecialExamType())){
                tbUserLanguageBackground.setExamTypeDesc(tbUserLanguageBackground.getSpecialExamType());
            }else{
                tbUserLanguageBackground.setExamTypeDesc(
                        DictUtils.getDictLabel(
                                Constants.BUSINESS_LANGUAGE_EXAM_TYPE,
                                tbUserLanguageBackground.getExamType()
                        )
                );
            }
            tbUserLanguageBackground.setExamTypeCode(tbUserLanguageBackground.getExamType());
            tbUserLanguageBackground.setExamTime(
                    tbUserLanguageBackground.getExamTimeYear()+"."+
                            tbUserLanguageBackground.getExamTimeMonth()+"."+
                            tbUserLanguageBackground.getExamTimeDay()
            );
            tbUserLanguageBackground.setScoreExpire(
                    tbUserLanguageBackground.getScoreExpireYear()+"."+
                            tbUserLanguageBackground.getScoreExpireMonth()+"."+
                            tbUserLanguageBackground.getScoreExpireDay()
            );
        }
    }

    /**
     * @Author : fanxiaolong
     * @Description : 修改编辑状态
     * @DateTime : 2023/4/18 13:21
     * @param : applyId
     * @param : state
     * @return : void
     */
    @Override
    public void updateModifyState(String applyId,String state){

        tbUserLanguageBackgroundMapper.updateModifyState(state,applyId);
    }
}
