package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.List;
import com.ruoyi.system.domain.TbUserApply;
import com.ruoyi.system.mapper.TbMaterialDemoMapper;
import com.ruoyi.system.mapper.TbUserApplyMapper;
import com.ruoyi.system.mapper.TbUserBasicInfoMapper;
import com.ruoyi.system.res.UserApplyRes;
import com.ruoyi.system.res.UserMaterialRes;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbUserMaterialMapper;
import com.ruoyi.system.domain.TbUserMaterial;
import com.ruoyi.system.service.ITbUserMaterialService;
import com.ruoyi.common.core.text.Convert;

/**
 * 用户提交的材料Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-04-10
 */
@Service
public class TbUserMaterialServiceImpl implements ITbUserMaterialService 
{
    @Autowired
    private TbUserMaterialMapper tbUserMaterialMapper;

    @Autowired
    private TbUserBasicInfoMapper userBasicInfoMapper;

    @Autowired
    private TbUserApplyMapper userApplyMapper;

    @Autowired
    private TbMaterialDemoMapper materialDemoMapper;

    /**
     * 查询用户提交的材料
     * 
     * @param id 用户提交的材料主键
     * @return 用户提交的材料
     */
    @Override
    public TbUserMaterial selectTbUserMaterialById(Long id)
    {
        TbUserMaterial tbUserMaterial = tbUserMaterialMapper.selectTbUserMaterialById(id);
        tbUserMaterial.setMaterialTypeDesc(
                materialDemoMapper.selectTbMaterialDemoById(tbUserMaterial.getMaterialType()).getMaterialName()
        );
        return tbUserMaterial;
    }

    /**
     * 查询用户提交的材料列表
     * 
     * @param tbUserMaterial 用户提交的材料
     * @return 用户提交的材料
     */
//    @Override
//    public List<TbUserMaterial> selectTbUserMaterialList(TbUserMaterial tbUserMaterial)
//    {
//        List<TbUserMaterial> tbUserMaterials = tbUserMaterialMapper.selectTbUserMaterialList(tbUserMaterial);
//        return tbUserMaterials;
//    }

    @Override
    public List<UserMaterialRes> selectUserMaterialList(TbUserMaterial tbUserMaterial){
        List<UserMaterialRes> originList=tbUserMaterialMapper.selectUserMaterialList(tbUserMaterial);
        if(null != originList && !originList.isEmpty()){
            for(UserMaterialRes userMaterialRes : originList){
                userMaterialRes.setMaterialTypeDesc(
                        materialDemoMapper.selectTbMaterialDemoById(userMaterialRes.getMaterialType()).getMaterialName()
                );
                userMaterialRes.setUserName(userBasicInfoMapper.selectUserNameByApplyId(userMaterialRes.getApplyId()));
                UserApplyRes tbUserApply = userApplyMapper.selectUserApplyById(userMaterialRes.getApplyId());
                userMaterialRes.setSchoolName(tbUserApply.getSchoolCnName());
                userMaterialRes.setMajorName(tbUserApply.getMajorCnName());
                userMaterialRes.setDegreeName(tbUserApply.getDegreeCnName());
            }
            return originList;
        }
        return new ArrayList<>();
    }

    /**
     * 新增用户提交的材料
     * 
     * @param tbUserMaterial 用户提交的材料
     * @return 结果
     */
    @Override
    public int insertTbUserMaterial(TbUserMaterial tbUserMaterial)
    {
        return tbUserMaterialMapper.insertTbUserMaterial(tbUserMaterial);
    }

    /**
     * 修改用户提交的材料
     * 
     * @param tbUserMaterial 用户提交的材料
     * @return 结果
     */
    @Override
    public int updateTbUserMaterial(TbUserMaterial tbUserMaterial)
    {
        return tbUserMaterialMapper.updateTbUserMaterial(tbUserMaterial);
    }

    /**
     * 批量删除用户提交的材料
     * 
     * @param ids 需要删除的用户提交的材料主键
     * @return 结果
     */
    @Override
    public int deleteTbUserMaterialByIds(String ids)
    {
        return tbUserMaterialMapper.deleteTbUserMaterialByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户提交的材料信息
     * 
     * @param id 用户提交的材料主键
     * @return 结果
     */
    @Override
    public int deleteTbUserMaterialById(Long id)
    {
        return tbUserMaterialMapper.deleteTbUserMaterialById(id);
    }
}
