package com.ruoyi.system.service.impl;

import java.util.Arrays;
import java.util.List;
import com.ruoyi.common.constant.ApplyStateEnum;
import com.ruoyi.common.constant.ApplyStatusEnum;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ShiroUtils;
import com.ruoyi.system.domain.*;
import com.ruoyi.system.mapper.*;
import com.ruoyi.system.res.UserApplyRes;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.service.ITbUserOfferService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;

/**
 * 用户offerService业务层处理
 * 
 * @author ruoyi
 * @date 2023-01-16
 */
@Service
public class TbUserOfferServiceImpl implements ITbUserOfferService 
{
    @Autowired
    private TbUserOfferMapper tbUserOfferMapper;

    @Autowired
    private TbUserApplyMapper tbUserApplyMapper;

    @Autowired
    private TbSchoolMajorMapper tbSchoolMajorMapper;

    @Autowired
    private TbSchoolMapper tbSchoolMapper;

    @Autowired
    private TbUserApplyMapper userApplyMapper;

    @Autowired
    private TbNoticeMapper noticeMapper;

    /**
     * 查询用户offer
     * 
     * @param id 用户offer主键
     * @return 用户offer
     */
    @Override
    public TbUserOffer selectTbUserOfferById(Long id)
    {
        return tbUserOfferMapper.selectTbUserOfferById(id);
    }

    /**
     * 查询用户offer列表
     * 
     * @param tbUserOffer 用户offer
     * @return 用户offer
     */
    @Override
    public List<TbUserOffer> selectTbUserOfferList(TbUserOffer tbUserOffer)
    {
        return tbUserOfferMapper.selectTbUserOfferList(tbUserOffer);
    }

    /**
     * 新增用户offer
     * 
     * @param tbUserOffer 用户offer
     * @return 结果
     */
    @Transactional
    @Override
    public int insertTbUserOffer(TbUserOffer tbUserOffer)
    {
        UserApplyRes tbUserApply=tbUserApplyMapper.selectTbUserApplyById(tbUserOffer.getApplyId());
        TbSchoolMajor tbSchoolMajor=tbSchoolMajorMapper.selectTbSchoolMajorById(Long.valueOf(tbUserApply.getMajorId()));
        //更新申请状态和进度
        TbUserApply userApply=new TbUserApply();
        userApply.setId(tbUserOffer.getApplyId());
        userApply.setApplyProgress(Constants.BUSINESS_APPLY_END);

        //0 被拒，1 被录取
        if(tbUserOffer.getApplyResult().equals("0")){
            //修改申请状态
            userApply.setApplyState(ApplyStateEnum.reject.getState());
            userApply.setApplyStatus(ApplyStatusEnum.reject_apply.getStatus());
            //给用户发通知
            TbNotice tbNotice=new TbNotice();
            tbNotice.setApplyId(tbUserOffer.getApplyId());
            tbNotice.setNoticeContent(tbUserOffer.getRejectReason());
            TbSchool tbSchool = tbSchoolMapper.selectTbSchoolById(tbSchoolMajor.getSchoolId());
            tbNotice.setNoticeTitle("申请 "+tbSchool.getSchoolCnName()+" "+tbSchoolMajor.getMajorCnName()+" 被拒");
            tbNotice.setNoticeType(2);
            tbNotice.setUserId(tbUserOffer.getUserid());
            tbNotice.setStatus(1);
            tbNotice.setCreator(ShiroUtils.getUserId());
            tbNotice.setCreateTime(DateUtils.getNowDate());
            noticeMapper.insertTbNotice(tbNotice);
        }else{
            //更新录取人数
            final boolean b = Arrays.stream(Constants.BUSSINESS_UNDERGRADUATE_DEGREE).anyMatch(s -> {
                if (s.equals(tbSchoolMajor.getDegreeType())) {
                    tbSchoolMapper.updateUndergraduateEnrollment(tbSchoolMajor.getSchoolId());
                    return true;
                }else{
                    return false;
                }
            });
            if(!b){
                tbSchoolMapper.updateMasterDoctoralEnrollment(tbSchoolMajor.getSchoolId());
            }
            userApply.setApplyState(ApplyStateEnum.finish.getState());
            userApply.setApplyStatus(ApplyStatusEnum.get_offer.getStatus());
        }
        userApplyMapper.updateTbUserApplyStatusById(userApply);

        return tbUserOfferMapper.insertTbUserOffer(tbUserOffer);
    }

    /**
     * 修改用户offer
     * 
     * @param tbUserOffer 用户offer
     * @return 结果
     */
    @Override
    public int updateTbUserOffer(TbUserOffer tbUserOffer)
    {
        return tbUserOfferMapper.updateTbUserOffer(tbUserOffer);
    }

    /**
     * 批量删除用户offer
     * 
     * @param ids 需要删除的用户offer主键
     * @return 结果
     */
    @Override
    public int deleteTbUserOfferByIds(String ids)
    {
        return tbUserOfferMapper.deleteTbUserOfferByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户offer信息
     * 
     * @param id 用户offer主键
     * @return 结果
     */
    @Override
    public int deleteTbUserOfferById(Long id)
    {
        return tbUserOfferMapper.deleteTbUserOfferById(id);
    }
}
