package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.constant.IDTypeEnum;
import com.ruoyi.common.utils.CacheUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbUserParentInfoMapper;
import com.ruoyi.system.domain.TbUserParentInfo;
import com.ruoyi.system.service.ITbUserParentInfoService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;

/**
 * 用户父母信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Service
public class TbUserParentInfoServiceImpl implements ITbUserParentInfoService 
{
    @Autowired
    private TbUserParentInfoMapper tbUserParentInfoMapper;

    /**
     * 查询用户父母信息
     * 
     * @param id 用户父母信息主键
     * @return 用户父母信息
     */
    @Override
    public TbUserParentInfo selectTbUserParentInfoById(Long id)
    {
        TbUserParentInfo parentInfo = tbUserParentInfoMapper.selectTbUserParentInfoById(id);
        convert(parentInfo);
        return parentInfo;
    }

    /**
     * 查询用户父母信息列表
     * 
     * @param tbUserParentInfo 用户父母信息
     * @return 用户父母信息
     */
    @Override
    public List<TbUserParentInfo> selectTbUserParentInfoList(TbUserParentInfo tbUserParentInfo)
    {
        List<TbUserParentInfo> parentInfoList = tbUserParentInfoMapper.selectTbUserParentInfoList(tbUserParentInfo);
        parentInfoList.stream().filter(parentInfo -> {
            convert(parentInfo);
            return true;
        }).collect(Collectors.toList());
        return parentInfoList;
    }

    @Override
    public List<TbUserParentInfo> selectTbUserParentInfoListByApplyId(String applyId){
        List<TbUserParentInfo> parentInfoList = tbUserParentInfoMapper.selectTbUserParentInfoListByApplyId(applyId);
        parentInfoList.stream().filter(parentInfo -> {
            convert(parentInfo);
            return true;
        }).collect(Collectors.toList());
        return parentInfoList;
    }

    /**
     * 新增用户父母信息
     * 
     * @param tbUserParentInfo 用户父母信息
     * @return 结果
     */
    @Override
    public int insertTbUserParentInfo(TbUserParentInfo tbUserParentInfo)
    {
        return tbUserParentInfoMapper.insertTbUserParentInfo(tbUserParentInfo);
    }

    /**
     * 修改用户父母信息
     * 
     * @param tbUserParentInfo 用户父母信息
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTbUserParentInfo(TbUserParentInfo tbUserParentInfo)
    {
        TbUserParentInfo userParentInfo=tbUserParentInfoMapper.selectTbUserParentInfoByMasterId(tbUserParentInfo.getId());
        if(ObjectUtils.isNotEmpty(userParentInfo)){
            TbUserParentInfo userParentInfo1=new TbUserParentInfo();
            BeanUtils.copyProperties(tbUserParentInfo,userParentInfo1);
            userParentInfo1.setApplyId(null);
            userParentInfo1.setMasterId(tbUserParentInfo.getId());
            userParentInfo1.setId(userParentInfo.getId());
            userParentInfo1.setIsModify(Constants.YES);
            userParentInfo1.setCountProgress(Constants.NO);
            userParentInfo1.setFinishState(Constants.NO);
            tbUserParentInfoMapper.updateTbUserParentInfo(userParentInfo1);
        }
        return tbUserParentInfoMapper.updateTbUserParentInfo(tbUserParentInfo);
    }

    /**
     * 批量删除用户父母信息
     * 
     * @param ids 需要删除的用户父母信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserParentInfoByIds(String ids)
    {
        return tbUserParentInfoMapper.deleteTbUserParentInfoByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户父母信息信息
     * 
     * @param id 用户父母信息主键
     * @return 结果
     */
    @Override
    public int deleteTbUserParentInfoById(Long id)
    {
        return tbUserParentInfoMapper.deleteTbUserParentInfoById(id);
    }

    private void convert(TbUserParentInfo parentInfo){
        parentInfo.setParentCountryCode(parentInfo.getParentCountry());
        parentInfo.setParentProvinceCode(parentInfo.getParentProvince());
        parentInfo.setParentCityCode(parentInfo.getParentCity());

        parentInfo.setParentCountryDesc(
                String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+parentInfo.getParentCountry()))
        );
        parentInfo.setParentProvinceDesc(
                String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+parentInfo.getParentProvince()))
        );
        parentInfo.setParentCityDesc(
                String.valueOf(CacheUtils.get(Constants.BUSINESS_REGION_CACHE,
                        Constants.BUSINESS_REGION_KEY+parentInfo.getParentCity()))
        );
        parentInfo.setParentCountryProvinceCity(
                parentInfo.getParentCountryDesc()+
                        parentInfo.getParentProvinceDesc()+
                        parentInfo.getParentCityDesc()
        );

        if(ObjectUtils.isNotEmpty(parentInfo.getParentIdType())){
            if(parentInfo.getParentIdType().equals(IDTypeEnum.idcard.getType())){
                parentInfo.setParentIdType(IDTypeEnum.idcard.getTypeDesc());
            }else if(parentInfo.getParentIdType().equals(IDTypeEnum.passport.getType())){
                parentInfo.setParentIdType(IDTypeEnum.passport.getTypeDesc());
            }
        }
    }

    /**
     * @Author : fanxiaolong
     * @Description : 修改编辑状态
     * @DateTime : 2023/4/18 13:19
     * @param : applyId
     * @param : state
     * @return : void
     */
    @Override
    public void updateModifyState(String applyId,String state){

        tbUserParentInfoMapper.updateModifyState(state,applyId);
    }
}
