package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.common.constant.Constants;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbUserWorkExperienceMapper;
import com.ruoyi.system.domain.TbUserWorkExperience;
import com.ruoyi.system.service.ITbUserWorkExperienceService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.ModelMap;

/**
 * 用户工作经历Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-29
 */
@Service
public class TbUserWorkExperienceServiceImpl implements ITbUserWorkExperienceService 
{
    @Autowired
    private TbUserWorkExperienceMapper tbUserWorkExperienceMapper;

    /**
     * 查询用户工作经历
     * 
     * @param id 用户工作经历主键
     * @return 用户工作经历
     */
    @Override
    public TbUserWorkExperience selectTbUserWorkExperienceById(Long id)
    {
        TbUserWorkExperience tbUserWorkExperience=tbUserWorkExperienceMapper.selectTbUserWorkExperienceById(id);
        convert(tbUserWorkExperience);
        return tbUserWorkExperience;
    }

    /**
     * 查询用户工作经历列表
     * 
     * @param tbUserWorkExperience 用户工作经历
     * @return 用户工作经历
     */
    @Override
    public List<TbUserWorkExperience> selectTbUserWorkExperienceList(TbUserWorkExperience tbUserWorkExperience)
    {
        List<TbUserWorkExperience> list=tbUserWorkExperienceMapper.selectTbUserWorkExperienceList(tbUserWorkExperience);
        list.stream().filter(workExperience -> {
            convert(workExperience);
            return true;
        }).collect(Collectors.toList());
        return list;
    }

    @Override
    public List<TbUserWorkExperience> selectTbUserWorkExperienceListByApplyId(String applyId){
        List<TbUserWorkExperience> list = tbUserWorkExperienceMapper.selectTbUserWorkExperienceListByApplyId(applyId);
        list.stream().filter(workExperience -> {
            convert(workExperience);
            return true;
        }).collect(Collectors.toList());
        return list;
    }

    /**
     * 新增用户工作经历
     * 
     * @param tbUserWorkExperience 用户工作经历
     * @return 结果
     */
    @Override
    public int insertTbUserWorkExperience(TbUserWorkExperience tbUserWorkExperience)
    {
        return tbUserWorkExperienceMapper.insertTbUserWorkExperience(tbUserWorkExperience);
    }

    /**
     * 修改用户工作经历
     * 
     * @param tbUserWorkExperience 用户工作经历
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTbUserWorkExperience(TbUserWorkExperience tbUserWorkExperience)
    {
        TbUserWorkExperience userWorkExperience=tbUserWorkExperienceMapper.selectTbUserWorkExperienceByMasterId(tbUserWorkExperience.getId());
        if(ObjectUtils.isNotEmpty(userWorkExperience)){
            TbUserWorkExperience workExperience=new TbUserWorkExperience();
            BeanUtils.copyProperties(tbUserWorkExperience,workExperience);
            workExperience.setId(userWorkExperience.getId());
            workExperience.setMasterId(tbUserWorkExperience.getId());
            workExperience.setIsModify(Constants.YES);
            workExperience.setFinishState(Constants.NO);
            workExperience.setCountProgress(Constants.NO);
            tbUserWorkExperienceMapper.updateTbUserWorkExperience(workExperience);
        }
        return tbUserWorkExperienceMapper.updateTbUserWorkExperience(tbUserWorkExperience);
    }

    /**
     * 批量删除用户工作经历
     * 
     * @param ids 需要删除的用户工作经历主键
     * @return 结果
     */
    @Override
    public int deleteTbUserWorkExperienceByIds(String ids)
    {
        return tbUserWorkExperienceMapper.deleteTbUserWorkExperienceByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户工作经历信息
     * 
     * @param id 用户工作经历主键
     * @return 结果
     */
    @Override
    public int deleteTbUserWorkExperienceById(Long id)
    {
        return tbUserWorkExperienceMapper.deleteTbUserWorkExperienceById(id);
    }

    private void convert(TbUserWorkExperience workExperience){
        workExperience.setStartTime(
                workExperience.getStartTimeYear()+"."+
                        workExperience.getStartTimeMonth()+"."+
                        workExperience.getStartTimeDay()
        );

        workExperience.setEndTime(
                workExperience.getEndTimeYear()+"."+
                        workExperience.getEndTimeMonth()+"."+
                        workExperience.getEndTimeDay()
        );
    }

    /**
     * @Author : fanxiaolong
     * @Description : 修改编辑状态
     * @DateTime : 2023/4/18 13:18
     * @param : applyId
     * @param : state
     * @return : void
     */
   @Override
   public void updateModifyState(String applyId,String state){

       tbUserWorkExperienceMapper.updateModifyState(state,applyId);
   }
}
